/* unicode-categories.h */
/* THIS IS A GENERATED FILE. CHANGES WILL BE OVERWRITTEN. */
/* Generated by ./gen-unicode-headers.pl */
/* Generated from UCD version 16.0.0 */

#pragma once

#include <glib.h>

#ifndef __GTK_DOC_IGNORE__

typedef struct _FontManagerUnicodeCategory FontManagerUnicodeCategory;

static const struct _FontManagerUnicodeCategory
{
  gunichar start;
  gunichar end;
  GUnicodeType category;
}
unicode_categories[] =
{
  { 0x0000, 0x001F, G_UNICODE_CONTROL },
  { 0x0020, 0x0020, G_UNICODE_SPACE_SEPARATOR },
  { 0x0021, 0x0023, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0024, 0x0024, G_UNICODE_CURRENCY_SYMBOL },
  { 0x0025, 0x0027, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0028, 0x0028, G_UNICODE_OPEN_PUNCTUATION },
  { 0x0029, 0x0029, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x002A, 0x002A, G_UNICODE_OTHER_PUNCTUATION },
  { 0x002B, 0x002B, G_UNICODE_MATH_SYMBOL },
  { 0x002C, 0x002C, G_UNICODE_OTHER_PUNCTUATION },
  { 0x002D, 0x002D, G_UNICODE_DASH_PUNCTUATION },
  { 0x002E, 0x002F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0030, 0x0039, G_UNICODE_DECIMAL_NUMBER },
  { 0x003A, 0x003B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x003C, 0x003E, G_UNICODE_MATH_SYMBOL },
  { 0x003F, 0x0040, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0041, 0x005A, G_UNICODE_UPPERCASE_LETTER },
  { 0x005B, 0x005B, G_UNICODE_OPEN_PUNCTUATION },
  { 0x005C, 0x005C, G_UNICODE_OTHER_PUNCTUATION },
  { 0x005D, 0x005D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x005E, 0x005E, G_UNICODE_MODIFIER_SYMBOL },
  { 0x005F, 0x005F, G_UNICODE_CONNECT_PUNCTUATION },
  { 0x0060, 0x0060, G_UNICODE_MODIFIER_SYMBOL },
  { 0x0061, 0x007A, G_UNICODE_LOWERCASE_LETTER },
  { 0x007B, 0x007B, G_UNICODE_OPEN_PUNCTUATION },
  { 0x007C, 0x007C, G_UNICODE_MATH_SYMBOL },
  { 0x007D, 0x007D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x007E, 0x007E, G_UNICODE_MATH_SYMBOL },
  { 0x007F, 0x009F, G_UNICODE_CONTROL },
  { 0x00A0, 0x00A0, G_UNICODE_SPACE_SEPARATOR },
  { 0x00A1, 0x00A1, G_UNICODE_OTHER_PUNCTUATION },
  { 0x00A2, 0x00A5, G_UNICODE_CURRENCY_SYMBOL },
  { 0x00A6, 0x00A6, G_UNICODE_OTHER_SYMBOL },
  { 0x00A7, 0x00A7, G_UNICODE_OTHER_PUNCTUATION },
  { 0x00A8, 0x00A8, G_UNICODE_MODIFIER_SYMBOL },
  { 0x00A9, 0x00A9, G_UNICODE_OTHER_SYMBOL },
  { 0x00AA, 0x00AA, G_UNICODE_OTHER_LETTER },
  { 0x00AB, 0x00AB, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x00AC, 0x00AC, G_UNICODE_MATH_SYMBOL },
  { 0x00AD, 0x00AD, G_UNICODE_FORMAT },
  { 0x00AE, 0x00AE, G_UNICODE_OTHER_SYMBOL },
  { 0x00AF, 0x00AF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x00B0, 0x00B0, G_UNICODE_OTHER_SYMBOL },
  { 0x00B1, 0x00B1, G_UNICODE_MATH_SYMBOL },
  { 0x00B2, 0x00B3, G_UNICODE_OTHER_NUMBER },
  { 0x00B4, 0x00B4, G_UNICODE_MODIFIER_SYMBOL },
  { 0x00B5, 0x00B5, G_UNICODE_LOWERCASE_LETTER },
  { 0x00B6, 0x00B7, G_UNICODE_OTHER_PUNCTUATION },
  { 0x00B8, 0x00B8, G_UNICODE_MODIFIER_SYMBOL },
  { 0x00B9, 0x00B9, G_UNICODE_OTHER_NUMBER },
  { 0x00BA, 0x00BA, G_UNICODE_OTHER_LETTER },
  { 0x00BB, 0x00BB, G_UNICODE_FINAL_PUNCTUATION },
  { 0x00BC, 0x00BE, G_UNICODE_OTHER_NUMBER },
  { 0x00BF, 0x00BF, G_UNICODE_OTHER_PUNCTUATION },
  { 0x00C0, 0x00D6, G_UNICODE_UPPERCASE_LETTER },
  { 0x00D7, 0x00D7, G_UNICODE_MATH_SYMBOL },
  { 0x00D8, 0x00DE, G_UNICODE_UPPERCASE_LETTER },
  { 0x00DF, 0x00F6, G_UNICODE_LOWERCASE_LETTER },
  { 0x00F7, 0x00F7, G_UNICODE_MATH_SYMBOL },
  { 0x00F8, 0x00FF, G_UNICODE_LOWERCASE_LETTER },
  { 0x0100, 0x0100, G_UNICODE_UPPERCASE_LETTER },
  { 0x0101, 0x0101, G_UNICODE_LOWERCASE_LETTER },
  { 0x0102, 0x0102, G_UNICODE_UPPERCASE_LETTER },
  { 0x0103, 0x0103, G_UNICODE_LOWERCASE_LETTER },
  { 0x0104, 0x0104, G_UNICODE_UPPERCASE_LETTER },
  { 0x0105, 0x0105, G_UNICODE_LOWERCASE_LETTER },
  { 0x0106, 0x0106, G_UNICODE_UPPERCASE_LETTER },
  { 0x0107, 0x0107, G_UNICODE_LOWERCASE_LETTER },
  { 0x0108, 0x0108, G_UNICODE_UPPERCASE_LETTER },
  { 0x0109, 0x0109, G_UNICODE_LOWERCASE_LETTER },
  { 0x010A, 0x010A, G_UNICODE_UPPERCASE_LETTER },
  { 0x010B, 0x010B, G_UNICODE_LOWERCASE_LETTER },
  { 0x010C, 0x010C, G_UNICODE_UPPERCASE_LETTER },
  { 0x010D, 0x010D, G_UNICODE_LOWERCASE_LETTER },
  { 0x010E, 0x010E, G_UNICODE_UPPERCASE_LETTER },
  { 0x010F, 0x010F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0110, 0x0110, G_UNICODE_UPPERCASE_LETTER },
  { 0x0111, 0x0111, G_UNICODE_LOWERCASE_LETTER },
  { 0x0112, 0x0112, G_UNICODE_UPPERCASE_LETTER },
  { 0x0113, 0x0113, G_UNICODE_LOWERCASE_LETTER },
  { 0x0114, 0x0114, G_UNICODE_UPPERCASE_LETTER },
  { 0x0115, 0x0115, G_UNICODE_LOWERCASE_LETTER },
  { 0x0116, 0x0116, G_UNICODE_UPPERCASE_LETTER },
  { 0x0117, 0x0117, G_UNICODE_LOWERCASE_LETTER },
  { 0x0118, 0x0118, G_UNICODE_UPPERCASE_LETTER },
  { 0x0119, 0x0119, G_UNICODE_LOWERCASE_LETTER },
  { 0x011A, 0x011A, G_UNICODE_UPPERCASE_LETTER },
  { 0x011B, 0x011B, G_UNICODE_LOWERCASE_LETTER },
  { 0x011C, 0x011C, G_UNICODE_UPPERCASE_LETTER },
  { 0x011D, 0x011D, G_UNICODE_LOWERCASE_LETTER },
  { 0x011E, 0x011E, G_UNICODE_UPPERCASE_LETTER },
  { 0x011F, 0x011F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0120, 0x0120, G_UNICODE_UPPERCASE_LETTER },
  { 0x0121, 0x0121, G_UNICODE_LOWERCASE_LETTER },
  { 0x0122, 0x0122, G_UNICODE_UPPERCASE_LETTER },
  { 0x0123, 0x0123, G_UNICODE_LOWERCASE_LETTER },
  { 0x0124, 0x0124, G_UNICODE_UPPERCASE_LETTER },
  { 0x0125, 0x0125, G_UNICODE_LOWERCASE_LETTER },
  { 0x0126, 0x0126, G_UNICODE_UPPERCASE_LETTER },
  { 0x0127, 0x0127, G_UNICODE_LOWERCASE_LETTER },
  { 0x0128, 0x0128, G_UNICODE_UPPERCASE_LETTER },
  { 0x0129, 0x0129, G_UNICODE_LOWERCASE_LETTER },
  { 0x012A, 0x012A, G_UNICODE_UPPERCASE_LETTER },
  { 0x012B, 0x012B, G_UNICODE_LOWERCASE_LETTER },
  { 0x012C, 0x012C, G_UNICODE_UPPERCASE_LETTER },
  { 0x012D, 0x012D, G_UNICODE_LOWERCASE_LETTER },
  { 0x012E, 0x012E, G_UNICODE_UPPERCASE_LETTER },
  { 0x012F, 0x012F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0130, 0x0130, G_UNICODE_UPPERCASE_LETTER },
  { 0x0131, 0x0131, G_UNICODE_LOWERCASE_LETTER },
  { 0x0132, 0x0132, G_UNICODE_UPPERCASE_LETTER },
  { 0x0133, 0x0133, G_UNICODE_LOWERCASE_LETTER },
  { 0x0134, 0x0134, G_UNICODE_UPPERCASE_LETTER },
  { 0x0135, 0x0135, G_UNICODE_LOWERCASE_LETTER },
  { 0x0136, 0x0136, G_UNICODE_UPPERCASE_LETTER },
  { 0x0137, 0x0138, G_UNICODE_LOWERCASE_LETTER },
  { 0x0139, 0x0139, G_UNICODE_UPPERCASE_LETTER },
  { 0x013A, 0x013A, G_UNICODE_LOWERCASE_LETTER },
  { 0x013B, 0x013B, G_UNICODE_UPPERCASE_LETTER },
  { 0x013C, 0x013C, G_UNICODE_LOWERCASE_LETTER },
  { 0x013D, 0x013D, G_UNICODE_UPPERCASE_LETTER },
  { 0x013E, 0x013E, G_UNICODE_LOWERCASE_LETTER },
  { 0x013F, 0x013F, G_UNICODE_UPPERCASE_LETTER },
  { 0x0140, 0x0140, G_UNICODE_LOWERCASE_LETTER },
  { 0x0141, 0x0141, G_UNICODE_UPPERCASE_LETTER },
  { 0x0142, 0x0142, G_UNICODE_LOWERCASE_LETTER },
  { 0x0143, 0x0143, G_UNICODE_UPPERCASE_LETTER },
  { 0x0144, 0x0144, G_UNICODE_LOWERCASE_LETTER },
  { 0x0145, 0x0145, G_UNICODE_UPPERCASE_LETTER },
  { 0x0146, 0x0146, G_UNICODE_LOWERCASE_LETTER },
  { 0x0147, 0x0147, G_UNICODE_UPPERCASE_LETTER },
  { 0x0148, 0x0149, G_UNICODE_LOWERCASE_LETTER },
  { 0x014A, 0x014A, G_UNICODE_UPPERCASE_LETTER },
  { 0x014B, 0x014B, G_UNICODE_LOWERCASE_LETTER },
  { 0x014C, 0x014C, G_UNICODE_UPPERCASE_LETTER },
  { 0x014D, 0x014D, G_UNICODE_LOWERCASE_LETTER },
  { 0x014E, 0x014E, G_UNICODE_UPPERCASE_LETTER },
  { 0x014F, 0x014F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0150, 0x0150, G_UNICODE_UPPERCASE_LETTER },
  { 0x0151, 0x0151, G_UNICODE_LOWERCASE_LETTER },
  { 0x0152, 0x0152, G_UNICODE_UPPERCASE_LETTER },
  { 0x0153, 0x0153, G_UNICODE_LOWERCASE_LETTER },
  { 0x0154, 0x0154, G_UNICODE_UPPERCASE_LETTER },
  { 0x0155, 0x0155, G_UNICODE_LOWERCASE_LETTER },
  { 0x0156, 0x0156, G_UNICODE_UPPERCASE_LETTER },
  { 0x0157, 0x0157, G_UNICODE_LOWERCASE_LETTER },
  { 0x0158, 0x0158, G_UNICODE_UPPERCASE_LETTER },
  { 0x0159, 0x0159, G_UNICODE_LOWERCASE_LETTER },
  { 0x015A, 0x015A, G_UNICODE_UPPERCASE_LETTER },
  { 0x015B, 0x015B, G_UNICODE_LOWERCASE_LETTER },
  { 0x015C, 0x015C, G_UNICODE_UPPERCASE_LETTER },
  { 0x015D, 0x015D, G_UNICODE_LOWERCASE_LETTER },
  { 0x015E, 0x015E, G_UNICODE_UPPERCASE_LETTER },
  { 0x015F, 0x015F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0160, 0x0160, G_UNICODE_UPPERCASE_LETTER },
  { 0x0161, 0x0161, G_UNICODE_LOWERCASE_LETTER },
  { 0x0162, 0x0162, G_UNICODE_UPPERCASE_LETTER },
  { 0x0163, 0x0163, G_UNICODE_LOWERCASE_LETTER },
  { 0x0164, 0x0164, G_UNICODE_UPPERCASE_LETTER },
  { 0x0165, 0x0165, G_UNICODE_LOWERCASE_LETTER },
  { 0x0166, 0x0166, G_UNICODE_UPPERCASE_LETTER },
  { 0x0167, 0x0167, G_UNICODE_LOWERCASE_LETTER },
  { 0x0168, 0x0168, G_UNICODE_UPPERCASE_LETTER },
  { 0x0169, 0x0169, G_UNICODE_LOWERCASE_LETTER },
  { 0x016A, 0x016A, G_UNICODE_UPPERCASE_LETTER },
  { 0x016B, 0x016B, G_UNICODE_LOWERCASE_LETTER },
  { 0x016C, 0x016C, G_UNICODE_UPPERCASE_LETTER },
  { 0x016D, 0x016D, G_UNICODE_LOWERCASE_LETTER },
  { 0x016E, 0x016E, G_UNICODE_UPPERCASE_LETTER },
  { 0x016F, 0x016F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0170, 0x0170, G_UNICODE_UPPERCASE_LETTER },
  { 0x0171, 0x0171, G_UNICODE_LOWERCASE_LETTER },
  { 0x0172, 0x0172, G_UNICODE_UPPERCASE_LETTER },
  { 0x0173, 0x0173, G_UNICODE_LOWERCASE_LETTER },
  { 0x0174, 0x0174, G_UNICODE_UPPERCASE_LETTER },
  { 0x0175, 0x0175, G_UNICODE_LOWERCASE_LETTER },
  { 0x0176, 0x0176, G_UNICODE_UPPERCASE_LETTER },
  { 0x0177, 0x0177, G_UNICODE_LOWERCASE_LETTER },
  { 0x0178, 0x0179, G_UNICODE_UPPERCASE_LETTER },
  { 0x017A, 0x017A, G_UNICODE_LOWERCASE_LETTER },
  { 0x017B, 0x017B, G_UNICODE_UPPERCASE_LETTER },
  { 0x017C, 0x017C, G_UNICODE_LOWERCASE_LETTER },
  { 0x017D, 0x017D, G_UNICODE_UPPERCASE_LETTER },
  { 0x017E, 0x0180, G_UNICODE_LOWERCASE_LETTER },
  { 0x0181, 0x0182, G_UNICODE_UPPERCASE_LETTER },
  { 0x0183, 0x0183, G_UNICODE_LOWERCASE_LETTER },
  { 0x0184, 0x0184, G_UNICODE_UPPERCASE_LETTER },
  { 0x0185, 0x0185, G_UNICODE_LOWERCASE_LETTER },
  { 0x0186, 0x0187, G_UNICODE_UPPERCASE_LETTER },
  { 0x0188, 0x0188, G_UNICODE_LOWERCASE_LETTER },
  { 0x0189, 0x018B, G_UNICODE_UPPERCASE_LETTER },
  { 0x018C, 0x018D, G_UNICODE_LOWERCASE_LETTER },
  { 0x018E, 0x0191, G_UNICODE_UPPERCASE_LETTER },
  { 0x0192, 0x0192, G_UNICODE_LOWERCASE_LETTER },
  { 0x0193, 0x0194, G_UNICODE_UPPERCASE_LETTER },
  { 0x0195, 0x0195, G_UNICODE_LOWERCASE_LETTER },
  { 0x0196, 0x0198, G_UNICODE_UPPERCASE_LETTER },
  { 0x0199, 0x019B, G_UNICODE_LOWERCASE_LETTER },
  { 0x019C, 0x019D, G_UNICODE_UPPERCASE_LETTER },
  { 0x019E, 0x019E, G_UNICODE_LOWERCASE_LETTER },
  { 0x019F, 0x01A0, G_UNICODE_UPPERCASE_LETTER },
  { 0x01A1, 0x01A1, G_UNICODE_LOWERCASE_LETTER },
  { 0x01A2, 0x01A2, G_UNICODE_UPPERCASE_LETTER },
  { 0x01A3, 0x01A3, G_UNICODE_LOWERCASE_LETTER },
  { 0x01A4, 0x01A4, G_UNICODE_UPPERCASE_LETTER },
  { 0x01A5, 0x01A5, G_UNICODE_LOWERCASE_LETTER },
  { 0x01A6, 0x01A7, G_UNICODE_UPPERCASE_LETTER },
  { 0x01A8, 0x01A8, G_UNICODE_LOWERCASE_LETTER },
  { 0x01A9, 0x01A9, G_UNICODE_UPPERCASE_LETTER },
  { 0x01AA, 0x01AB, G_UNICODE_LOWERCASE_LETTER },
  { 0x01AC, 0x01AC, G_UNICODE_UPPERCASE_LETTER },
  { 0x01AD, 0x01AD, G_UNICODE_LOWERCASE_LETTER },
  { 0x01AE, 0x01AF, G_UNICODE_UPPERCASE_LETTER },
  { 0x01B0, 0x01B0, G_UNICODE_LOWERCASE_LETTER },
  { 0x01B1, 0x01B3, G_UNICODE_UPPERCASE_LETTER },
  { 0x01B4, 0x01B4, G_UNICODE_LOWERCASE_LETTER },
  { 0x01B5, 0x01B5, G_UNICODE_UPPERCASE_LETTER },
  { 0x01B6, 0x01B6, G_UNICODE_LOWERCASE_LETTER },
  { 0x01B7, 0x01B8, G_UNICODE_UPPERCASE_LETTER },
  { 0x01B9, 0x01BA, G_UNICODE_LOWERCASE_LETTER },
  { 0x01BB, 0x01BB, G_UNICODE_OTHER_LETTER },
  { 0x01BC, 0x01BC, G_UNICODE_UPPERCASE_LETTER },
  { 0x01BD, 0x01BF, G_UNICODE_LOWERCASE_LETTER },
  { 0x01C0, 0x01C3, G_UNICODE_OTHER_LETTER },
  { 0x01C4, 0x01C4, G_UNICODE_UPPERCASE_LETTER },
  { 0x01C5, 0x01C5, G_UNICODE_TITLECASE_LETTER },
  { 0x01C6, 0x01C6, G_UNICODE_LOWERCASE_LETTER },
  { 0x01C7, 0x01C7, G_UNICODE_UPPERCASE_LETTER },
  { 0x01C8, 0x01C8, G_UNICODE_TITLECASE_LETTER },
  { 0x01C9, 0x01C9, G_UNICODE_LOWERCASE_LETTER },
  { 0x01CA, 0x01CA, G_UNICODE_UPPERCASE_LETTER },
  { 0x01CB, 0x01CB, G_UNICODE_TITLECASE_LETTER },
  { 0x01CC, 0x01CC, G_UNICODE_LOWERCASE_LETTER },
  { 0x01CD, 0x01CD, G_UNICODE_UPPERCASE_LETTER },
  { 0x01CE, 0x01CE, G_UNICODE_LOWERCASE_LETTER },
  { 0x01CF, 0x01CF, G_UNICODE_UPPERCASE_LETTER },
  { 0x01D0, 0x01D0, G_UNICODE_LOWERCASE_LETTER },
  { 0x01D1, 0x01D1, G_UNICODE_UPPERCASE_LETTER },
  { 0x01D2, 0x01D2, G_UNICODE_LOWERCASE_LETTER },
  { 0x01D3, 0x01D3, G_UNICODE_UPPERCASE_LETTER },
  { 0x01D4, 0x01D4, G_UNICODE_LOWERCASE_LETTER },
  { 0x01D5, 0x01D5, G_UNICODE_UPPERCASE_LETTER },
  { 0x01D6, 0x01D6, G_UNICODE_LOWERCASE_LETTER },
  { 0x01D7, 0x01D7, G_UNICODE_UPPERCASE_LETTER },
  { 0x01D8, 0x01D8, G_UNICODE_LOWERCASE_LETTER },
  { 0x01D9, 0x01D9, G_UNICODE_UPPERCASE_LETTER },
  { 0x01DA, 0x01DA, G_UNICODE_LOWERCASE_LETTER },
  { 0x01DB, 0x01DB, G_UNICODE_UPPERCASE_LETTER },
  { 0x01DC, 0x01DD, G_UNICODE_LOWERCASE_LETTER },
  { 0x01DE, 0x01DE, G_UNICODE_UPPERCASE_LETTER },
  { 0x01DF, 0x01DF, G_UNICODE_LOWERCASE_LETTER },
  { 0x01E0, 0x01E0, G_UNICODE_UPPERCASE_LETTER },
  { 0x01E1, 0x01E1, G_UNICODE_LOWERCASE_LETTER },
  { 0x01E2, 0x01E2, G_UNICODE_UPPERCASE_LETTER },
  { 0x01E3, 0x01E3, G_UNICODE_LOWERCASE_LETTER },
  { 0x01E4, 0x01E4, G_UNICODE_UPPERCASE_LETTER },
  { 0x01E5, 0x01E5, G_UNICODE_LOWERCASE_LETTER },
  { 0x01E6, 0x01E6, G_UNICODE_UPPERCASE_LETTER },
  { 0x01E7, 0x01E7, G_UNICODE_LOWERCASE_LETTER },
  { 0x01E8, 0x01E8, G_UNICODE_UPPERCASE_LETTER },
  { 0x01E9, 0x01E9, G_UNICODE_LOWERCASE_LETTER },
  { 0x01EA, 0x01EA, G_UNICODE_UPPERCASE_LETTER },
  { 0x01EB, 0x01EB, G_UNICODE_LOWERCASE_LETTER },
  { 0x01EC, 0x01EC, G_UNICODE_UPPERCASE_LETTER },
  { 0x01ED, 0x01ED, G_UNICODE_LOWERCASE_LETTER },
  { 0x01EE, 0x01EE, G_UNICODE_UPPERCASE_LETTER },
  { 0x01EF, 0x01F0, G_UNICODE_LOWERCASE_LETTER },
  { 0x01F1, 0x01F1, G_UNICODE_UPPERCASE_LETTER },
  { 0x01F2, 0x01F2, G_UNICODE_TITLECASE_LETTER },
  { 0x01F3, 0x01F3, G_UNICODE_LOWERCASE_LETTER },
  { 0x01F4, 0x01F4, G_UNICODE_UPPERCASE_LETTER },
  { 0x01F5, 0x01F5, G_UNICODE_LOWERCASE_LETTER },
  { 0x01F6, 0x01F8, G_UNICODE_UPPERCASE_LETTER },
  { 0x01F9, 0x01F9, G_UNICODE_LOWERCASE_LETTER },
  { 0x01FA, 0x01FA, G_UNICODE_UPPERCASE_LETTER },
  { 0x01FB, 0x01FB, G_UNICODE_LOWERCASE_LETTER },
  { 0x01FC, 0x01FC, G_UNICODE_UPPERCASE_LETTER },
  { 0x01FD, 0x01FD, G_UNICODE_LOWERCASE_LETTER },
  { 0x01FE, 0x01FE, G_UNICODE_UPPERCASE_LETTER },
  { 0x01FF, 0x01FF, G_UNICODE_LOWERCASE_LETTER },
  { 0x0200, 0x0200, G_UNICODE_UPPERCASE_LETTER },
  { 0x0201, 0x0201, G_UNICODE_LOWERCASE_LETTER },
  { 0x0202, 0x0202, G_UNICODE_UPPERCASE_LETTER },
  { 0x0203, 0x0203, G_UNICODE_LOWERCASE_LETTER },
  { 0x0204, 0x0204, G_UNICODE_UPPERCASE_LETTER },
  { 0x0205, 0x0205, G_UNICODE_LOWERCASE_LETTER },
  { 0x0206, 0x0206, G_UNICODE_UPPERCASE_LETTER },
  { 0x0207, 0x0207, G_UNICODE_LOWERCASE_LETTER },
  { 0x0208, 0x0208, G_UNICODE_UPPERCASE_LETTER },
  { 0x0209, 0x0209, G_UNICODE_LOWERCASE_LETTER },
  { 0x020A, 0x020A, G_UNICODE_UPPERCASE_LETTER },
  { 0x020B, 0x020B, G_UNICODE_LOWERCASE_LETTER },
  { 0x020C, 0x020C, G_UNICODE_UPPERCASE_LETTER },
  { 0x020D, 0x020D, G_UNICODE_LOWERCASE_LETTER },
  { 0x020E, 0x020E, G_UNICODE_UPPERCASE_LETTER },
  { 0x020F, 0x020F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0210, 0x0210, G_UNICODE_UPPERCASE_LETTER },
  { 0x0211, 0x0211, G_UNICODE_LOWERCASE_LETTER },
  { 0x0212, 0x0212, G_UNICODE_UPPERCASE_LETTER },
  { 0x0213, 0x0213, G_UNICODE_LOWERCASE_LETTER },
  { 0x0214, 0x0214, G_UNICODE_UPPERCASE_LETTER },
  { 0x0215, 0x0215, G_UNICODE_LOWERCASE_LETTER },
  { 0x0216, 0x0216, G_UNICODE_UPPERCASE_LETTER },
  { 0x0217, 0x0217, G_UNICODE_LOWERCASE_LETTER },
  { 0x0218, 0x0218, G_UNICODE_UPPERCASE_LETTER },
  { 0x0219, 0x0219, G_UNICODE_LOWERCASE_LETTER },
  { 0x021A, 0x021A, G_UNICODE_UPPERCASE_LETTER },
  { 0x021B, 0x021B, G_UNICODE_LOWERCASE_LETTER },
  { 0x021C, 0x021C, G_UNICODE_UPPERCASE_LETTER },
  { 0x021D, 0x021D, G_UNICODE_LOWERCASE_LETTER },
  { 0x021E, 0x021E, G_UNICODE_UPPERCASE_LETTER },
  { 0x021F, 0x021F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0220, 0x0220, G_UNICODE_UPPERCASE_LETTER },
  { 0x0221, 0x0221, G_UNICODE_LOWERCASE_LETTER },
  { 0x0222, 0x0222, G_UNICODE_UPPERCASE_LETTER },
  { 0x0223, 0x0223, G_UNICODE_LOWERCASE_LETTER },
  { 0x0224, 0x0224, G_UNICODE_UPPERCASE_LETTER },
  { 0x0225, 0x0225, G_UNICODE_LOWERCASE_LETTER },
  { 0x0226, 0x0226, G_UNICODE_UPPERCASE_LETTER },
  { 0x0227, 0x0227, G_UNICODE_LOWERCASE_LETTER },
  { 0x0228, 0x0228, G_UNICODE_UPPERCASE_LETTER },
  { 0x0229, 0x0229, G_UNICODE_LOWERCASE_LETTER },
  { 0x022A, 0x022A, G_UNICODE_UPPERCASE_LETTER },
  { 0x022B, 0x022B, G_UNICODE_LOWERCASE_LETTER },
  { 0x022C, 0x022C, G_UNICODE_UPPERCASE_LETTER },
  { 0x022D, 0x022D, G_UNICODE_LOWERCASE_LETTER },
  { 0x022E, 0x022E, G_UNICODE_UPPERCASE_LETTER },
  { 0x022F, 0x022F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0230, 0x0230, G_UNICODE_UPPERCASE_LETTER },
  { 0x0231, 0x0231, G_UNICODE_LOWERCASE_LETTER },
  { 0x0232, 0x0232, G_UNICODE_UPPERCASE_LETTER },
  { 0x0233, 0x0239, G_UNICODE_LOWERCASE_LETTER },
  { 0x023A, 0x023B, G_UNICODE_UPPERCASE_LETTER },
  { 0x023C, 0x023C, G_UNICODE_LOWERCASE_LETTER },
  { 0x023D, 0x023E, G_UNICODE_UPPERCASE_LETTER },
  { 0x023F, 0x0240, G_UNICODE_LOWERCASE_LETTER },
  { 0x0241, 0x0241, G_UNICODE_UPPERCASE_LETTER },
  { 0x0242, 0x0242, G_UNICODE_LOWERCASE_LETTER },
  { 0x0243, 0x0246, G_UNICODE_UPPERCASE_LETTER },
  { 0x0247, 0x0247, G_UNICODE_LOWERCASE_LETTER },
  { 0x0248, 0x0248, G_UNICODE_UPPERCASE_LETTER },
  { 0x0249, 0x0249, G_UNICODE_LOWERCASE_LETTER },
  { 0x024A, 0x024A, G_UNICODE_UPPERCASE_LETTER },
  { 0x024B, 0x024B, G_UNICODE_LOWERCASE_LETTER },
  { 0x024C, 0x024C, G_UNICODE_UPPERCASE_LETTER },
  { 0x024D, 0x024D, G_UNICODE_LOWERCASE_LETTER },
  { 0x024E, 0x024E, G_UNICODE_UPPERCASE_LETTER },
  { 0x024F, 0x0293, G_UNICODE_LOWERCASE_LETTER },
  { 0x0294, 0x0294, G_UNICODE_OTHER_LETTER },
  { 0x0295, 0x02AF, G_UNICODE_LOWERCASE_LETTER },
  { 0x02B0, 0x02C1, G_UNICODE_MODIFIER_LETTER },
  { 0x02C2, 0x02C5, G_UNICODE_MODIFIER_SYMBOL },
  { 0x02C6, 0x02D1, G_UNICODE_MODIFIER_LETTER },
  { 0x02D2, 0x02DF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x02E0, 0x02E4, G_UNICODE_MODIFIER_LETTER },
  { 0x02E5, 0x02EB, G_UNICODE_MODIFIER_SYMBOL },
  { 0x02EC, 0x02EC, G_UNICODE_MODIFIER_LETTER },
  { 0x02ED, 0x02ED, G_UNICODE_MODIFIER_SYMBOL },
  { 0x02EE, 0x02EE, G_UNICODE_MODIFIER_LETTER },
  { 0x02EF, 0x02FF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x0300, 0x036F, G_UNICODE_NON_SPACING_MARK },
  { 0x0370, 0x0370, G_UNICODE_UPPERCASE_LETTER },
  { 0x0371, 0x0371, G_UNICODE_LOWERCASE_LETTER },
  { 0x0372, 0x0372, G_UNICODE_UPPERCASE_LETTER },
  { 0x0373, 0x0373, G_UNICODE_LOWERCASE_LETTER },
  { 0x0374, 0x0374, G_UNICODE_MODIFIER_LETTER },
  { 0x0375, 0x0375, G_UNICODE_MODIFIER_SYMBOL },
  { 0x0376, 0x0376, G_UNICODE_UPPERCASE_LETTER },
  { 0x0377, 0x0377, G_UNICODE_LOWERCASE_LETTER },
  { 0x037A, 0x037A, G_UNICODE_MODIFIER_LETTER },
  { 0x037B, 0x037D, G_UNICODE_LOWERCASE_LETTER },
  { 0x037E, 0x037E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x037F, 0x037F, G_UNICODE_UPPERCASE_LETTER },
  { 0x0384, 0x0385, G_UNICODE_MODIFIER_SYMBOL },
  { 0x0386, 0x0386, G_UNICODE_UPPERCASE_LETTER },
  { 0x0387, 0x0387, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0388, 0x038A, G_UNICODE_UPPERCASE_LETTER },
  { 0x038C, 0x038C, G_UNICODE_UPPERCASE_LETTER },
  { 0x038E, 0x038F, G_UNICODE_UPPERCASE_LETTER },
  { 0x0390, 0x0390, G_UNICODE_LOWERCASE_LETTER },
  { 0x0391, 0x03A1, G_UNICODE_UPPERCASE_LETTER },
  { 0x03A3, 0x03AB, G_UNICODE_UPPERCASE_LETTER },
  { 0x03AC, 0x03CE, G_UNICODE_LOWERCASE_LETTER },
  { 0x03CF, 0x03CF, G_UNICODE_UPPERCASE_LETTER },
  { 0x03D0, 0x03D1, G_UNICODE_LOWERCASE_LETTER },
  { 0x03D2, 0x03D4, G_UNICODE_UPPERCASE_LETTER },
  { 0x03D5, 0x03D7, G_UNICODE_LOWERCASE_LETTER },
  { 0x03D8, 0x03D8, G_UNICODE_UPPERCASE_LETTER },
  { 0x03D9, 0x03D9, G_UNICODE_LOWERCASE_LETTER },
  { 0x03DA, 0x03DA, G_UNICODE_UPPERCASE_LETTER },
  { 0x03DB, 0x03DB, G_UNICODE_LOWERCASE_LETTER },
  { 0x03DC, 0x03DC, G_UNICODE_UPPERCASE_LETTER },
  { 0x03DD, 0x03DD, G_UNICODE_LOWERCASE_LETTER },
  { 0x03DE, 0x03DE, G_UNICODE_UPPERCASE_LETTER },
  { 0x03DF, 0x03DF, G_UNICODE_LOWERCASE_LETTER },
  { 0x03E0, 0x03E0, G_UNICODE_UPPERCASE_LETTER },
  { 0x03E1, 0x03E1, G_UNICODE_LOWERCASE_LETTER },
  { 0x03E2, 0x03E2, G_UNICODE_UPPERCASE_LETTER },
  { 0x03E3, 0x03E3, G_UNICODE_LOWERCASE_LETTER },
  { 0x03E4, 0x03E4, G_UNICODE_UPPERCASE_LETTER },
  { 0x03E5, 0x03E5, G_UNICODE_LOWERCASE_LETTER },
  { 0x03E6, 0x03E6, G_UNICODE_UPPERCASE_LETTER },
  { 0x03E7, 0x03E7, G_UNICODE_LOWERCASE_LETTER },
  { 0x03E8, 0x03E8, G_UNICODE_UPPERCASE_LETTER },
  { 0x03E9, 0x03E9, G_UNICODE_LOWERCASE_LETTER },
  { 0x03EA, 0x03EA, G_UNICODE_UPPERCASE_LETTER },
  { 0x03EB, 0x03EB, G_UNICODE_LOWERCASE_LETTER },
  { 0x03EC, 0x03EC, G_UNICODE_UPPERCASE_LETTER },
  { 0x03ED, 0x03ED, G_UNICODE_LOWERCASE_LETTER },
  { 0x03EE, 0x03EE, G_UNICODE_UPPERCASE_LETTER },
  { 0x03EF, 0x03F3, G_UNICODE_LOWERCASE_LETTER },
  { 0x03F4, 0x03F4, G_UNICODE_UPPERCASE_LETTER },
  { 0x03F5, 0x03F5, G_UNICODE_LOWERCASE_LETTER },
  { 0x03F6, 0x03F6, G_UNICODE_MATH_SYMBOL },
  { 0x03F7, 0x03F7, G_UNICODE_UPPERCASE_LETTER },
  { 0x03F8, 0x03F8, G_UNICODE_LOWERCASE_LETTER },
  { 0x03F9, 0x03FA, G_UNICODE_UPPERCASE_LETTER },
  { 0x03FB, 0x03FC, G_UNICODE_LOWERCASE_LETTER },
  { 0x03FD, 0x042F, G_UNICODE_UPPERCASE_LETTER },
  { 0x0430, 0x045F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0460, 0x0460, G_UNICODE_UPPERCASE_LETTER },
  { 0x0461, 0x0461, G_UNICODE_LOWERCASE_LETTER },
  { 0x0462, 0x0462, G_UNICODE_UPPERCASE_LETTER },
  { 0x0463, 0x0463, G_UNICODE_LOWERCASE_LETTER },
  { 0x0464, 0x0464, G_UNICODE_UPPERCASE_LETTER },
  { 0x0465, 0x0465, G_UNICODE_LOWERCASE_LETTER },
  { 0x0466, 0x0466, G_UNICODE_UPPERCASE_LETTER },
  { 0x0467, 0x0467, G_UNICODE_LOWERCASE_LETTER },
  { 0x0468, 0x0468, G_UNICODE_UPPERCASE_LETTER },
  { 0x0469, 0x0469, G_UNICODE_LOWERCASE_LETTER },
  { 0x046A, 0x046A, G_UNICODE_UPPERCASE_LETTER },
  { 0x046B, 0x046B, G_UNICODE_LOWERCASE_LETTER },
  { 0x046C, 0x046C, G_UNICODE_UPPERCASE_LETTER },
  { 0x046D, 0x046D, G_UNICODE_LOWERCASE_LETTER },
  { 0x046E, 0x046E, G_UNICODE_UPPERCASE_LETTER },
  { 0x046F, 0x046F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0470, 0x0470, G_UNICODE_UPPERCASE_LETTER },
  { 0x0471, 0x0471, G_UNICODE_LOWERCASE_LETTER },
  { 0x0472, 0x0472, G_UNICODE_UPPERCASE_LETTER },
  { 0x0473, 0x0473, G_UNICODE_LOWERCASE_LETTER },
  { 0x0474, 0x0474, G_UNICODE_UPPERCASE_LETTER },
  { 0x0475, 0x0475, G_UNICODE_LOWERCASE_LETTER },
  { 0x0476, 0x0476, G_UNICODE_UPPERCASE_LETTER },
  { 0x0477, 0x0477, G_UNICODE_LOWERCASE_LETTER },
  { 0x0478, 0x0478, G_UNICODE_UPPERCASE_LETTER },
  { 0x0479, 0x0479, G_UNICODE_LOWERCASE_LETTER },
  { 0x047A, 0x047A, G_UNICODE_UPPERCASE_LETTER },
  { 0x047B, 0x047B, G_UNICODE_LOWERCASE_LETTER },
  { 0x047C, 0x047C, G_UNICODE_UPPERCASE_LETTER },
  { 0x047D, 0x047D, G_UNICODE_LOWERCASE_LETTER },
  { 0x047E, 0x047E, G_UNICODE_UPPERCASE_LETTER },
  { 0x047F, 0x047F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0480, 0x0480, G_UNICODE_UPPERCASE_LETTER },
  { 0x0481, 0x0481, G_UNICODE_LOWERCASE_LETTER },
  { 0x0482, 0x0482, G_UNICODE_OTHER_SYMBOL },
  { 0x0483, 0x0487, G_UNICODE_NON_SPACING_MARK },
  { 0x0488, 0x0489, G_UNICODE_ENCLOSING_MARK },
  { 0x048A, 0x048A, G_UNICODE_UPPERCASE_LETTER },
  { 0x048B, 0x048B, G_UNICODE_LOWERCASE_LETTER },
  { 0x048C, 0x048C, G_UNICODE_UPPERCASE_LETTER },
  { 0x048D, 0x048D, G_UNICODE_LOWERCASE_LETTER },
  { 0x048E, 0x048E, G_UNICODE_UPPERCASE_LETTER },
  { 0x048F, 0x048F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0490, 0x0490, G_UNICODE_UPPERCASE_LETTER },
  { 0x0491, 0x0491, G_UNICODE_LOWERCASE_LETTER },
  { 0x0492, 0x0492, G_UNICODE_UPPERCASE_LETTER },
  { 0x0493, 0x0493, G_UNICODE_LOWERCASE_LETTER },
  { 0x0494, 0x0494, G_UNICODE_UPPERCASE_LETTER },
  { 0x0495, 0x0495, G_UNICODE_LOWERCASE_LETTER },
  { 0x0496, 0x0496, G_UNICODE_UPPERCASE_LETTER },
  { 0x0497, 0x0497, G_UNICODE_LOWERCASE_LETTER },
  { 0x0498, 0x0498, G_UNICODE_UPPERCASE_LETTER },
  { 0x0499, 0x0499, G_UNICODE_LOWERCASE_LETTER },
  { 0x049A, 0x049A, G_UNICODE_UPPERCASE_LETTER },
  { 0x049B, 0x049B, G_UNICODE_LOWERCASE_LETTER },
  { 0x049C, 0x049C, G_UNICODE_UPPERCASE_LETTER },
  { 0x049D, 0x049D, G_UNICODE_LOWERCASE_LETTER },
  { 0x049E, 0x049E, G_UNICODE_UPPERCASE_LETTER },
  { 0x049F, 0x049F, G_UNICODE_LOWERCASE_LETTER },
  { 0x04A0, 0x04A0, G_UNICODE_UPPERCASE_LETTER },
  { 0x04A1, 0x04A1, G_UNICODE_LOWERCASE_LETTER },
  { 0x04A2, 0x04A2, G_UNICODE_UPPERCASE_LETTER },
  { 0x04A3, 0x04A3, G_UNICODE_LOWERCASE_LETTER },
  { 0x04A4, 0x04A4, G_UNICODE_UPPERCASE_LETTER },
  { 0x04A5, 0x04A5, G_UNICODE_LOWERCASE_LETTER },
  { 0x04A6, 0x04A6, G_UNICODE_UPPERCASE_LETTER },
  { 0x04A7, 0x04A7, G_UNICODE_LOWERCASE_LETTER },
  { 0x04A8, 0x04A8, G_UNICODE_UPPERCASE_LETTER },
  { 0x04A9, 0x04A9, G_UNICODE_LOWERCASE_LETTER },
  { 0x04AA, 0x04AA, G_UNICODE_UPPERCASE_LETTER },
  { 0x04AB, 0x04AB, G_UNICODE_LOWERCASE_LETTER },
  { 0x04AC, 0x04AC, G_UNICODE_UPPERCASE_LETTER },
  { 0x04AD, 0x04AD, G_UNICODE_LOWERCASE_LETTER },
  { 0x04AE, 0x04AE, G_UNICODE_UPPERCASE_LETTER },
  { 0x04AF, 0x04AF, G_UNICODE_LOWERCASE_LETTER },
  { 0x04B0, 0x04B0, G_UNICODE_UPPERCASE_LETTER },
  { 0x04B1, 0x04B1, G_UNICODE_LOWERCASE_LETTER },
  { 0x04B2, 0x04B2, G_UNICODE_UPPERCASE_LETTER },
  { 0x04B3, 0x04B3, G_UNICODE_LOWERCASE_LETTER },
  { 0x04B4, 0x04B4, G_UNICODE_UPPERCASE_LETTER },
  { 0x04B5, 0x04B5, G_UNICODE_LOWERCASE_LETTER },
  { 0x04B6, 0x04B6, G_UNICODE_UPPERCASE_LETTER },
  { 0x04B7, 0x04B7, G_UNICODE_LOWERCASE_LETTER },
  { 0x04B8, 0x04B8, G_UNICODE_UPPERCASE_LETTER },
  { 0x04B9, 0x04B9, G_UNICODE_LOWERCASE_LETTER },
  { 0x04BA, 0x04BA, G_UNICODE_UPPERCASE_LETTER },
  { 0x04BB, 0x04BB, G_UNICODE_LOWERCASE_LETTER },
  { 0x04BC, 0x04BC, G_UNICODE_UPPERCASE_LETTER },
  { 0x04BD, 0x04BD, G_UNICODE_LOWERCASE_LETTER },
  { 0x04BE, 0x04BE, G_UNICODE_UPPERCASE_LETTER },
  { 0x04BF, 0x04BF, G_UNICODE_LOWERCASE_LETTER },
  { 0x04C0, 0x04C1, G_UNICODE_UPPERCASE_LETTER },
  { 0x04C2, 0x04C2, G_UNICODE_LOWERCASE_LETTER },
  { 0x04C3, 0x04C3, G_UNICODE_UPPERCASE_LETTER },
  { 0x04C4, 0x04C4, G_UNICODE_LOWERCASE_LETTER },
  { 0x04C5, 0x04C5, G_UNICODE_UPPERCASE_LETTER },
  { 0x04C6, 0x04C6, G_UNICODE_LOWERCASE_LETTER },
  { 0x04C7, 0x04C7, G_UNICODE_UPPERCASE_LETTER },
  { 0x04C8, 0x04C8, G_UNICODE_LOWERCASE_LETTER },
  { 0x04C9, 0x04C9, G_UNICODE_UPPERCASE_LETTER },
  { 0x04CA, 0x04CA, G_UNICODE_LOWERCASE_LETTER },
  { 0x04CB, 0x04CB, G_UNICODE_UPPERCASE_LETTER },
  { 0x04CC, 0x04CC, G_UNICODE_LOWERCASE_LETTER },
  { 0x04CD, 0x04CD, G_UNICODE_UPPERCASE_LETTER },
  { 0x04CE, 0x04CF, G_UNICODE_LOWERCASE_LETTER },
  { 0x04D0, 0x04D0, G_UNICODE_UPPERCASE_LETTER },
  { 0x04D1, 0x04D1, G_UNICODE_LOWERCASE_LETTER },
  { 0x04D2, 0x04D2, G_UNICODE_UPPERCASE_LETTER },
  { 0x04D3, 0x04D3, G_UNICODE_LOWERCASE_LETTER },
  { 0x04D4, 0x04D4, G_UNICODE_UPPERCASE_LETTER },
  { 0x04D5, 0x04D5, G_UNICODE_LOWERCASE_LETTER },
  { 0x04D6, 0x04D6, G_UNICODE_UPPERCASE_LETTER },
  { 0x04D7, 0x04D7, G_UNICODE_LOWERCASE_LETTER },
  { 0x04D8, 0x04D8, G_UNICODE_UPPERCASE_LETTER },
  { 0x04D9, 0x04D9, G_UNICODE_LOWERCASE_LETTER },
  { 0x04DA, 0x04DA, G_UNICODE_UPPERCASE_LETTER },
  { 0x04DB, 0x04DB, G_UNICODE_LOWERCASE_LETTER },
  { 0x04DC, 0x04DC, G_UNICODE_UPPERCASE_LETTER },
  { 0x04DD, 0x04DD, G_UNICODE_LOWERCASE_LETTER },
  { 0x04DE, 0x04DE, G_UNICODE_UPPERCASE_LETTER },
  { 0x04DF, 0x04DF, G_UNICODE_LOWERCASE_LETTER },
  { 0x04E0, 0x04E0, G_UNICODE_UPPERCASE_LETTER },
  { 0x04E1, 0x04E1, G_UNICODE_LOWERCASE_LETTER },
  { 0x04E2, 0x04E2, G_UNICODE_UPPERCASE_LETTER },
  { 0x04E3, 0x04E3, G_UNICODE_LOWERCASE_LETTER },
  { 0x04E4, 0x04E4, G_UNICODE_UPPERCASE_LETTER },
  { 0x04E5, 0x04E5, G_UNICODE_LOWERCASE_LETTER },
  { 0x04E6, 0x04E6, G_UNICODE_UPPERCASE_LETTER },
  { 0x04E7, 0x04E7, G_UNICODE_LOWERCASE_LETTER },
  { 0x04E8, 0x04E8, G_UNICODE_UPPERCASE_LETTER },
  { 0x04E9, 0x04E9, G_UNICODE_LOWERCASE_LETTER },
  { 0x04EA, 0x04EA, G_UNICODE_UPPERCASE_LETTER },
  { 0x04EB, 0x04EB, G_UNICODE_LOWERCASE_LETTER },
  { 0x04EC, 0x04EC, G_UNICODE_UPPERCASE_LETTER },
  { 0x04ED, 0x04ED, G_UNICODE_LOWERCASE_LETTER },
  { 0x04EE, 0x04EE, G_UNICODE_UPPERCASE_LETTER },
  { 0x04EF, 0x04EF, G_UNICODE_LOWERCASE_LETTER },
  { 0x04F0, 0x04F0, G_UNICODE_UPPERCASE_LETTER },
  { 0x04F1, 0x04F1, G_UNICODE_LOWERCASE_LETTER },
  { 0x04F2, 0x04F2, G_UNICODE_UPPERCASE_LETTER },
  { 0x04F3, 0x04F3, G_UNICODE_LOWERCASE_LETTER },
  { 0x04F4, 0x04F4, G_UNICODE_UPPERCASE_LETTER },
  { 0x04F5, 0x04F5, G_UNICODE_LOWERCASE_LETTER },
  { 0x04F6, 0x04F6, G_UNICODE_UPPERCASE_LETTER },
  { 0x04F7, 0x04F7, G_UNICODE_LOWERCASE_LETTER },
  { 0x04F8, 0x04F8, G_UNICODE_UPPERCASE_LETTER },
  { 0x04F9, 0x04F9, G_UNICODE_LOWERCASE_LETTER },
  { 0x04FA, 0x04FA, G_UNICODE_UPPERCASE_LETTER },
  { 0x04FB, 0x04FB, G_UNICODE_LOWERCASE_LETTER },
  { 0x04FC, 0x04FC, G_UNICODE_UPPERCASE_LETTER },
  { 0x04FD, 0x04FD, G_UNICODE_LOWERCASE_LETTER },
  { 0x04FE, 0x04FE, G_UNICODE_UPPERCASE_LETTER },
  { 0x04FF, 0x04FF, G_UNICODE_LOWERCASE_LETTER },
  { 0x0500, 0x0500, G_UNICODE_UPPERCASE_LETTER },
  { 0x0501, 0x0501, G_UNICODE_LOWERCASE_LETTER },
  { 0x0502, 0x0502, G_UNICODE_UPPERCASE_LETTER },
  { 0x0503, 0x0503, G_UNICODE_LOWERCASE_LETTER },
  { 0x0504, 0x0504, G_UNICODE_UPPERCASE_LETTER },
  { 0x0505, 0x0505, G_UNICODE_LOWERCASE_LETTER },
  { 0x0506, 0x0506, G_UNICODE_UPPERCASE_LETTER },
  { 0x0507, 0x0507, G_UNICODE_LOWERCASE_LETTER },
  { 0x0508, 0x0508, G_UNICODE_UPPERCASE_LETTER },
  { 0x0509, 0x0509, G_UNICODE_LOWERCASE_LETTER },
  { 0x050A, 0x050A, G_UNICODE_UPPERCASE_LETTER },
  { 0x050B, 0x050B, G_UNICODE_LOWERCASE_LETTER },
  { 0x050C, 0x050C, G_UNICODE_UPPERCASE_LETTER },
  { 0x050D, 0x050D, G_UNICODE_LOWERCASE_LETTER },
  { 0x050E, 0x050E, G_UNICODE_UPPERCASE_LETTER },
  { 0x050F, 0x050F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0510, 0x0510, G_UNICODE_UPPERCASE_LETTER },
  { 0x0511, 0x0511, G_UNICODE_LOWERCASE_LETTER },
  { 0x0512, 0x0512, G_UNICODE_UPPERCASE_LETTER },
  { 0x0513, 0x0513, G_UNICODE_LOWERCASE_LETTER },
  { 0x0514, 0x0514, G_UNICODE_UPPERCASE_LETTER },
  { 0x0515, 0x0515, G_UNICODE_LOWERCASE_LETTER },
  { 0x0516, 0x0516, G_UNICODE_UPPERCASE_LETTER },
  { 0x0517, 0x0517, G_UNICODE_LOWERCASE_LETTER },
  { 0x0518, 0x0518, G_UNICODE_UPPERCASE_LETTER },
  { 0x0519, 0x0519, G_UNICODE_LOWERCASE_LETTER },
  { 0x051A, 0x051A, G_UNICODE_UPPERCASE_LETTER },
  { 0x051B, 0x051B, G_UNICODE_LOWERCASE_LETTER },
  { 0x051C, 0x051C, G_UNICODE_UPPERCASE_LETTER },
  { 0x051D, 0x051D, G_UNICODE_LOWERCASE_LETTER },
  { 0x051E, 0x051E, G_UNICODE_UPPERCASE_LETTER },
  { 0x051F, 0x051F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0520, 0x0520, G_UNICODE_UPPERCASE_LETTER },
  { 0x0521, 0x0521, G_UNICODE_LOWERCASE_LETTER },
  { 0x0522, 0x0522, G_UNICODE_UPPERCASE_LETTER },
  { 0x0523, 0x0523, G_UNICODE_LOWERCASE_LETTER },
  { 0x0524, 0x0524, G_UNICODE_UPPERCASE_LETTER },
  { 0x0525, 0x0525, G_UNICODE_LOWERCASE_LETTER },
  { 0x0526, 0x0526, G_UNICODE_UPPERCASE_LETTER },
  { 0x0527, 0x0527, G_UNICODE_LOWERCASE_LETTER },
  { 0x0528, 0x0528, G_UNICODE_UPPERCASE_LETTER },
  { 0x0529, 0x0529, G_UNICODE_LOWERCASE_LETTER },
  { 0x052A, 0x052A, G_UNICODE_UPPERCASE_LETTER },
  { 0x052B, 0x052B, G_UNICODE_LOWERCASE_LETTER },
  { 0x052C, 0x052C, G_UNICODE_UPPERCASE_LETTER },
  { 0x052D, 0x052D, G_UNICODE_LOWERCASE_LETTER },
  { 0x052E, 0x052E, G_UNICODE_UPPERCASE_LETTER },
  { 0x052F, 0x052F, G_UNICODE_LOWERCASE_LETTER },
  { 0x0531, 0x0556, G_UNICODE_UPPERCASE_LETTER },
  { 0x0559, 0x0559, G_UNICODE_MODIFIER_LETTER },
  { 0x055A, 0x055F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0560, 0x0588, G_UNICODE_LOWERCASE_LETTER },
  { 0x0589, 0x0589, G_UNICODE_OTHER_PUNCTUATION },
  { 0x058A, 0x058A, G_UNICODE_DASH_PUNCTUATION },
  { 0x058D, 0x058E, G_UNICODE_OTHER_SYMBOL },
  { 0x058F, 0x058F, G_UNICODE_CURRENCY_SYMBOL },
  { 0x0591, 0x05BD, G_UNICODE_NON_SPACING_MARK },
  { 0x05BE, 0x05BE, G_UNICODE_DASH_PUNCTUATION },
  { 0x05BF, 0x05BF, G_UNICODE_NON_SPACING_MARK },
  { 0x05C0, 0x05C0, G_UNICODE_OTHER_PUNCTUATION },
  { 0x05C1, 0x05C2, G_UNICODE_NON_SPACING_MARK },
  { 0x05C3, 0x05C3, G_UNICODE_OTHER_PUNCTUATION },
  { 0x05C4, 0x05C5, G_UNICODE_NON_SPACING_MARK },
  { 0x05C6, 0x05C6, G_UNICODE_OTHER_PUNCTUATION },
  { 0x05C7, 0x05C7, G_UNICODE_NON_SPACING_MARK },
  { 0x05D0, 0x05EA, G_UNICODE_OTHER_LETTER },
  { 0x05EF, 0x05F2, G_UNICODE_OTHER_LETTER },
  { 0x05F3, 0x05F4, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0600, 0x0605, G_UNICODE_FORMAT },
  { 0x0606, 0x0608, G_UNICODE_MATH_SYMBOL },
  { 0x0609, 0x060A, G_UNICODE_OTHER_PUNCTUATION },
  { 0x060B, 0x060B, G_UNICODE_CURRENCY_SYMBOL },
  { 0x060C, 0x060D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x060E, 0x060F, G_UNICODE_OTHER_SYMBOL },
  { 0x0610, 0x061A, G_UNICODE_NON_SPACING_MARK },
  { 0x061B, 0x061B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x061C, 0x061C, G_UNICODE_FORMAT },
  { 0x061D, 0x061F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0620, 0x063F, G_UNICODE_OTHER_LETTER },
  { 0x0640, 0x0640, G_UNICODE_MODIFIER_LETTER },
  { 0x0641, 0x064A, G_UNICODE_OTHER_LETTER },
  { 0x064B, 0x065F, G_UNICODE_NON_SPACING_MARK },
  { 0x0660, 0x0669, G_UNICODE_DECIMAL_NUMBER },
  { 0x066A, 0x066D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x066E, 0x066F, G_UNICODE_OTHER_LETTER },
  { 0x0670, 0x0670, G_UNICODE_NON_SPACING_MARK },
  { 0x0671, 0x06D3, G_UNICODE_OTHER_LETTER },
  { 0x06D4, 0x06D4, G_UNICODE_OTHER_PUNCTUATION },
  { 0x06D5, 0x06D5, G_UNICODE_OTHER_LETTER },
  { 0x06D6, 0x06DC, G_UNICODE_NON_SPACING_MARK },
  { 0x06DD, 0x06DD, G_UNICODE_FORMAT },
  { 0x06DE, 0x06DE, G_UNICODE_OTHER_SYMBOL },
  { 0x06DF, 0x06E4, G_UNICODE_NON_SPACING_MARK },
  { 0x06E5, 0x06E6, G_UNICODE_MODIFIER_LETTER },
  { 0x06E7, 0x06E8, G_UNICODE_NON_SPACING_MARK },
  { 0x06E9, 0x06E9, G_UNICODE_OTHER_SYMBOL },
  { 0x06EA, 0x06ED, G_UNICODE_NON_SPACING_MARK },
  { 0x06EE, 0x06EF, G_UNICODE_OTHER_LETTER },
  { 0x06F0, 0x06F9, G_UNICODE_DECIMAL_NUMBER },
  { 0x06FA, 0x06FC, G_UNICODE_OTHER_LETTER },
  { 0x06FD, 0x06FE, G_UNICODE_OTHER_SYMBOL },
  { 0x06FF, 0x06FF, G_UNICODE_OTHER_LETTER },
  { 0x0700, 0x070D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x070F, 0x070F, G_UNICODE_FORMAT },
  { 0x0710, 0x0710, G_UNICODE_OTHER_LETTER },
  { 0x0711, 0x0711, G_UNICODE_NON_SPACING_MARK },
  { 0x0712, 0x072F, G_UNICODE_OTHER_LETTER },
  { 0x0730, 0x074A, G_UNICODE_NON_SPACING_MARK },
  { 0x074D, 0x07A5, G_UNICODE_OTHER_LETTER },
  { 0x07A6, 0x07B0, G_UNICODE_NON_SPACING_MARK },
  { 0x07B1, 0x07B1, G_UNICODE_OTHER_LETTER },
  { 0x07C0, 0x07C9, G_UNICODE_DECIMAL_NUMBER },
  { 0x07CA, 0x07EA, G_UNICODE_OTHER_LETTER },
  { 0x07EB, 0x07F3, G_UNICODE_NON_SPACING_MARK },
  { 0x07F4, 0x07F5, G_UNICODE_MODIFIER_LETTER },
  { 0x07F6, 0x07F6, G_UNICODE_OTHER_SYMBOL },
  { 0x07F7, 0x07F9, G_UNICODE_OTHER_PUNCTUATION },
  { 0x07FA, 0x07FA, G_UNICODE_MODIFIER_LETTER },
  { 0x07FD, 0x07FD, G_UNICODE_NON_SPACING_MARK },
  { 0x07FE, 0x07FF, G_UNICODE_CURRENCY_SYMBOL },
  { 0x0800, 0x0815, G_UNICODE_OTHER_LETTER },
  { 0x0816, 0x0819, G_UNICODE_NON_SPACING_MARK },
  { 0x081A, 0x081A, G_UNICODE_MODIFIER_LETTER },
  { 0x081B, 0x0823, G_UNICODE_NON_SPACING_MARK },
  { 0x0824, 0x0824, G_UNICODE_MODIFIER_LETTER },
  { 0x0825, 0x0827, G_UNICODE_NON_SPACING_MARK },
  { 0x0828, 0x0828, G_UNICODE_MODIFIER_LETTER },
  { 0x0829, 0x082D, G_UNICODE_NON_SPACING_MARK },
  { 0x0830, 0x083E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0840, 0x0858, G_UNICODE_OTHER_LETTER },
  { 0x0859, 0x085B, G_UNICODE_NON_SPACING_MARK },
  { 0x085E, 0x085E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0860, 0x086A, G_UNICODE_OTHER_LETTER },
  { 0x0870, 0x0887, G_UNICODE_OTHER_LETTER },
  { 0x0888, 0x0888, G_UNICODE_MODIFIER_SYMBOL },
  { 0x0889, 0x088E, G_UNICODE_OTHER_LETTER },
  { 0x0890, 0x0891, G_UNICODE_FORMAT },
  { 0x0897, 0x089F, G_UNICODE_NON_SPACING_MARK },
  { 0x08A0, 0x08C8, G_UNICODE_OTHER_LETTER },
  { 0x08C9, 0x08C9, G_UNICODE_MODIFIER_LETTER },
  { 0x08CA, 0x08E1, G_UNICODE_NON_SPACING_MARK },
  { 0x08E2, 0x08E2, G_UNICODE_FORMAT },
  { 0x08E3, 0x0902, G_UNICODE_NON_SPACING_MARK },
  { 0x0903, 0x0903, G_UNICODE_SPACING_MARK },
  { 0x0904, 0x0939, G_UNICODE_OTHER_LETTER },
  { 0x093A, 0x093A, G_UNICODE_NON_SPACING_MARK },
  { 0x093B, 0x093B, G_UNICODE_SPACING_MARK },
  { 0x093C, 0x093C, G_UNICODE_NON_SPACING_MARK },
  { 0x093D, 0x093D, G_UNICODE_OTHER_LETTER },
  { 0x093E, 0x0940, G_UNICODE_SPACING_MARK },
  { 0x0941, 0x0948, G_UNICODE_NON_SPACING_MARK },
  { 0x0949, 0x094C, G_UNICODE_SPACING_MARK },
  { 0x094D, 0x094D, G_UNICODE_NON_SPACING_MARK },
  { 0x094E, 0x094F, G_UNICODE_SPACING_MARK },
  { 0x0950, 0x0950, G_UNICODE_OTHER_LETTER },
  { 0x0951, 0x0957, G_UNICODE_NON_SPACING_MARK },
  { 0x0958, 0x0961, G_UNICODE_OTHER_LETTER },
  { 0x0962, 0x0963, G_UNICODE_NON_SPACING_MARK },
  { 0x0964, 0x0965, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0966, 0x096F, G_UNICODE_DECIMAL_NUMBER },
  { 0x0970, 0x0970, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0971, 0x0971, G_UNICODE_MODIFIER_LETTER },
  { 0x0972, 0x0980, G_UNICODE_OTHER_LETTER },
  { 0x0981, 0x0981, G_UNICODE_NON_SPACING_MARK },
  { 0x0982, 0x0983, G_UNICODE_SPACING_MARK },
  { 0x0985, 0x098C, G_UNICODE_OTHER_LETTER },
  { 0x098F, 0x0990, G_UNICODE_OTHER_LETTER },
  { 0x0993, 0x09A8, G_UNICODE_OTHER_LETTER },
  { 0x09AA, 0x09B0, G_UNICODE_OTHER_LETTER },
  { 0x09B2, 0x09B2, G_UNICODE_OTHER_LETTER },
  { 0x09B6, 0x09B9, G_UNICODE_OTHER_LETTER },
  { 0x09BC, 0x09BC, G_UNICODE_NON_SPACING_MARK },
  { 0x09BD, 0x09BD, G_UNICODE_OTHER_LETTER },
  { 0x09BE, 0x09C0, G_UNICODE_SPACING_MARK },
  { 0x09C1, 0x09C4, G_UNICODE_NON_SPACING_MARK },
  { 0x09C7, 0x09C8, G_UNICODE_SPACING_MARK },
  { 0x09CB, 0x09CC, G_UNICODE_SPACING_MARK },
  { 0x09CD, 0x09CD, G_UNICODE_NON_SPACING_MARK },
  { 0x09CE, 0x09CE, G_UNICODE_OTHER_LETTER },
  { 0x09D7, 0x09D7, G_UNICODE_SPACING_MARK },
  { 0x09DC, 0x09DD, G_UNICODE_OTHER_LETTER },
  { 0x09DF, 0x09E1, G_UNICODE_OTHER_LETTER },
  { 0x09E2, 0x09E3, G_UNICODE_NON_SPACING_MARK },
  { 0x09E6, 0x09EF, G_UNICODE_DECIMAL_NUMBER },
  { 0x09F0, 0x09F1, G_UNICODE_OTHER_LETTER },
  { 0x09F2, 0x09F3, G_UNICODE_CURRENCY_SYMBOL },
  { 0x09F4, 0x09F9, G_UNICODE_OTHER_NUMBER },
  { 0x09FA, 0x09FA, G_UNICODE_OTHER_SYMBOL },
  { 0x09FB, 0x09FB, G_UNICODE_CURRENCY_SYMBOL },
  { 0x09FC, 0x09FC, G_UNICODE_OTHER_LETTER },
  { 0x09FD, 0x09FD, G_UNICODE_OTHER_PUNCTUATION },
  { 0x09FE, 0x09FE, G_UNICODE_NON_SPACING_MARK },
  { 0x0A01, 0x0A02, G_UNICODE_NON_SPACING_MARK },
  { 0x0A03, 0x0A03, G_UNICODE_SPACING_MARK },
  { 0x0A05, 0x0A0A, G_UNICODE_OTHER_LETTER },
  { 0x0A0F, 0x0A10, G_UNICODE_OTHER_LETTER },
  { 0x0A13, 0x0A28, G_UNICODE_OTHER_LETTER },
  { 0x0A2A, 0x0A30, G_UNICODE_OTHER_LETTER },
  { 0x0A32, 0x0A33, G_UNICODE_OTHER_LETTER },
  { 0x0A35, 0x0A36, G_UNICODE_OTHER_LETTER },
  { 0x0A38, 0x0A39, G_UNICODE_OTHER_LETTER },
  { 0x0A3C, 0x0A3C, G_UNICODE_NON_SPACING_MARK },
  { 0x0A3E, 0x0A40, G_UNICODE_SPACING_MARK },
  { 0x0A41, 0x0A42, G_UNICODE_NON_SPACING_MARK },
  { 0x0A47, 0x0A48, G_UNICODE_NON_SPACING_MARK },
  { 0x0A4B, 0x0A4D, G_UNICODE_NON_SPACING_MARK },
  { 0x0A51, 0x0A51, G_UNICODE_NON_SPACING_MARK },
  { 0x0A59, 0x0A5C, G_UNICODE_OTHER_LETTER },
  { 0x0A5E, 0x0A5E, G_UNICODE_OTHER_LETTER },
  { 0x0A66, 0x0A6F, G_UNICODE_DECIMAL_NUMBER },
  { 0x0A70, 0x0A71, G_UNICODE_NON_SPACING_MARK },
  { 0x0A72, 0x0A74, G_UNICODE_OTHER_LETTER },
  { 0x0A75, 0x0A75, G_UNICODE_NON_SPACING_MARK },
  { 0x0A76, 0x0A76, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0A81, 0x0A82, G_UNICODE_NON_SPACING_MARK },
  { 0x0A83, 0x0A83, G_UNICODE_SPACING_MARK },
  { 0x0A85, 0x0A8D, G_UNICODE_OTHER_LETTER },
  { 0x0A8F, 0x0A91, G_UNICODE_OTHER_LETTER },
  { 0x0A93, 0x0AA8, G_UNICODE_OTHER_LETTER },
  { 0x0AAA, 0x0AB0, G_UNICODE_OTHER_LETTER },
  { 0x0AB2, 0x0AB3, G_UNICODE_OTHER_LETTER },
  { 0x0AB5, 0x0AB9, G_UNICODE_OTHER_LETTER },
  { 0x0ABC, 0x0ABC, G_UNICODE_NON_SPACING_MARK },
  { 0x0ABD, 0x0ABD, G_UNICODE_OTHER_LETTER },
  { 0x0ABE, 0x0AC0, G_UNICODE_SPACING_MARK },
  { 0x0AC1, 0x0AC5, G_UNICODE_NON_SPACING_MARK },
  { 0x0AC7, 0x0AC8, G_UNICODE_NON_SPACING_MARK },
  { 0x0AC9, 0x0AC9, G_UNICODE_SPACING_MARK },
  { 0x0ACB, 0x0ACC, G_UNICODE_SPACING_MARK },
  { 0x0ACD, 0x0ACD, G_UNICODE_NON_SPACING_MARK },
  { 0x0AD0, 0x0AD0, G_UNICODE_OTHER_LETTER },
  { 0x0AE0, 0x0AE1, G_UNICODE_OTHER_LETTER },
  { 0x0AE2, 0x0AE3, G_UNICODE_NON_SPACING_MARK },
  { 0x0AE6, 0x0AEF, G_UNICODE_DECIMAL_NUMBER },
  { 0x0AF0, 0x0AF0, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0AF1, 0x0AF1, G_UNICODE_CURRENCY_SYMBOL },
  { 0x0AF9, 0x0AF9, G_UNICODE_OTHER_LETTER },
  { 0x0AFA, 0x0AFF, G_UNICODE_NON_SPACING_MARK },
  { 0x0B01, 0x0B01, G_UNICODE_NON_SPACING_MARK },
  { 0x0B02, 0x0B03, G_UNICODE_SPACING_MARK },
  { 0x0B05, 0x0B0C, G_UNICODE_OTHER_LETTER },
  { 0x0B0F, 0x0B10, G_UNICODE_OTHER_LETTER },
  { 0x0B13, 0x0B28, G_UNICODE_OTHER_LETTER },
  { 0x0B2A, 0x0B30, G_UNICODE_OTHER_LETTER },
  { 0x0B32, 0x0B33, G_UNICODE_OTHER_LETTER },
  { 0x0B35, 0x0B39, G_UNICODE_OTHER_LETTER },
  { 0x0B3C, 0x0B3C, G_UNICODE_NON_SPACING_MARK },
  { 0x0B3D, 0x0B3D, G_UNICODE_OTHER_LETTER },
  { 0x0B3E, 0x0B3E, G_UNICODE_SPACING_MARK },
  { 0x0B3F, 0x0B3F, G_UNICODE_NON_SPACING_MARK },
  { 0x0B40, 0x0B40, G_UNICODE_SPACING_MARK },
  { 0x0B41, 0x0B44, G_UNICODE_NON_SPACING_MARK },
  { 0x0B47, 0x0B48, G_UNICODE_SPACING_MARK },
  { 0x0B4B, 0x0B4C, G_UNICODE_SPACING_MARK },
  { 0x0B4D, 0x0B4D, G_UNICODE_NON_SPACING_MARK },
  { 0x0B55, 0x0B56, G_UNICODE_NON_SPACING_MARK },
  { 0x0B57, 0x0B57, G_UNICODE_SPACING_MARK },
  { 0x0B5C, 0x0B5D, G_UNICODE_OTHER_LETTER },
  { 0x0B5F, 0x0B61, G_UNICODE_OTHER_LETTER },
  { 0x0B62, 0x0B63, G_UNICODE_NON_SPACING_MARK },
  { 0x0B66, 0x0B6F, G_UNICODE_DECIMAL_NUMBER },
  { 0x0B70, 0x0B70, G_UNICODE_OTHER_SYMBOL },
  { 0x0B71, 0x0B71, G_UNICODE_OTHER_LETTER },
  { 0x0B72, 0x0B77, G_UNICODE_OTHER_NUMBER },
  { 0x0B82, 0x0B82, G_UNICODE_NON_SPACING_MARK },
  { 0x0B83, 0x0B83, G_UNICODE_OTHER_LETTER },
  { 0x0B85, 0x0B8A, G_UNICODE_OTHER_LETTER },
  { 0x0B8E, 0x0B90, G_UNICODE_OTHER_LETTER },
  { 0x0B92, 0x0B95, G_UNICODE_OTHER_LETTER },
  { 0x0B99, 0x0B9A, G_UNICODE_OTHER_LETTER },
  { 0x0B9C, 0x0B9C, G_UNICODE_OTHER_LETTER },
  { 0x0B9E, 0x0B9F, G_UNICODE_OTHER_LETTER },
  { 0x0BA3, 0x0BA4, G_UNICODE_OTHER_LETTER },
  { 0x0BA8, 0x0BAA, G_UNICODE_OTHER_LETTER },
  { 0x0BAE, 0x0BB9, G_UNICODE_OTHER_LETTER },
  { 0x0BBE, 0x0BBF, G_UNICODE_SPACING_MARK },
  { 0x0BC0, 0x0BC0, G_UNICODE_NON_SPACING_MARK },
  { 0x0BC1, 0x0BC2, G_UNICODE_SPACING_MARK },
  { 0x0BC6, 0x0BC8, G_UNICODE_SPACING_MARK },
  { 0x0BCA, 0x0BCC, G_UNICODE_SPACING_MARK },
  { 0x0BCD, 0x0BCD, G_UNICODE_NON_SPACING_MARK },
  { 0x0BD0, 0x0BD0, G_UNICODE_OTHER_LETTER },
  { 0x0BD7, 0x0BD7, G_UNICODE_SPACING_MARK },
  { 0x0BE6, 0x0BEF, G_UNICODE_DECIMAL_NUMBER },
  { 0x0BF0, 0x0BF2, G_UNICODE_OTHER_NUMBER },
  { 0x0BF3, 0x0BF8, G_UNICODE_OTHER_SYMBOL },
  { 0x0BF9, 0x0BF9, G_UNICODE_CURRENCY_SYMBOL },
  { 0x0BFA, 0x0BFA, G_UNICODE_OTHER_SYMBOL },
  { 0x0C00, 0x0C00, G_UNICODE_NON_SPACING_MARK },
  { 0x0C01, 0x0C03, G_UNICODE_SPACING_MARK },
  { 0x0C04, 0x0C04, G_UNICODE_NON_SPACING_MARK },
  { 0x0C05, 0x0C0C, G_UNICODE_OTHER_LETTER },
  { 0x0C0E, 0x0C10, G_UNICODE_OTHER_LETTER },
  { 0x0C12, 0x0C28, G_UNICODE_OTHER_LETTER },
  { 0x0C2A, 0x0C39, G_UNICODE_OTHER_LETTER },
  { 0x0C3C, 0x0C3C, G_UNICODE_NON_SPACING_MARK },
  { 0x0C3D, 0x0C3D, G_UNICODE_OTHER_LETTER },
  { 0x0C3E, 0x0C40, G_UNICODE_NON_SPACING_MARK },
  { 0x0C41, 0x0C44, G_UNICODE_SPACING_MARK },
  { 0x0C46, 0x0C48, G_UNICODE_NON_SPACING_MARK },
  { 0x0C4A, 0x0C4D, G_UNICODE_NON_SPACING_MARK },
  { 0x0C55, 0x0C56, G_UNICODE_NON_SPACING_MARK },
  { 0x0C58, 0x0C5A, G_UNICODE_OTHER_LETTER },
  { 0x0C5D, 0x0C5D, G_UNICODE_OTHER_LETTER },
  { 0x0C60, 0x0C61, G_UNICODE_OTHER_LETTER },
  { 0x0C62, 0x0C63, G_UNICODE_NON_SPACING_MARK },
  { 0x0C66, 0x0C6F, G_UNICODE_DECIMAL_NUMBER },
  { 0x0C77, 0x0C77, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0C78, 0x0C7E, G_UNICODE_OTHER_NUMBER },
  { 0x0C7F, 0x0C7F, G_UNICODE_OTHER_SYMBOL },
  { 0x0C80, 0x0C80, G_UNICODE_OTHER_LETTER },
  { 0x0C81, 0x0C81, G_UNICODE_NON_SPACING_MARK },
  { 0x0C82, 0x0C83, G_UNICODE_SPACING_MARK },
  { 0x0C84, 0x0C84, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0C85, 0x0C8C, G_UNICODE_OTHER_LETTER },
  { 0x0C8E, 0x0C90, G_UNICODE_OTHER_LETTER },
  { 0x0C92, 0x0CA8, G_UNICODE_OTHER_LETTER },
  { 0x0CAA, 0x0CB3, G_UNICODE_OTHER_LETTER },
  { 0x0CB5, 0x0CB9, G_UNICODE_OTHER_LETTER },
  { 0x0CBC, 0x0CBC, G_UNICODE_NON_SPACING_MARK },
  { 0x0CBD, 0x0CBD, G_UNICODE_OTHER_LETTER },
  { 0x0CBE, 0x0CBE, G_UNICODE_SPACING_MARK },
  { 0x0CBF, 0x0CBF, G_UNICODE_NON_SPACING_MARK },
  { 0x0CC0, 0x0CC4, G_UNICODE_SPACING_MARK },
  { 0x0CC6, 0x0CC6, G_UNICODE_NON_SPACING_MARK },
  { 0x0CC7, 0x0CC8, G_UNICODE_SPACING_MARK },
  { 0x0CCA, 0x0CCB, G_UNICODE_SPACING_MARK },
  { 0x0CCC, 0x0CCD, G_UNICODE_NON_SPACING_MARK },
  { 0x0CD5, 0x0CD6, G_UNICODE_SPACING_MARK },
  { 0x0CDD, 0x0CDE, G_UNICODE_OTHER_LETTER },
  { 0x0CE0, 0x0CE1, G_UNICODE_OTHER_LETTER },
  { 0x0CE2, 0x0CE3, G_UNICODE_NON_SPACING_MARK },
  { 0x0CE6, 0x0CEF, G_UNICODE_DECIMAL_NUMBER },
  { 0x0CF1, 0x0CF2, G_UNICODE_OTHER_LETTER },
  { 0x0CF3, 0x0CF3, G_UNICODE_SPACING_MARK },
  { 0x0D00, 0x0D01, G_UNICODE_NON_SPACING_MARK },
  { 0x0D02, 0x0D03, G_UNICODE_SPACING_MARK },
  { 0x0D04, 0x0D0C, G_UNICODE_OTHER_LETTER },
  { 0x0D0E, 0x0D10, G_UNICODE_OTHER_LETTER },
  { 0x0D12, 0x0D3A, G_UNICODE_OTHER_LETTER },
  { 0x0D3B, 0x0D3C, G_UNICODE_NON_SPACING_MARK },
  { 0x0D3D, 0x0D3D, G_UNICODE_OTHER_LETTER },
  { 0x0D3E, 0x0D40, G_UNICODE_SPACING_MARK },
  { 0x0D41, 0x0D44, G_UNICODE_NON_SPACING_MARK },
  { 0x0D46, 0x0D48, G_UNICODE_SPACING_MARK },
  { 0x0D4A, 0x0D4C, G_UNICODE_SPACING_MARK },
  { 0x0D4D, 0x0D4D, G_UNICODE_NON_SPACING_MARK },
  { 0x0D4E, 0x0D4E, G_UNICODE_OTHER_LETTER },
  { 0x0D4F, 0x0D4F, G_UNICODE_OTHER_SYMBOL },
  { 0x0D54, 0x0D56, G_UNICODE_OTHER_LETTER },
  { 0x0D57, 0x0D57, G_UNICODE_SPACING_MARK },
  { 0x0D58, 0x0D5E, G_UNICODE_OTHER_NUMBER },
  { 0x0D5F, 0x0D61, G_UNICODE_OTHER_LETTER },
  { 0x0D62, 0x0D63, G_UNICODE_NON_SPACING_MARK },
  { 0x0D66, 0x0D6F, G_UNICODE_DECIMAL_NUMBER },
  { 0x0D70, 0x0D78, G_UNICODE_OTHER_NUMBER },
  { 0x0D79, 0x0D79, G_UNICODE_OTHER_SYMBOL },
  { 0x0D7A, 0x0D7F, G_UNICODE_OTHER_LETTER },
  { 0x0D81, 0x0D81, G_UNICODE_NON_SPACING_MARK },
  { 0x0D82, 0x0D83, G_UNICODE_SPACING_MARK },
  { 0x0D85, 0x0D96, G_UNICODE_OTHER_LETTER },
  { 0x0D9A, 0x0DB1, G_UNICODE_OTHER_LETTER },
  { 0x0DB3, 0x0DBB, G_UNICODE_OTHER_LETTER },
  { 0x0DBD, 0x0DBD, G_UNICODE_OTHER_LETTER },
  { 0x0DC0, 0x0DC6, G_UNICODE_OTHER_LETTER },
  { 0x0DCA, 0x0DCA, G_UNICODE_NON_SPACING_MARK },
  { 0x0DCF, 0x0DD1, G_UNICODE_SPACING_MARK },
  { 0x0DD2, 0x0DD4, G_UNICODE_NON_SPACING_MARK },
  { 0x0DD6, 0x0DD6, G_UNICODE_NON_SPACING_MARK },
  { 0x0DD8, 0x0DDF, G_UNICODE_SPACING_MARK },
  { 0x0DE6, 0x0DEF, G_UNICODE_DECIMAL_NUMBER },
  { 0x0DF2, 0x0DF3, G_UNICODE_SPACING_MARK },
  { 0x0DF4, 0x0DF4, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0E01, 0x0E30, G_UNICODE_OTHER_LETTER },
  { 0x0E31, 0x0E31, G_UNICODE_NON_SPACING_MARK },
  { 0x0E32, 0x0E33, G_UNICODE_OTHER_LETTER },
  { 0x0E34, 0x0E3A, G_UNICODE_NON_SPACING_MARK },
  { 0x0E3F, 0x0E3F, G_UNICODE_CURRENCY_SYMBOL },
  { 0x0E40, 0x0E45, G_UNICODE_OTHER_LETTER },
  { 0x0E46, 0x0E46, G_UNICODE_MODIFIER_LETTER },
  { 0x0E47, 0x0E4E, G_UNICODE_NON_SPACING_MARK },
  { 0x0E4F, 0x0E4F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0E50, 0x0E59, G_UNICODE_DECIMAL_NUMBER },
  { 0x0E5A, 0x0E5B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0E81, 0x0E82, G_UNICODE_OTHER_LETTER },
  { 0x0E84, 0x0E84, G_UNICODE_OTHER_LETTER },
  { 0x0E86, 0x0E8A, G_UNICODE_OTHER_LETTER },
  { 0x0E8C, 0x0EA3, G_UNICODE_OTHER_LETTER },
  { 0x0EA5, 0x0EA5, G_UNICODE_OTHER_LETTER },
  { 0x0EA7, 0x0EB0, G_UNICODE_OTHER_LETTER },
  { 0x0EB1, 0x0EB1, G_UNICODE_NON_SPACING_MARK },
  { 0x0EB2, 0x0EB3, G_UNICODE_OTHER_LETTER },
  { 0x0EB4, 0x0EBC, G_UNICODE_NON_SPACING_MARK },
  { 0x0EBD, 0x0EBD, G_UNICODE_OTHER_LETTER },
  { 0x0EC0, 0x0EC4, G_UNICODE_OTHER_LETTER },
  { 0x0EC6, 0x0EC6, G_UNICODE_MODIFIER_LETTER },
  { 0x0EC8, 0x0ECE, G_UNICODE_NON_SPACING_MARK },
  { 0x0ED0, 0x0ED9, G_UNICODE_DECIMAL_NUMBER },
  { 0x0EDC, 0x0EDF, G_UNICODE_OTHER_LETTER },
  { 0x0F00, 0x0F00, G_UNICODE_OTHER_LETTER },
  { 0x0F01, 0x0F03, G_UNICODE_OTHER_SYMBOL },
  { 0x0F04, 0x0F12, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0F13, 0x0F13, G_UNICODE_OTHER_SYMBOL },
  { 0x0F14, 0x0F14, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0F15, 0x0F17, G_UNICODE_OTHER_SYMBOL },
  { 0x0F18, 0x0F19, G_UNICODE_NON_SPACING_MARK },
  { 0x0F1A, 0x0F1F, G_UNICODE_OTHER_SYMBOL },
  { 0x0F20, 0x0F29, G_UNICODE_DECIMAL_NUMBER },
  { 0x0F2A, 0x0F33, G_UNICODE_OTHER_NUMBER },
  { 0x0F34, 0x0F34, G_UNICODE_OTHER_SYMBOL },
  { 0x0F35, 0x0F35, G_UNICODE_NON_SPACING_MARK },
  { 0x0F36, 0x0F36, G_UNICODE_OTHER_SYMBOL },
  { 0x0F37, 0x0F37, G_UNICODE_NON_SPACING_MARK },
  { 0x0F38, 0x0F38, G_UNICODE_OTHER_SYMBOL },
  { 0x0F39, 0x0F39, G_UNICODE_NON_SPACING_MARK },
  { 0x0F3A, 0x0F3A, G_UNICODE_OPEN_PUNCTUATION },
  { 0x0F3B, 0x0F3B, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x0F3C, 0x0F3C, G_UNICODE_OPEN_PUNCTUATION },
  { 0x0F3D, 0x0F3D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x0F3E, 0x0F3F, G_UNICODE_SPACING_MARK },
  { 0x0F40, 0x0F47, G_UNICODE_OTHER_LETTER },
  { 0x0F49, 0x0F6C, G_UNICODE_OTHER_LETTER },
  { 0x0F71, 0x0F7E, G_UNICODE_NON_SPACING_MARK },
  { 0x0F7F, 0x0F7F, G_UNICODE_SPACING_MARK },
  { 0x0F80, 0x0F84, G_UNICODE_NON_SPACING_MARK },
  { 0x0F85, 0x0F85, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0F86, 0x0F87, G_UNICODE_NON_SPACING_MARK },
  { 0x0F88, 0x0F8C, G_UNICODE_OTHER_LETTER },
  { 0x0F8D, 0x0F97, G_UNICODE_NON_SPACING_MARK },
  { 0x0F99, 0x0FBC, G_UNICODE_NON_SPACING_MARK },
  { 0x0FBE, 0x0FC5, G_UNICODE_OTHER_SYMBOL },
  { 0x0FC6, 0x0FC6, G_UNICODE_NON_SPACING_MARK },
  { 0x0FC7, 0x0FCC, G_UNICODE_OTHER_SYMBOL },
  { 0x0FCE, 0x0FCF, G_UNICODE_OTHER_SYMBOL },
  { 0x0FD0, 0x0FD4, G_UNICODE_OTHER_PUNCTUATION },
  { 0x0FD5, 0x0FD8, G_UNICODE_OTHER_SYMBOL },
  { 0x0FD9, 0x0FDA, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1000, 0x102A, G_UNICODE_OTHER_LETTER },
  { 0x102B, 0x102C, G_UNICODE_SPACING_MARK },
  { 0x102D, 0x1030, G_UNICODE_NON_SPACING_MARK },
  { 0x1031, 0x1031, G_UNICODE_SPACING_MARK },
  { 0x1032, 0x1037, G_UNICODE_NON_SPACING_MARK },
  { 0x1038, 0x1038, G_UNICODE_SPACING_MARK },
  { 0x1039, 0x103A, G_UNICODE_NON_SPACING_MARK },
  { 0x103B, 0x103C, G_UNICODE_SPACING_MARK },
  { 0x103D, 0x103E, G_UNICODE_NON_SPACING_MARK },
  { 0x103F, 0x103F, G_UNICODE_OTHER_LETTER },
  { 0x1040, 0x1049, G_UNICODE_DECIMAL_NUMBER },
  { 0x104A, 0x104F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1050, 0x1055, G_UNICODE_OTHER_LETTER },
  { 0x1056, 0x1057, G_UNICODE_SPACING_MARK },
  { 0x1058, 0x1059, G_UNICODE_NON_SPACING_MARK },
  { 0x105A, 0x105D, G_UNICODE_OTHER_LETTER },
  { 0x105E, 0x1060, G_UNICODE_NON_SPACING_MARK },
  { 0x1061, 0x1061, G_UNICODE_OTHER_LETTER },
  { 0x1062, 0x1064, G_UNICODE_SPACING_MARK },
  { 0x1065, 0x1066, G_UNICODE_OTHER_LETTER },
  { 0x1067, 0x106D, G_UNICODE_SPACING_MARK },
  { 0x106E, 0x1070, G_UNICODE_OTHER_LETTER },
  { 0x1071, 0x1074, G_UNICODE_NON_SPACING_MARK },
  { 0x1075, 0x1081, G_UNICODE_OTHER_LETTER },
  { 0x1082, 0x1082, G_UNICODE_NON_SPACING_MARK },
  { 0x1083, 0x1084, G_UNICODE_SPACING_MARK },
  { 0x1085, 0x1086, G_UNICODE_NON_SPACING_MARK },
  { 0x1087, 0x108C, G_UNICODE_SPACING_MARK },
  { 0x108D, 0x108D, G_UNICODE_NON_SPACING_MARK },
  { 0x108E, 0x108E, G_UNICODE_OTHER_LETTER },
  { 0x108F, 0x108F, G_UNICODE_SPACING_MARK },
  { 0x1090, 0x1099, G_UNICODE_DECIMAL_NUMBER },
  { 0x109A, 0x109C, G_UNICODE_SPACING_MARK },
  { 0x109D, 0x109D, G_UNICODE_NON_SPACING_MARK },
  { 0x109E, 0x109F, G_UNICODE_OTHER_SYMBOL },
  { 0x10A0, 0x10C5, G_UNICODE_UPPERCASE_LETTER },
  { 0x10C7, 0x10C7, G_UNICODE_UPPERCASE_LETTER },
  { 0x10CD, 0x10CD, G_UNICODE_UPPERCASE_LETTER },
  { 0x10D0, 0x10FA, G_UNICODE_LOWERCASE_LETTER },
  { 0x10FB, 0x10FB, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10FC, 0x10FC, G_UNICODE_MODIFIER_LETTER },
  { 0x10FD, 0x10FF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1100, 0x1248, G_UNICODE_OTHER_LETTER },
  { 0x124A, 0x124D, G_UNICODE_OTHER_LETTER },
  { 0x1250, 0x1256, G_UNICODE_OTHER_LETTER },
  { 0x1258, 0x1258, G_UNICODE_OTHER_LETTER },
  { 0x125A, 0x125D, G_UNICODE_OTHER_LETTER },
  { 0x1260, 0x1288, G_UNICODE_OTHER_LETTER },
  { 0x128A, 0x128D, G_UNICODE_OTHER_LETTER },
  { 0x1290, 0x12B0, G_UNICODE_OTHER_LETTER },
  { 0x12B2, 0x12B5, G_UNICODE_OTHER_LETTER },
  { 0x12B8, 0x12BE, G_UNICODE_OTHER_LETTER },
  { 0x12C0, 0x12C0, G_UNICODE_OTHER_LETTER },
  { 0x12C2, 0x12C5, G_UNICODE_OTHER_LETTER },
  { 0x12C8, 0x12D6, G_UNICODE_OTHER_LETTER },
  { 0x12D8, 0x1310, G_UNICODE_OTHER_LETTER },
  { 0x1312, 0x1315, G_UNICODE_OTHER_LETTER },
  { 0x1318, 0x135A, G_UNICODE_OTHER_LETTER },
  { 0x135D, 0x135F, G_UNICODE_NON_SPACING_MARK },
  { 0x1360, 0x1368, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1369, 0x137C, G_UNICODE_OTHER_NUMBER },
  { 0x1380, 0x138F, G_UNICODE_OTHER_LETTER },
  { 0x1390, 0x1399, G_UNICODE_OTHER_SYMBOL },
  { 0x13A0, 0x13F5, G_UNICODE_UPPERCASE_LETTER },
  { 0x13F8, 0x13FD, G_UNICODE_LOWERCASE_LETTER },
  { 0x1400, 0x1400, G_UNICODE_DASH_PUNCTUATION },
  { 0x1401, 0x166C, G_UNICODE_OTHER_LETTER },
  { 0x166D, 0x166D, G_UNICODE_OTHER_SYMBOL },
  { 0x166E, 0x166E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x166F, 0x167F, G_UNICODE_OTHER_LETTER },
  { 0x1680, 0x1680, G_UNICODE_SPACE_SEPARATOR },
  { 0x1681, 0x169A, G_UNICODE_OTHER_LETTER },
  { 0x169B, 0x169B, G_UNICODE_OPEN_PUNCTUATION },
  { 0x169C, 0x169C, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x16A0, 0x16EA, G_UNICODE_OTHER_LETTER },
  { 0x16EB, 0x16ED, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16EE, 0x16F0, G_UNICODE_LETTER_NUMBER },
  { 0x16F1, 0x16F8, G_UNICODE_OTHER_LETTER },
  { 0x1700, 0x1711, G_UNICODE_OTHER_LETTER },
  { 0x1712, 0x1714, G_UNICODE_NON_SPACING_MARK },
  { 0x1715, 0x1715, G_UNICODE_SPACING_MARK },
  { 0x171F, 0x1731, G_UNICODE_OTHER_LETTER },
  { 0x1732, 0x1733, G_UNICODE_NON_SPACING_MARK },
  { 0x1734, 0x1734, G_UNICODE_SPACING_MARK },
  { 0x1735, 0x1736, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1740, 0x1751, G_UNICODE_OTHER_LETTER },
  { 0x1752, 0x1753, G_UNICODE_NON_SPACING_MARK },
  { 0x1760, 0x176C, G_UNICODE_OTHER_LETTER },
  { 0x176E, 0x1770, G_UNICODE_OTHER_LETTER },
  { 0x1772, 0x1773, G_UNICODE_NON_SPACING_MARK },
  { 0x1780, 0x17B3, G_UNICODE_OTHER_LETTER },
  { 0x17B4, 0x17B5, G_UNICODE_NON_SPACING_MARK },
  { 0x17B6, 0x17B6, G_UNICODE_SPACING_MARK },
  { 0x17B7, 0x17BD, G_UNICODE_NON_SPACING_MARK },
  { 0x17BE, 0x17C5, G_UNICODE_SPACING_MARK },
  { 0x17C6, 0x17C6, G_UNICODE_NON_SPACING_MARK },
  { 0x17C7, 0x17C8, G_UNICODE_SPACING_MARK },
  { 0x17C9, 0x17D3, G_UNICODE_NON_SPACING_MARK },
  { 0x17D4, 0x17D6, G_UNICODE_OTHER_PUNCTUATION },
  { 0x17D7, 0x17D7, G_UNICODE_MODIFIER_LETTER },
  { 0x17D8, 0x17DA, G_UNICODE_OTHER_PUNCTUATION },
  { 0x17DB, 0x17DB, G_UNICODE_CURRENCY_SYMBOL },
  { 0x17DC, 0x17DC, G_UNICODE_OTHER_LETTER },
  { 0x17DD, 0x17DD, G_UNICODE_NON_SPACING_MARK },
  { 0x17E0, 0x17E9, G_UNICODE_DECIMAL_NUMBER },
  { 0x17F0, 0x17F9, G_UNICODE_OTHER_NUMBER },
  { 0x1800, 0x1805, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1806, 0x1806, G_UNICODE_DASH_PUNCTUATION },
  { 0x1807, 0x180A, G_UNICODE_OTHER_PUNCTUATION },
  { 0x180B, 0x180D, G_UNICODE_NON_SPACING_MARK },
  { 0x180E, 0x180E, G_UNICODE_FORMAT },
  { 0x180F, 0x180F, G_UNICODE_NON_SPACING_MARK },
  { 0x1810, 0x1819, G_UNICODE_DECIMAL_NUMBER },
  { 0x1820, 0x1842, G_UNICODE_OTHER_LETTER },
  { 0x1843, 0x1843, G_UNICODE_MODIFIER_LETTER },
  { 0x1844, 0x1878, G_UNICODE_OTHER_LETTER },
  { 0x1880, 0x1884, G_UNICODE_OTHER_LETTER },
  { 0x1885, 0x1886, G_UNICODE_NON_SPACING_MARK },
  { 0x1887, 0x18A8, G_UNICODE_OTHER_LETTER },
  { 0x18A9, 0x18A9, G_UNICODE_NON_SPACING_MARK },
  { 0x18AA, 0x18AA, G_UNICODE_OTHER_LETTER },
  { 0x18B0, 0x18F5, G_UNICODE_OTHER_LETTER },
  { 0x1900, 0x191E, G_UNICODE_OTHER_LETTER },
  { 0x1920, 0x1922, G_UNICODE_NON_SPACING_MARK },
  { 0x1923, 0x1926, G_UNICODE_SPACING_MARK },
  { 0x1927, 0x1928, G_UNICODE_NON_SPACING_MARK },
  { 0x1929, 0x192B, G_UNICODE_SPACING_MARK },
  { 0x1930, 0x1931, G_UNICODE_SPACING_MARK },
  { 0x1932, 0x1932, G_UNICODE_NON_SPACING_MARK },
  { 0x1933, 0x1938, G_UNICODE_SPACING_MARK },
  { 0x1939, 0x193B, G_UNICODE_NON_SPACING_MARK },
  { 0x1940, 0x1940, G_UNICODE_OTHER_SYMBOL },
  { 0x1944, 0x1945, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1946, 0x194F, G_UNICODE_DECIMAL_NUMBER },
  { 0x1950, 0x196D, G_UNICODE_OTHER_LETTER },
  { 0x1970, 0x1974, G_UNICODE_OTHER_LETTER },
  { 0x1980, 0x19AB, G_UNICODE_OTHER_LETTER },
  { 0x19B0, 0x19C9, G_UNICODE_OTHER_LETTER },
  { 0x19D0, 0x19D9, G_UNICODE_DECIMAL_NUMBER },
  { 0x19DA, 0x19DA, G_UNICODE_OTHER_NUMBER },
  { 0x19DE, 0x19FF, G_UNICODE_OTHER_SYMBOL },
  { 0x1A00, 0x1A16, G_UNICODE_OTHER_LETTER },
  { 0x1A17, 0x1A18, G_UNICODE_NON_SPACING_MARK },
  { 0x1A19, 0x1A1A, G_UNICODE_SPACING_MARK },
  { 0x1A1B, 0x1A1B, G_UNICODE_NON_SPACING_MARK },
  { 0x1A1E, 0x1A1F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1A20, 0x1A54, G_UNICODE_OTHER_LETTER },
  { 0x1A55, 0x1A55, G_UNICODE_SPACING_MARK },
  { 0x1A56, 0x1A56, G_UNICODE_NON_SPACING_MARK },
  { 0x1A57, 0x1A57, G_UNICODE_SPACING_MARK },
  { 0x1A58, 0x1A5E, G_UNICODE_NON_SPACING_MARK },
  { 0x1A60, 0x1A60, G_UNICODE_NON_SPACING_MARK },
  { 0x1A61, 0x1A61, G_UNICODE_SPACING_MARK },
  { 0x1A62, 0x1A62, G_UNICODE_NON_SPACING_MARK },
  { 0x1A63, 0x1A64, G_UNICODE_SPACING_MARK },
  { 0x1A65, 0x1A6C, G_UNICODE_NON_SPACING_MARK },
  { 0x1A6D, 0x1A72, G_UNICODE_SPACING_MARK },
  { 0x1A73, 0x1A7C, G_UNICODE_NON_SPACING_MARK },
  { 0x1A7F, 0x1A7F, G_UNICODE_NON_SPACING_MARK },
  { 0x1A80, 0x1A89, G_UNICODE_DECIMAL_NUMBER },
  { 0x1A90, 0x1A99, G_UNICODE_DECIMAL_NUMBER },
  { 0x1AA0, 0x1AA6, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1AA7, 0x1AA7, G_UNICODE_MODIFIER_LETTER },
  { 0x1AA8, 0x1AAD, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1AB0, 0x1ABD, G_UNICODE_NON_SPACING_MARK },
  { 0x1ABE, 0x1ABE, G_UNICODE_ENCLOSING_MARK },
  { 0x1ABF, 0x1ACE, G_UNICODE_NON_SPACING_MARK },
  { 0x1B00, 0x1B03, G_UNICODE_NON_SPACING_MARK },
  { 0x1B04, 0x1B04, G_UNICODE_SPACING_MARK },
  { 0x1B05, 0x1B33, G_UNICODE_OTHER_LETTER },
  { 0x1B34, 0x1B34, G_UNICODE_NON_SPACING_MARK },
  { 0x1B35, 0x1B35, G_UNICODE_SPACING_MARK },
  { 0x1B36, 0x1B3A, G_UNICODE_NON_SPACING_MARK },
  { 0x1B3B, 0x1B3B, G_UNICODE_SPACING_MARK },
  { 0x1B3C, 0x1B3C, G_UNICODE_NON_SPACING_MARK },
  { 0x1B3D, 0x1B41, G_UNICODE_SPACING_MARK },
  { 0x1B42, 0x1B42, G_UNICODE_NON_SPACING_MARK },
  { 0x1B43, 0x1B44, G_UNICODE_SPACING_MARK },
  { 0x1B45, 0x1B4C, G_UNICODE_OTHER_LETTER },
  { 0x1B4E, 0x1B4F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1B50, 0x1B59, G_UNICODE_DECIMAL_NUMBER },
  { 0x1B5A, 0x1B60, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1B61, 0x1B6A, G_UNICODE_OTHER_SYMBOL },
  { 0x1B6B, 0x1B73, G_UNICODE_NON_SPACING_MARK },
  { 0x1B74, 0x1B7C, G_UNICODE_OTHER_SYMBOL },
  { 0x1B7D, 0x1B7F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1B80, 0x1B81, G_UNICODE_NON_SPACING_MARK },
  { 0x1B82, 0x1B82, G_UNICODE_SPACING_MARK },
  { 0x1B83, 0x1BA0, G_UNICODE_OTHER_LETTER },
  { 0x1BA1, 0x1BA1, G_UNICODE_SPACING_MARK },
  { 0x1BA2, 0x1BA5, G_UNICODE_NON_SPACING_MARK },
  { 0x1BA6, 0x1BA7, G_UNICODE_SPACING_MARK },
  { 0x1BA8, 0x1BA9, G_UNICODE_NON_SPACING_MARK },
  { 0x1BAA, 0x1BAA, G_UNICODE_SPACING_MARK },
  { 0x1BAB, 0x1BAD, G_UNICODE_NON_SPACING_MARK },
  { 0x1BAE, 0x1BAF, G_UNICODE_OTHER_LETTER },
  { 0x1BB0, 0x1BB9, G_UNICODE_DECIMAL_NUMBER },
  { 0x1BBA, 0x1BE5, G_UNICODE_OTHER_LETTER },
  { 0x1BE6, 0x1BE6, G_UNICODE_NON_SPACING_MARK },
  { 0x1BE7, 0x1BE7, G_UNICODE_SPACING_MARK },
  { 0x1BE8, 0x1BE9, G_UNICODE_NON_SPACING_MARK },
  { 0x1BEA, 0x1BEC, G_UNICODE_SPACING_MARK },
  { 0x1BED, 0x1BED, G_UNICODE_NON_SPACING_MARK },
  { 0x1BEE, 0x1BEE, G_UNICODE_SPACING_MARK },
  { 0x1BEF, 0x1BF1, G_UNICODE_NON_SPACING_MARK },
  { 0x1BF2, 0x1BF3, G_UNICODE_SPACING_MARK },
  { 0x1BFC, 0x1BFF, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1C00, 0x1C23, G_UNICODE_OTHER_LETTER },
  { 0x1C24, 0x1C2B, G_UNICODE_SPACING_MARK },
  { 0x1C2C, 0x1C33, G_UNICODE_NON_SPACING_MARK },
  { 0x1C34, 0x1C35, G_UNICODE_SPACING_MARK },
  { 0x1C36, 0x1C37, G_UNICODE_NON_SPACING_MARK },
  { 0x1C3B, 0x1C3F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1C40, 0x1C49, G_UNICODE_DECIMAL_NUMBER },
  { 0x1C4D, 0x1C4F, G_UNICODE_OTHER_LETTER },
  { 0x1C50, 0x1C59, G_UNICODE_DECIMAL_NUMBER },
  { 0x1C5A, 0x1C77, G_UNICODE_OTHER_LETTER },
  { 0x1C78, 0x1C7D, G_UNICODE_MODIFIER_LETTER },
  { 0x1C7E, 0x1C7F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1C80, 0x1C88, G_UNICODE_LOWERCASE_LETTER },
  { 0x1C89, 0x1C89, G_UNICODE_UPPERCASE_LETTER },
  { 0x1C8A, 0x1C8A, G_UNICODE_LOWERCASE_LETTER },
  { 0x1C90, 0x1CBA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1CBD, 0x1CBF, G_UNICODE_UPPERCASE_LETTER },
  { 0x1CC0, 0x1CC7, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1CD0, 0x1CD2, G_UNICODE_NON_SPACING_MARK },
  { 0x1CD3, 0x1CD3, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1CD4, 0x1CE0, G_UNICODE_NON_SPACING_MARK },
  { 0x1CE1, 0x1CE1, G_UNICODE_SPACING_MARK },
  { 0x1CE2, 0x1CE8, G_UNICODE_NON_SPACING_MARK },
  { 0x1CE9, 0x1CEC, G_UNICODE_OTHER_LETTER },
  { 0x1CED, 0x1CED, G_UNICODE_NON_SPACING_MARK },
  { 0x1CEE, 0x1CF3, G_UNICODE_OTHER_LETTER },
  { 0x1CF4, 0x1CF4, G_UNICODE_NON_SPACING_MARK },
  { 0x1CF5, 0x1CF6, G_UNICODE_OTHER_LETTER },
  { 0x1CF7, 0x1CF7, G_UNICODE_SPACING_MARK },
  { 0x1CF8, 0x1CF9, G_UNICODE_NON_SPACING_MARK },
  { 0x1CFA, 0x1CFA, G_UNICODE_OTHER_LETTER },
  { 0x1D00, 0x1D2B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D2C, 0x1D6A, G_UNICODE_MODIFIER_LETTER },
  { 0x1D6B, 0x1D77, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D78, 0x1D78, G_UNICODE_MODIFIER_LETTER },
  { 0x1D79, 0x1D9A, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D9B, 0x1DBF, G_UNICODE_MODIFIER_LETTER },
  { 0x1DC0, 0x1DFF, G_UNICODE_NON_SPACING_MARK },
  { 0x1E00, 0x1E00, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E01, 0x1E01, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E02, 0x1E02, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E03, 0x1E03, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E04, 0x1E04, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E05, 0x1E05, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E06, 0x1E06, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E07, 0x1E07, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E08, 0x1E08, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E09, 0x1E09, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E0A, 0x1E0A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E0B, 0x1E0B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E0C, 0x1E0C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E0D, 0x1E0D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E0E, 0x1E0E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E0F, 0x1E0F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E10, 0x1E10, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E11, 0x1E11, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E12, 0x1E12, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E13, 0x1E13, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E14, 0x1E14, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E15, 0x1E15, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E16, 0x1E16, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E17, 0x1E17, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E18, 0x1E18, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E19, 0x1E19, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E1A, 0x1E1A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E1B, 0x1E1B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E1C, 0x1E1C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E1D, 0x1E1D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E1E, 0x1E1E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E1F, 0x1E1F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E20, 0x1E20, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E21, 0x1E21, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E22, 0x1E22, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E23, 0x1E23, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E24, 0x1E24, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E25, 0x1E25, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E26, 0x1E26, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E27, 0x1E27, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E28, 0x1E28, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E29, 0x1E29, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E2A, 0x1E2A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E2B, 0x1E2B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E2C, 0x1E2C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E2D, 0x1E2D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E2E, 0x1E2E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E2F, 0x1E2F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E30, 0x1E30, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E31, 0x1E31, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E32, 0x1E32, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E33, 0x1E33, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E34, 0x1E34, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E35, 0x1E35, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E36, 0x1E36, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E37, 0x1E37, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E38, 0x1E38, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E39, 0x1E39, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E3A, 0x1E3A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E3B, 0x1E3B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E3C, 0x1E3C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E3D, 0x1E3D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E3E, 0x1E3E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E3F, 0x1E3F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E40, 0x1E40, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E41, 0x1E41, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E42, 0x1E42, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E43, 0x1E43, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E44, 0x1E44, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E45, 0x1E45, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E46, 0x1E46, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E47, 0x1E47, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E48, 0x1E48, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E49, 0x1E49, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E4A, 0x1E4A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E4B, 0x1E4B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E4C, 0x1E4C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E4D, 0x1E4D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E4E, 0x1E4E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E4F, 0x1E4F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E50, 0x1E50, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E51, 0x1E51, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E52, 0x1E52, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E53, 0x1E53, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E54, 0x1E54, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E55, 0x1E55, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E56, 0x1E56, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E57, 0x1E57, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E58, 0x1E58, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E59, 0x1E59, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E5A, 0x1E5A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E5B, 0x1E5B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E5C, 0x1E5C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E5D, 0x1E5D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E5E, 0x1E5E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E5F, 0x1E5F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E60, 0x1E60, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E61, 0x1E61, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E62, 0x1E62, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E63, 0x1E63, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E64, 0x1E64, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E65, 0x1E65, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E66, 0x1E66, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E67, 0x1E67, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E68, 0x1E68, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E69, 0x1E69, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E6A, 0x1E6A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E6B, 0x1E6B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E6C, 0x1E6C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E6D, 0x1E6D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E6E, 0x1E6E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E6F, 0x1E6F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E70, 0x1E70, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E71, 0x1E71, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E72, 0x1E72, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E73, 0x1E73, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E74, 0x1E74, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E75, 0x1E75, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E76, 0x1E76, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E77, 0x1E77, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E78, 0x1E78, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E79, 0x1E79, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E7A, 0x1E7A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E7B, 0x1E7B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E7C, 0x1E7C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E7D, 0x1E7D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E7E, 0x1E7E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E7F, 0x1E7F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E80, 0x1E80, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E81, 0x1E81, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E82, 0x1E82, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E83, 0x1E83, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E84, 0x1E84, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E85, 0x1E85, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E86, 0x1E86, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E87, 0x1E87, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E88, 0x1E88, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E89, 0x1E89, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E8A, 0x1E8A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E8B, 0x1E8B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E8C, 0x1E8C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E8D, 0x1E8D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E8E, 0x1E8E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E8F, 0x1E8F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E90, 0x1E90, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E91, 0x1E91, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E92, 0x1E92, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E93, 0x1E93, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E94, 0x1E94, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E95, 0x1E9D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E9E, 0x1E9E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E9F, 0x1E9F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EA0, 0x1EA0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EA1, 0x1EA1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EA2, 0x1EA2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EA3, 0x1EA3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EA4, 0x1EA4, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EA5, 0x1EA5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EA6, 0x1EA6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EA7, 0x1EA7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EA8, 0x1EA8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EA9, 0x1EA9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EAA, 0x1EAA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EAB, 0x1EAB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EAC, 0x1EAC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EAD, 0x1EAD, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EAE, 0x1EAE, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EAF, 0x1EAF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EB0, 0x1EB0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EB1, 0x1EB1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EB2, 0x1EB2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EB3, 0x1EB3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EB4, 0x1EB4, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EB5, 0x1EB5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EB6, 0x1EB6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EB7, 0x1EB7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EB8, 0x1EB8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EB9, 0x1EB9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EBA, 0x1EBA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EBB, 0x1EBB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EBC, 0x1EBC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EBD, 0x1EBD, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EBE, 0x1EBE, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EBF, 0x1EBF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EC0, 0x1EC0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EC1, 0x1EC1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EC2, 0x1EC2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EC3, 0x1EC3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EC4, 0x1EC4, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EC5, 0x1EC5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EC6, 0x1EC6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EC7, 0x1EC7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EC8, 0x1EC8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EC9, 0x1EC9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ECA, 0x1ECA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ECB, 0x1ECB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ECC, 0x1ECC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ECD, 0x1ECD, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ECE, 0x1ECE, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ECF, 0x1ECF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ED0, 0x1ED0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ED1, 0x1ED1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ED2, 0x1ED2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ED3, 0x1ED3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ED4, 0x1ED4, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ED5, 0x1ED5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ED6, 0x1ED6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ED7, 0x1ED7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1ED8, 0x1ED8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1ED9, 0x1ED9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EDA, 0x1EDA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EDB, 0x1EDB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EDC, 0x1EDC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EDD, 0x1EDD, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EDE, 0x1EDE, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EDF, 0x1EDF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EE0, 0x1EE0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EE1, 0x1EE1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EE2, 0x1EE2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EE3, 0x1EE3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EE4, 0x1EE4, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EE5, 0x1EE5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EE6, 0x1EE6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EE7, 0x1EE7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EE8, 0x1EE8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EE9, 0x1EE9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EEA, 0x1EEA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EEB, 0x1EEB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EEC, 0x1EEC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EED, 0x1EED, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EEE, 0x1EEE, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EEF, 0x1EEF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EF0, 0x1EF0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EF1, 0x1EF1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EF2, 0x1EF2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EF3, 0x1EF3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EF4, 0x1EF4, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EF5, 0x1EF5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EF6, 0x1EF6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EF7, 0x1EF7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EF8, 0x1EF8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EF9, 0x1EF9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EFA, 0x1EFA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EFB, 0x1EFB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EFC, 0x1EFC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EFD, 0x1EFD, G_UNICODE_LOWERCASE_LETTER },
  { 0x1EFE, 0x1EFE, G_UNICODE_UPPERCASE_LETTER },
  { 0x1EFF, 0x1F07, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F08, 0x1F0F, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F10, 0x1F15, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F18, 0x1F1D, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F20, 0x1F27, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F28, 0x1F2F, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F30, 0x1F37, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F38, 0x1F3F, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F40, 0x1F45, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F48, 0x1F4D, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F50, 0x1F57, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F59, 0x1F59, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F5B, 0x1F5B, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F5D, 0x1F5D, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F5F, 0x1F5F, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F60, 0x1F67, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F68, 0x1F6F, G_UNICODE_UPPERCASE_LETTER },
  { 0x1F70, 0x1F7D, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F80, 0x1F87, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F88, 0x1F8F, G_UNICODE_TITLECASE_LETTER },
  { 0x1F90, 0x1F97, G_UNICODE_LOWERCASE_LETTER },
  { 0x1F98, 0x1F9F, G_UNICODE_TITLECASE_LETTER },
  { 0x1FA0, 0x1FA7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FA8, 0x1FAF, G_UNICODE_TITLECASE_LETTER },
  { 0x1FB0, 0x1FB4, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FB6, 0x1FB7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FB8, 0x1FBB, G_UNICODE_UPPERCASE_LETTER },
  { 0x1FBC, 0x1FBC, G_UNICODE_TITLECASE_LETTER },
  { 0x1FBD, 0x1FBD, G_UNICODE_MODIFIER_SYMBOL },
  { 0x1FBE, 0x1FBE, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FBF, 0x1FC1, G_UNICODE_MODIFIER_SYMBOL },
  { 0x1FC2, 0x1FC4, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FC6, 0x1FC7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FC8, 0x1FCB, G_UNICODE_UPPERCASE_LETTER },
  { 0x1FCC, 0x1FCC, G_UNICODE_TITLECASE_LETTER },
  { 0x1FCD, 0x1FCF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x1FD0, 0x1FD3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FD6, 0x1FD7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FD8, 0x1FDB, G_UNICODE_UPPERCASE_LETTER },
  { 0x1FDD, 0x1FDF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x1FE0, 0x1FE7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FE8, 0x1FEC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1FED, 0x1FEF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x1FF2, 0x1FF4, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FF6, 0x1FF7, G_UNICODE_LOWERCASE_LETTER },
  { 0x1FF8, 0x1FFB, G_UNICODE_UPPERCASE_LETTER },
  { 0x1FFC, 0x1FFC, G_UNICODE_TITLECASE_LETTER },
  { 0x1FFD, 0x1FFE, G_UNICODE_MODIFIER_SYMBOL },
  { 0x2000, 0x200A, G_UNICODE_SPACE_SEPARATOR },
  { 0x200B, 0x200F, G_UNICODE_FORMAT },
  { 0x2010, 0x2015, G_UNICODE_DASH_PUNCTUATION },
  { 0x2016, 0x2017, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2018, 0x2018, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2019, 0x2019, G_UNICODE_FINAL_PUNCTUATION },
  { 0x201A, 0x201A, G_UNICODE_OPEN_PUNCTUATION },
  { 0x201B, 0x201C, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x201D, 0x201D, G_UNICODE_FINAL_PUNCTUATION },
  { 0x201E, 0x201E, G_UNICODE_OPEN_PUNCTUATION },
  { 0x201F, 0x201F, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2020, 0x2027, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2028, 0x2028, G_UNICODE_LINE_SEPARATOR },
  { 0x2029, 0x2029, G_UNICODE_PARAGRAPH_SEPARATOR },
  { 0x202A, 0x202E, G_UNICODE_FORMAT },
  { 0x202F, 0x202F, G_UNICODE_SPACE_SEPARATOR },
  { 0x2030, 0x2038, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2039, 0x2039, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x203A, 0x203A, G_UNICODE_FINAL_PUNCTUATION },
  { 0x203B, 0x203E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x203F, 0x2040, G_UNICODE_CONNECT_PUNCTUATION },
  { 0x2041, 0x2043, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2044, 0x2044, G_UNICODE_MATH_SYMBOL },
  { 0x2045, 0x2045, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2046, 0x2046, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2047, 0x2051, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2052, 0x2052, G_UNICODE_MATH_SYMBOL },
  { 0x2053, 0x2053, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2054, 0x2054, G_UNICODE_CONNECT_PUNCTUATION },
  { 0x2055, 0x205E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x205F, 0x205F, G_UNICODE_SPACE_SEPARATOR },
  { 0x2060, 0x2064, G_UNICODE_FORMAT },
  { 0x2066, 0x206F, G_UNICODE_FORMAT },
  { 0x2070, 0x2070, G_UNICODE_OTHER_NUMBER },
  { 0x2071, 0x2071, G_UNICODE_MODIFIER_LETTER },
  { 0x2074, 0x2079, G_UNICODE_OTHER_NUMBER },
  { 0x207A, 0x207C, G_UNICODE_MATH_SYMBOL },
  { 0x207D, 0x207D, G_UNICODE_OPEN_PUNCTUATION },
  { 0x207E, 0x207E, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x207F, 0x207F, G_UNICODE_MODIFIER_LETTER },
  { 0x2080, 0x2089, G_UNICODE_OTHER_NUMBER },
  { 0x208A, 0x208C, G_UNICODE_MATH_SYMBOL },
  { 0x208D, 0x208D, G_UNICODE_OPEN_PUNCTUATION },
  { 0x208E, 0x208E, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2090, 0x209C, G_UNICODE_MODIFIER_LETTER },
  { 0x20A0, 0x20C0, G_UNICODE_CURRENCY_SYMBOL },
  { 0x20D0, 0x20DC, G_UNICODE_NON_SPACING_MARK },
  { 0x20DD, 0x20E0, G_UNICODE_ENCLOSING_MARK },
  { 0x20E1, 0x20E1, G_UNICODE_NON_SPACING_MARK },
  { 0x20E2, 0x20E4, G_UNICODE_ENCLOSING_MARK },
  { 0x20E5, 0x20F0, G_UNICODE_NON_SPACING_MARK },
  { 0x2100, 0x2101, G_UNICODE_OTHER_SYMBOL },
  { 0x2102, 0x2102, G_UNICODE_UPPERCASE_LETTER },
  { 0x2103, 0x2106, G_UNICODE_OTHER_SYMBOL },
  { 0x2107, 0x2107, G_UNICODE_UPPERCASE_LETTER },
  { 0x2108, 0x2109, G_UNICODE_OTHER_SYMBOL },
  { 0x210A, 0x210A, G_UNICODE_LOWERCASE_LETTER },
  { 0x210B, 0x210D, G_UNICODE_UPPERCASE_LETTER },
  { 0x210E, 0x210F, G_UNICODE_LOWERCASE_LETTER },
  { 0x2110, 0x2112, G_UNICODE_UPPERCASE_LETTER },
  { 0x2113, 0x2113, G_UNICODE_LOWERCASE_LETTER },
  { 0x2114, 0x2114, G_UNICODE_OTHER_SYMBOL },
  { 0x2115, 0x2115, G_UNICODE_UPPERCASE_LETTER },
  { 0x2116, 0x2117, G_UNICODE_OTHER_SYMBOL },
  { 0x2118, 0x2118, G_UNICODE_MATH_SYMBOL },
  { 0x2119, 0x211D, G_UNICODE_UPPERCASE_LETTER },
  { 0x211E, 0x2123, G_UNICODE_OTHER_SYMBOL },
  { 0x2124, 0x2124, G_UNICODE_UPPERCASE_LETTER },
  { 0x2125, 0x2125, G_UNICODE_OTHER_SYMBOL },
  { 0x2126, 0x2126, G_UNICODE_UPPERCASE_LETTER },
  { 0x2127, 0x2127, G_UNICODE_OTHER_SYMBOL },
  { 0x2128, 0x2128, G_UNICODE_UPPERCASE_LETTER },
  { 0x2129, 0x2129, G_UNICODE_OTHER_SYMBOL },
  { 0x212A, 0x212D, G_UNICODE_UPPERCASE_LETTER },
  { 0x212E, 0x212E, G_UNICODE_OTHER_SYMBOL },
  { 0x212F, 0x212F, G_UNICODE_LOWERCASE_LETTER },
  { 0x2130, 0x2133, G_UNICODE_UPPERCASE_LETTER },
  { 0x2134, 0x2134, G_UNICODE_LOWERCASE_LETTER },
  { 0x2135, 0x2138, G_UNICODE_OTHER_LETTER },
  { 0x2139, 0x2139, G_UNICODE_LOWERCASE_LETTER },
  { 0x213A, 0x213B, G_UNICODE_OTHER_SYMBOL },
  { 0x213C, 0x213D, G_UNICODE_LOWERCASE_LETTER },
  { 0x213E, 0x213F, G_UNICODE_UPPERCASE_LETTER },
  { 0x2140, 0x2144, G_UNICODE_MATH_SYMBOL },
  { 0x2145, 0x2145, G_UNICODE_UPPERCASE_LETTER },
  { 0x2146, 0x2149, G_UNICODE_LOWERCASE_LETTER },
  { 0x214A, 0x214A, G_UNICODE_OTHER_SYMBOL },
  { 0x214B, 0x214B, G_UNICODE_MATH_SYMBOL },
  { 0x214C, 0x214D, G_UNICODE_OTHER_SYMBOL },
  { 0x214E, 0x214E, G_UNICODE_LOWERCASE_LETTER },
  { 0x214F, 0x214F, G_UNICODE_OTHER_SYMBOL },
  { 0x2150, 0x215F, G_UNICODE_OTHER_NUMBER },
  { 0x2160, 0x2182, G_UNICODE_LETTER_NUMBER },
  { 0x2183, 0x2183, G_UNICODE_UPPERCASE_LETTER },
  { 0x2184, 0x2184, G_UNICODE_LOWERCASE_LETTER },
  { 0x2185, 0x2188, G_UNICODE_LETTER_NUMBER },
  { 0x2189, 0x2189, G_UNICODE_OTHER_NUMBER },
  { 0x218A, 0x218B, G_UNICODE_OTHER_SYMBOL },
  { 0x2190, 0x2194, G_UNICODE_MATH_SYMBOL },
  { 0x2195, 0x2199, G_UNICODE_OTHER_SYMBOL },
  { 0x219A, 0x219B, G_UNICODE_MATH_SYMBOL },
  { 0x219C, 0x219F, G_UNICODE_OTHER_SYMBOL },
  { 0x21A0, 0x21A0, G_UNICODE_MATH_SYMBOL },
  { 0x21A1, 0x21A2, G_UNICODE_OTHER_SYMBOL },
  { 0x21A3, 0x21A3, G_UNICODE_MATH_SYMBOL },
  { 0x21A4, 0x21A5, G_UNICODE_OTHER_SYMBOL },
  { 0x21A6, 0x21A6, G_UNICODE_MATH_SYMBOL },
  { 0x21A7, 0x21AD, G_UNICODE_OTHER_SYMBOL },
  { 0x21AE, 0x21AE, G_UNICODE_MATH_SYMBOL },
  { 0x21AF, 0x21CD, G_UNICODE_OTHER_SYMBOL },
  { 0x21CE, 0x21CF, G_UNICODE_MATH_SYMBOL },
  { 0x21D0, 0x21D1, G_UNICODE_OTHER_SYMBOL },
  { 0x21D2, 0x21D2, G_UNICODE_MATH_SYMBOL },
  { 0x21D3, 0x21D3, G_UNICODE_OTHER_SYMBOL },
  { 0x21D4, 0x21D4, G_UNICODE_MATH_SYMBOL },
  { 0x21D5, 0x21F3, G_UNICODE_OTHER_SYMBOL },
  { 0x21F4, 0x22FF, G_UNICODE_MATH_SYMBOL },
  { 0x2300, 0x2307, G_UNICODE_OTHER_SYMBOL },
  { 0x2308, 0x2308, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2309, 0x2309, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x230A, 0x230A, G_UNICODE_OPEN_PUNCTUATION },
  { 0x230B, 0x230B, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x230C, 0x231F, G_UNICODE_OTHER_SYMBOL },
  { 0x2320, 0x2321, G_UNICODE_MATH_SYMBOL },
  { 0x2322, 0x2328, G_UNICODE_OTHER_SYMBOL },
  { 0x2329, 0x2329, G_UNICODE_OPEN_PUNCTUATION },
  { 0x232A, 0x232A, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x232B, 0x237B, G_UNICODE_OTHER_SYMBOL },
  { 0x237C, 0x237C, G_UNICODE_MATH_SYMBOL },
  { 0x237D, 0x239A, G_UNICODE_OTHER_SYMBOL },
  { 0x239B, 0x23B3, G_UNICODE_MATH_SYMBOL },
  { 0x23B4, 0x23DB, G_UNICODE_OTHER_SYMBOL },
  { 0x23DC, 0x23E1, G_UNICODE_MATH_SYMBOL },
  { 0x23E2, 0x2429, G_UNICODE_OTHER_SYMBOL },
  { 0x2440, 0x244A, G_UNICODE_OTHER_SYMBOL },
  { 0x2460, 0x249B, G_UNICODE_OTHER_NUMBER },
  { 0x249C, 0x24E9, G_UNICODE_OTHER_SYMBOL },
  { 0x24EA, 0x24FF, G_UNICODE_OTHER_NUMBER },
  { 0x2500, 0x25B6, G_UNICODE_OTHER_SYMBOL },
  { 0x25B7, 0x25B7, G_UNICODE_MATH_SYMBOL },
  { 0x25B8, 0x25C0, G_UNICODE_OTHER_SYMBOL },
  { 0x25C1, 0x25C1, G_UNICODE_MATH_SYMBOL },
  { 0x25C2, 0x25F7, G_UNICODE_OTHER_SYMBOL },
  { 0x25F8, 0x25FF, G_UNICODE_MATH_SYMBOL },
  { 0x2600, 0x266E, G_UNICODE_OTHER_SYMBOL },
  { 0x266F, 0x266F, G_UNICODE_MATH_SYMBOL },
  { 0x2670, 0x2767, G_UNICODE_OTHER_SYMBOL },
  { 0x2768, 0x2768, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2769, 0x2769, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x276A, 0x276A, G_UNICODE_OPEN_PUNCTUATION },
  { 0x276B, 0x276B, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x276C, 0x276C, G_UNICODE_OPEN_PUNCTUATION },
  { 0x276D, 0x276D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x276E, 0x276E, G_UNICODE_OPEN_PUNCTUATION },
  { 0x276F, 0x276F, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2770, 0x2770, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2771, 0x2771, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2772, 0x2772, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2773, 0x2773, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2774, 0x2774, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2775, 0x2775, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2776, 0x2793, G_UNICODE_OTHER_NUMBER },
  { 0x2794, 0x27BF, G_UNICODE_OTHER_SYMBOL },
  { 0x27C0, 0x27C4, G_UNICODE_MATH_SYMBOL },
  { 0x27C5, 0x27C5, G_UNICODE_OPEN_PUNCTUATION },
  { 0x27C6, 0x27C6, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x27C7, 0x27E5, G_UNICODE_MATH_SYMBOL },
  { 0x27E6, 0x27E6, G_UNICODE_OPEN_PUNCTUATION },
  { 0x27E7, 0x27E7, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x27E8, 0x27E8, G_UNICODE_OPEN_PUNCTUATION },
  { 0x27E9, 0x27E9, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x27EA, 0x27EA, G_UNICODE_OPEN_PUNCTUATION },
  { 0x27EB, 0x27EB, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x27EC, 0x27EC, G_UNICODE_OPEN_PUNCTUATION },
  { 0x27ED, 0x27ED, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x27EE, 0x27EE, G_UNICODE_OPEN_PUNCTUATION },
  { 0x27EF, 0x27EF, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x27F0, 0x27FF, G_UNICODE_MATH_SYMBOL },
  { 0x2800, 0x28FF, G_UNICODE_OTHER_SYMBOL },
  { 0x2900, 0x2982, G_UNICODE_MATH_SYMBOL },
  { 0x2983, 0x2983, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2984, 0x2984, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2985, 0x2985, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2986, 0x2986, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2987, 0x2987, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2988, 0x2988, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2989, 0x2989, G_UNICODE_OPEN_PUNCTUATION },
  { 0x298A, 0x298A, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x298B, 0x298B, G_UNICODE_OPEN_PUNCTUATION },
  { 0x298C, 0x298C, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x298D, 0x298D, G_UNICODE_OPEN_PUNCTUATION },
  { 0x298E, 0x298E, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x298F, 0x298F, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2990, 0x2990, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2991, 0x2991, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2992, 0x2992, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2993, 0x2993, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2994, 0x2994, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2995, 0x2995, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2996, 0x2996, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2997, 0x2997, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2998, 0x2998, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2999, 0x29D7, G_UNICODE_MATH_SYMBOL },
  { 0x29D8, 0x29D8, G_UNICODE_OPEN_PUNCTUATION },
  { 0x29D9, 0x29D9, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x29DA, 0x29DA, G_UNICODE_OPEN_PUNCTUATION },
  { 0x29DB, 0x29DB, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x29DC, 0x29FB, G_UNICODE_MATH_SYMBOL },
  { 0x29FC, 0x29FC, G_UNICODE_OPEN_PUNCTUATION },
  { 0x29FD, 0x29FD, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x29FE, 0x2AFF, G_UNICODE_MATH_SYMBOL },
  { 0x2B00, 0x2B2F, G_UNICODE_OTHER_SYMBOL },
  { 0x2B30, 0x2B44, G_UNICODE_MATH_SYMBOL },
  { 0x2B45, 0x2B46, G_UNICODE_OTHER_SYMBOL },
  { 0x2B47, 0x2B4C, G_UNICODE_MATH_SYMBOL },
  { 0x2B4D, 0x2B73, G_UNICODE_OTHER_SYMBOL },
  { 0x2B76, 0x2B95, G_UNICODE_OTHER_SYMBOL },
  { 0x2B97, 0x2BFF, G_UNICODE_OTHER_SYMBOL },
  { 0x2C00, 0x2C2F, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C30, 0x2C5F, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C60, 0x2C60, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C61, 0x2C61, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C62, 0x2C64, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C65, 0x2C66, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C67, 0x2C67, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C68, 0x2C68, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C69, 0x2C69, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C6A, 0x2C6A, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C6B, 0x2C6B, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C6C, 0x2C6C, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C6D, 0x2C70, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C71, 0x2C71, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C72, 0x2C72, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C73, 0x2C74, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C75, 0x2C75, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C76, 0x2C7B, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C7C, 0x2C7D, G_UNICODE_MODIFIER_LETTER },
  { 0x2C7E, 0x2C80, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C81, 0x2C81, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C82, 0x2C82, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C83, 0x2C83, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C84, 0x2C84, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C85, 0x2C85, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C86, 0x2C86, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C87, 0x2C87, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C88, 0x2C88, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C89, 0x2C89, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C8A, 0x2C8A, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C8B, 0x2C8B, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C8C, 0x2C8C, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C8D, 0x2C8D, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C8E, 0x2C8E, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C8F, 0x2C8F, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C90, 0x2C90, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C91, 0x2C91, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C92, 0x2C92, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C93, 0x2C93, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C94, 0x2C94, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C95, 0x2C95, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C96, 0x2C96, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C97, 0x2C97, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C98, 0x2C98, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C99, 0x2C99, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C9A, 0x2C9A, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C9B, 0x2C9B, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C9C, 0x2C9C, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C9D, 0x2C9D, G_UNICODE_LOWERCASE_LETTER },
  { 0x2C9E, 0x2C9E, G_UNICODE_UPPERCASE_LETTER },
  { 0x2C9F, 0x2C9F, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CA0, 0x2CA0, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CA1, 0x2CA1, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CA2, 0x2CA2, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CA3, 0x2CA3, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CA4, 0x2CA4, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CA5, 0x2CA5, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CA6, 0x2CA6, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CA7, 0x2CA7, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CA8, 0x2CA8, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CA9, 0x2CA9, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CAA, 0x2CAA, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CAB, 0x2CAB, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CAC, 0x2CAC, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CAD, 0x2CAD, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CAE, 0x2CAE, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CAF, 0x2CAF, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CB0, 0x2CB0, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CB1, 0x2CB1, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CB2, 0x2CB2, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CB3, 0x2CB3, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CB4, 0x2CB4, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CB5, 0x2CB5, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CB6, 0x2CB6, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CB7, 0x2CB7, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CB8, 0x2CB8, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CB9, 0x2CB9, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CBA, 0x2CBA, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CBB, 0x2CBB, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CBC, 0x2CBC, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CBD, 0x2CBD, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CBE, 0x2CBE, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CBF, 0x2CBF, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CC0, 0x2CC0, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CC1, 0x2CC1, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CC2, 0x2CC2, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CC3, 0x2CC3, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CC4, 0x2CC4, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CC5, 0x2CC5, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CC6, 0x2CC6, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CC7, 0x2CC7, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CC8, 0x2CC8, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CC9, 0x2CC9, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CCA, 0x2CCA, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CCB, 0x2CCB, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CCC, 0x2CCC, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CCD, 0x2CCD, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CCE, 0x2CCE, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CCF, 0x2CCF, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CD0, 0x2CD0, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CD1, 0x2CD1, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CD2, 0x2CD2, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CD3, 0x2CD3, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CD4, 0x2CD4, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CD5, 0x2CD5, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CD6, 0x2CD6, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CD7, 0x2CD7, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CD8, 0x2CD8, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CD9, 0x2CD9, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CDA, 0x2CDA, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CDB, 0x2CDB, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CDC, 0x2CDC, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CDD, 0x2CDD, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CDE, 0x2CDE, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CDF, 0x2CDF, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CE0, 0x2CE0, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CE1, 0x2CE1, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CE2, 0x2CE2, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CE3, 0x2CE4, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CE5, 0x2CEA, G_UNICODE_OTHER_SYMBOL },
  { 0x2CEB, 0x2CEB, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CEC, 0x2CEC, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CED, 0x2CED, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CEE, 0x2CEE, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CEF, 0x2CF1, G_UNICODE_NON_SPACING_MARK },
  { 0x2CF2, 0x2CF2, G_UNICODE_UPPERCASE_LETTER },
  { 0x2CF3, 0x2CF3, G_UNICODE_LOWERCASE_LETTER },
  { 0x2CF9, 0x2CFC, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2CFD, 0x2CFD, G_UNICODE_OTHER_NUMBER },
  { 0x2CFE, 0x2CFF, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2D00, 0x2D25, G_UNICODE_LOWERCASE_LETTER },
  { 0x2D27, 0x2D27, G_UNICODE_LOWERCASE_LETTER },
  { 0x2D2D, 0x2D2D, G_UNICODE_LOWERCASE_LETTER },
  { 0x2D30, 0x2D67, G_UNICODE_OTHER_LETTER },
  { 0x2D6F, 0x2D6F, G_UNICODE_MODIFIER_LETTER },
  { 0x2D70, 0x2D70, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2D7F, 0x2D7F, G_UNICODE_NON_SPACING_MARK },
  { 0x2D80, 0x2D96, G_UNICODE_OTHER_LETTER },
  { 0x2DA0, 0x2DA6, G_UNICODE_OTHER_LETTER },
  { 0x2DA8, 0x2DAE, G_UNICODE_OTHER_LETTER },
  { 0x2DB0, 0x2DB6, G_UNICODE_OTHER_LETTER },
  { 0x2DB8, 0x2DBE, G_UNICODE_OTHER_LETTER },
  { 0x2DC0, 0x2DC6, G_UNICODE_OTHER_LETTER },
  { 0x2DC8, 0x2DCE, G_UNICODE_OTHER_LETTER },
  { 0x2DD0, 0x2DD6, G_UNICODE_OTHER_LETTER },
  { 0x2DD8, 0x2DDE, G_UNICODE_OTHER_LETTER },
  { 0x2DE0, 0x2DFF, G_UNICODE_NON_SPACING_MARK },
  { 0x2E00, 0x2E01, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E02, 0x2E02, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2E03, 0x2E03, G_UNICODE_FINAL_PUNCTUATION },
  { 0x2E04, 0x2E04, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2E05, 0x2E05, G_UNICODE_FINAL_PUNCTUATION },
  { 0x2E06, 0x2E08, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E09, 0x2E09, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2E0A, 0x2E0A, G_UNICODE_FINAL_PUNCTUATION },
  { 0x2E0B, 0x2E0B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E0C, 0x2E0C, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2E0D, 0x2E0D, G_UNICODE_FINAL_PUNCTUATION },
  { 0x2E0E, 0x2E16, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E17, 0x2E17, G_UNICODE_DASH_PUNCTUATION },
  { 0x2E18, 0x2E19, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E1A, 0x2E1A, G_UNICODE_DASH_PUNCTUATION },
  { 0x2E1B, 0x2E1B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E1C, 0x2E1C, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2E1D, 0x2E1D, G_UNICODE_FINAL_PUNCTUATION },
  { 0x2E1E, 0x2E1F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E20, 0x2E20, G_UNICODE_INITIAL_PUNCTUATION },
  { 0x2E21, 0x2E21, G_UNICODE_FINAL_PUNCTUATION },
  { 0x2E22, 0x2E22, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E23, 0x2E23, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E24, 0x2E24, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E25, 0x2E25, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E26, 0x2E26, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E27, 0x2E27, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E28, 0x2E28, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E29, 0x2E29, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E2A, 0x2E2E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E2F, 0x2E2F, G_UNICODE_MODIFIER_LETTER },
  { 0x2E30, 0x2E39, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E3A, 0x2E3B, G_UNICODE_DASH_PUNCTUATION },
  { 0x2E3C, 0x2E3F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E40, 0x2E40, G_UNICODE_DASH_PUNCTUATION },
  { 0x2E41, 0x2E41, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E42, 0x2E42, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E43, 0x2E4F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E50, 0x2E51, G_UNICODE_OTHER_SYMBOL },
  { 0x2E52, 0x2E54, G_UNICODE_OTHER_PUNCTUATION },
  { 0x2E55, 0x2E55, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E56, 0x2E56, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E57, 0x2E57, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E58, 0x2E58, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E59, 0x2E59, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E5A, 0x2E5A, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E5B, 0x2E5B, G_UNICODE_OPEN_PUNCTUATION },
  { 0x2E5C, 0x2E5C, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x2E5D, 0x2E5D, G_UNICODE_DASH_PUNCTUATION },
  { 0x2E80, 0x2E99, G_UNICODE_OTHER_SYMBOL },
  { 0x2E9B, 0x2EF3, G_UNICODE_OTHER_SYMBOL },
  { 0x2F00, 0x2FD5, G_UNICODE_OTHER_SYMBOL },
  { 0x2FF0, 0x2FFF, G_UNICODE_OTHER_SYMBOL },
  { 0x3000, 0x3000, G_UNICODE_SPACE_SEPARATOR },
  { 0x3001, 0x3003, G_UNICODE_OTHER_PUNCTUATION },
  { 0x3004, 0x3004, G_UNICODE_OTHER_SYMBOL },
  { 0x3005, 0x3005, G_UNICODE_MODIFIER_LETTER },
  { 0x3006, 0x3006, G_UNICODE_OTHER_LETTER },
  { 0x3007, 0x3007, G_UNICODE_LETTER_NUMBER },
  { 0x3008, 0x3008, G_UNICODE_OPEN_PUNCTUATION },
  { 0x3009, 0x3009, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x300A, 0x300A, G_UNICODE_OPEN_PUNCTUATION },
  { 0x300B, 0x300B, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x300C, 0x300C, G_UNICODE_OPEN_PUNCTUATION },
  { 0x300D, 0x300D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x300E, 0x300E, G_UNICODE_OPEN_PUNCTUATION },
  { 0x300F, 0x300F, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x3010, 0x3010, G_UNICODE_OPEN_PUNCTUATION },
  { 0x3011, 0x3011, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x3012, 0x3013, G_UNICODE_OTHER_SYMBOL },
  { 0x3014, 0x3014, G_UNICODE_OPEN_PUNCTUATION },
  { 0x3015, 0x3015, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x3016, 0x3016, G_UNICODE_OPEN_PUNCTUATION },
  { 0x3017, 0x3017, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x3018, 0x3018, G_UNICODE_OPEN_PUNCTUATION },
  { 0x3019, 0x3019, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x301A, 0x301A, G_UNICODE_OPEN_PUNCTUATION },
  { 0x301B, 0x301B, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x301C, 0x301C, G_UNICODE_DASH_PUNCTUATION },
  { 0x301D, 0x301D, G_UNICODE_OPEN_PUNCTUATION },
  { 0x301E, 0x301F, G_UNICODE_CLOSE_PUNCTUATION },
  { 0x3020, 0x3020, G_UNICODE_OTHER_SYMBOL },
  { 0x3021, 0x3029, G_UNICODE_LETTER_NUMBER },
  { 0x302A, 0x302D, G_UNICODE_NON_SPACING_MARK },
  { 0x302E, 0x302F, G_UNICODE_SPACING_MARK },
  { 0x3030, 0x3030, G_UNICODE_DASH_PUNCTUATION },
  { 0x3031, 0x3035, G_UNICODE_MODIFIER_LETTER },
  { 0x3036, 0x3037, G_UNICODE_OTHER_SYMBOL },
  { 0x3038, 0x303A, G_UNICODE_LETTER_NUMBER },
  { 0x303B, 0x303B, G_UNICODE_MODIFIER_LETTER },
  { 0x303C, 0x303C, G_UNICODE_OTHER_LETTER },
  { 0x303D, 0x303D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x303E, 0x303F, G_UNICODE_OTHER_SYMBOL },
  { 0x3041, 0x3096, G_UNICODE_OTHER_LETTER },
  { 0x3099, 0x309A, G_UNICODE_NON_SPACING_MARK },
  { 0x309B, 0x309C, G_UNICODE_MODIFIER_SYMBOL },
  { 0x309D, 0x309E, G_UNICODE_MODIFIER_LETTER },
  { 0x309F, 0x309F, G_UNICODE_OTHER_LETTER },
  { 0x30A0, 0x30A0, G_UNICODE_DASH_PUNCTUATION },
  { 0x30A1, 0x30FA, G_UNICODE_OTHER_LETTER },
  { 0x30FB, 0x30FB, G_UNICODE_OTHER_PUNCTUATION },
  { 0x30FC, 0x30FE, G_UNICODE_MODIFIER_LETTER },
  { 0x30FF, 0x30FF, G_UNICODE_OTHER_LETTER },
  { 0x3105, 0x312F, G_UNICODE_OTHER_LETTER },
  { 0x3131, 0x318E, G_UNICODE_OTHER_LETTER },
  { 0x3190, 0x3191, G_UNICODE_OTHER_SYMBOL },
  { 0x3192, 0x3195, G_UNICODE_OTHER_NUMBER },
  { 0x3196, 0x319F, G_UNICODE_OTHER_SYMBOL },
  { 0x31A0, 0x31BF, G_UNICODE_OTHER_LETTER },
  { 0x31C0, 0x31E5, G_UNICODE_OTHER_SYMBOL },
  { 0x31EF, 0x31EF, G_UNICODE_OTHER_SYMBOL },
  { 0x31F0, 0x31FF, G_UNICODE_OTHER_LETTER },
  { 0x3200, 0x321E, G_UNICODE_OTHER_SYMBOL },
  { 0x3220, 0x3229, G_UNICODE_OTHER_NUMBER },
  { 0x322A, 0x3247, G_UNICODE_OTHER_SYMBOL },
  { 0x3248, 0x324F, G_UNICODE_OTHER_NUMBER },
  { 0x3250, 0x3250, G_UNICODE_OTHER_SYMBOL },
  { 0x3251, 0x325F, G_UNICODE_OTHER_NUMBER },
  { 0x3260, 0x327F, G_UNICODE_OTHER_SYMBOL },
  { 0x3280, 0x3289, G_UNICODE_OTHER_NUMBER },
  { 0x328A, 0x32B0, G_UNICODE_OTHER_SYMBOL },
  { 0x32B1, 0x32BF, G_UNICODE_OTHER_NUMBER },
  { 0x32C0, 0x33FF, G_UNICODE_OTHER_SYMBOL },
  { 0x3400, 0x4DBF, G_UNICODE_OTHER_LETTER },
  { 0x4DC0, 0x4DFF, G_UNICODE_OTHER_SYMBOL },
  { 0x4E00, 0x9FFF, G_UNICODE_OTHER_LETTER },
  { 0xA000, 0xA014, G_UNICODE_OTHER_LETTER },
  { 0xA015, 0xA015, G_UNICODE_MODIFIER_LETTER },
  { 0xA016, 0xA48C, G_UNICODE_OTHER_LETTER },
  { 0xA490, 0xA4C6, G_UNICODE_OTHER_SYMBOL },
  { 0xA4D0, 0xA4F7, G_UNICODE_OTHER_LETTER },
  { 0xA4F8, 0xA4FD, G_UNICODE_MODIFIER_LETTER },
  { 0xA4FE, 0xA4FF, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA500, 0xA60B, G_UNICODE_OTHER_LETTER },
  { 0xA60C, 0xA60C, G_UNICODE_MODIFIER_LETTER },
  { 0xA60D, 0xA60F, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA610, 0xA61F, G_UNICODE_OTHER_LETTER },
  { 0xA620, 0xA629, G_UNICODE_DECIMAL_NUMBER },
  { 0xA62A, 0xA62B, G_UNICODE_OTHER_LETTER },
  { 0xA640, 0xA640, G_UNICODE_UPPERCASE_LETTER },
  { 0xA641, 0xA641, G_UNICODE_LOWERCASE_LETTER },
  { 0xA642, 0xA642, G_UNICODE_UPPERCASE_LETTER },
  { 0xA643, 0xA643, G_UNICODE_LOWERCASE_LETTER },
  { 0xA644, 0xA644, G_UNICODE_UPPERCASE_LETTER },
  { 0xA645, 0xA645, G_UNICODE_LOWERCASE_LETTER },
  { 0xA646, 0xA646, G_UNICODE_UPPERCASE_LETTER },
  { 0xA647, 0xA647, G_UNICODE_LOWERCASE_LETTER },
  { 0xA648, 0xA648, G_UNICODE_UPPERCASE_LETTER },
  { 0xA649, 0xA649, G_UNICODE_LOWERCASE_LETTER },
  { 0xA64A, 0xA64A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA64B, 0xA64B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA64C, 0xA64C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA64D, 0xA64D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA64E, 0xA64E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA64F, 0xA64F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA650, 0xA650, G_UNICODE_UPPERCASE_LETTER },
  { 0xA651, 0xA651, G_UNICODE_LOWERCASE_LETTER },
  { 0xA652, 0xA652, G_UNICODE_UPPERCASE_LETTER },
  { 0xA653, 0xA653, G_UNICODE_LOWERCASE_LETTER },
  { 0xA654, 0xA654, G_UNICODE_UPPERCASE_LETTER },
  { 0xA655, 0xA655, G_UNICODE_LOWERCASE_LETTER },
  { 0xA656, 0xA656, G_UNICODE_UPPERCASE_LETTER },
  { 0xA657, 0xA657, G_UNICODE_LOWERCASE_LETTER },
  { 0xA658, 0xA658, G_UNICODE_UPPERCASE_LETTER },
  { 0xA659, 0xA659, G_UNICODE_LOWERCASE_LETTER },
  { 0xA65A, 0xA65A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA65B, 0xA65B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA65C, 0xA65C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA65D, 0xA65D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA65E, 0xA65E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA65F, 0xA65F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA660, 0xA660, G_UNICODE_UPPERCASE_LETTER },
  { 0xA661, 0xA661, G_UNICODE_LOWERCASE_LETTER },
  { 0xA662, 0xA662, G_UNICODE_UPPERCASE_LETTER },
  { 0xA663, 0xA663, G_UNICODE_LOWERCASE_LETTER },
  { 0xA664, 0xA664, G_UNICODE_UPPERCASE_LETTER },
  { 0xA665, 0xA665, G_UNICODE_LOWERCASE_LETTER },
  { 0xA666, 0xA666, G_UNICODE_UPPERCASE_LETTER },
  { 0xA667, 0xA667, G_UNICODE_LOWERCASE_LETTER },
  { 0xA668, 0xA668, G_UNICODE_UPPERCASE_LETTER },
  { 0xA669, 0xA669, G_UNICODE_LOWERCASE_LETTER },
  { 0xA66A, 0xA66A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA66B, 0xA66B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA66C, 0xA66C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA66D, 0xA66D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA66E, 0xA66E, G_UNICODE_OTHER_LETTER },
  { 0xA66F, 0xA66F, G_UNICODE_NON_SPACING_MARK },
  { 0xA670, 0xA672, G_UNICODE_ENCLOSING_MARK },
  { 0xA673, 0xA673, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA674, 0xA67D, G_UNICODE_NON_SPACING_MARK },
  { 0xA67E, 0xA67E, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA67F, 0xA67F, G_UNICODE_MODIFIER_LETTER },
  { 0xA680, 0xA680, G_UNICODE_UPPERCASE_LETTER },
  { 0xA681, 0xA681, G_UNICODE_LOWERCASE_LETTER },
  { 0xA682, 0xA682, G_UNICODE_UPPERCASE_LETTER },
  { 0xA683, 0xA683, G_UNICODE_LOWERCASE_LETTER },
  { 0xA684, 0xA684, G_UNICODE_UPPERCASE_LETTER },
  { 0xA685, 0xA685, G_UNICODE_LOWERCASE_LETTER },
  { 0xA686, 0xA686, G_UNICODE_UPPERCASE_LETTER },
  { 0xA687, 0xA687, G_UNICODE_LOWERCASE_LETTER },
  { 0xA688, 0xA688, G_UNICODE_UPPERCASE_LETTER },
  { 0xA689, 0xA689, G_UNICODE_LOWERCASE_LETTER },
  { 0xA68A, 0xA68A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA68B, 0xA68B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA68C, 0xA68C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA68D, 0xA68D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA68E, 0xA68E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA68F, 0xA68F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA690, 0xA690, G_UNICODE_UPPERCASE_LETTER },
  { 0xA691, 0xA691, G_UNICODE_LOWERCASE_LETTER },
  { 0xA692, 0xA692, G_UNICODE_UPPERCASE_LETTER },
  { 0xA693, 0xA693, G_UNICODE_LOWERCASE_LETTER },
  { 0xA694, 0xA694, G_UNICODE_UPPERCASE_LETTER },
  { 0xA695, 0xA695, G_UNICODE_LOWERCASE_LETTER },
  { 0xA696, 0xA696, G_UNICODE_UPPERCASE_LETTER },
  { 0xA697, 0xA697, G_UNICODE_LOWERCASE_LETTER },
  { 0xA698, 0xA698, G_UNICODE_UPPERCASE_LETTER },
  { 0xA699, 0xA699, G_UNICODE_LOWERCASE_LETTER },
  { 0xA69A, 0xA69A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA69B, 0xA69B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA69C, 0xA69D, G_UNICODE_MODIFIER_LETTER },
  { 0xA69E, 0xA69F, G_UNICODE_NON_SPACING_MARK },
  { 0xA6A0, 0xA6E5, G_UNICODE_OTHER_LETTER },
  { 0xA6E6, 0xA6EF, G_UNICODE_LETTER_NUMBER },
  { 0xA6F0, 0xA6F1, G_UNICODE_NON_SPACING_MARK },
  { 0xA6F2, 0xA6F7, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA700, 0xA716, G_UNICODE_MODIFIER_SYMBOL },
  { 0xA717, 0xA71F, G_UNICODE_MODIFIER_LETTER },
  { 0xA720, 0xA721, G_UNICODE_MODIFIER_SYMBOL },
  { 0xA722, 0xA722, G_UNICODE_UPPERCASE_LETTER },
  { 0xA723, 0xA723, G_UNICODE_LOWERCASE_LETTER },
  { 0xA724, 0xA724, G_UNICODE_UPPERCASE_LETTER },
  { 0xA725, 0xA725, G_UNICODE_LOWERCASE_LETTER },
  { 0xA726, 0xA726, G_UNICODE_UPPERCASE_LETTER },
  { 0xA727, 0xA727, G_UNICODE_LOWERCASE_LETTER },
  { 0xA728, 0xA728, G_UNICODE_UPPERCASE_LETTER },
  { 0xA729, 0xA729, G_UNICODE_LOWERCASE_LETTER },
  { 0xA72A, 0xA72A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA72B, 0xA72B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA72C, 0xA72C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA72D, 0xA72D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA72E, 0xA72E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA72F, 0xA731, G_UNICODE_LOWERCASE_LETTER },
  { 0xA732, 0xA732, G_UNICODE_UPPERCASE_LETTER },
  { 0xA733, 0xA733, G_UNICODE_LOWERCASE_LETTER },
  { 0xA734, 0xA734, G_UNICODE_UPPERCASE_LETTER },
  { 0xA735, 0xA735, G_UNICODE_LOWERCASE_LETTER },
  { 0xA736, 0xA736, G_UNICODE_UPPERCASE_LETTER },
  { 0xA737, 0xA737, G_UNICODE_LOWERCASE_LETTER },
  { 0xA738, 0xA738, G_UNICODE_UPPERCASE_LETTER },
  { 0xA739, 0xA739, G_UNICODE_LOWERCASE_LETTER },
  { 0xA73A, 0xA73A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA73B, 0xA73B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA73C, 0xA73C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA73D, 0xA73D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA73E, 0xA73E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA73F, 0xA73F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA740, 0xA740, G_UNICODE_UPPERCASE_LETTER },
  { 0xA741, 0xA741, G_UNICODE_LOWERCASE_LETTER },
  { 0xA742, 0xA742, G_UNICODE_UPPERCASE_LETTER },
  { 0xA743, 0xA743, G_UNICODE_LOWERCASE_LETTER },
  { 0xA744, 0xA744, G_UNICODE_UPPERCASE_LETTER },
  { 0xA745, 0xA745, G_UNICODE_LOWERCASE_LETTER },
  { 0xA746, 0xA746, G_UNICODE_UPPERCASE_LETTER },
  { 0xA747, 0xA747, G_UNICODE_LOWERCASE_LETTER },
  { 0xA748, 0xA748, G_UNICODE_UPPERCASE_LETTER },
  { 0xA749, 0xA749, G_UNICODE_LOWERCASE_LETTER },
  { 0xA74A, 0xA74A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA74B, 0xA74B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA74C, 0xA74C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA74D, 0xA74D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA74E, 0xA74E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA74F, 0xA74F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA750, 0xA750, G_UNICODE_UPPERCASE_LETTER },
  { 0xA751, 0xA751, G_UNICODE_LOWERCASE_LETTER },
  { 0xA752, 0xA752, G_UNICODE_UPPERCASE_LETTER },
  { 0xA753, 0xA753, G_UNICODE_LOWERCASE_LETTER },
  { 0xA754, 0xA754, G_UNICODE_UPPERCASE_LETTER },
  { 0xA755, 0xA755, G_UNICODE_LOWERCASE_LETTER },
  { 0xA756, 0xA756, G_UNICODE_UPPERCASE_LETTER },
  { 0xA757, 0xA757, G_UNICODE_LOWERCASE_LETTER },
  { 0xA758, 0xA758, G_UNICODE_UPPERCASE_LETTER },
  { 0xA759, 0xA759, G_UNICODE_LOWERCASE_LETTER },
  { 0xA75A, 0xA75A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA75B, 0xA75B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA75C, 0xA75C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA75D, 0xA75D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA75E, 0xA75E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA75F, 0xA75F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA760, 0xA760, G_UNICODE_UPPERCASE_LETTER },
  { 0xA761, 0xA761, G_UNICODE_LOWERCASE_LETTER },
  { 0xA762, 0xA762, G_UNICODE_UPPERCASE_LETTER },
  { 0xA763, 0xA763, G_UNICODE_LOWERCASE_LETTER },
  { 0xA764, 0xA764, G_UNICODE_UPPERCASE_LETTER },
  { 0xA765, 0xA765, G_UNICODE_LOWERCASE_LETTER },
  { 0xA766, 0xA766, G_UNICODE_UPPERCASE_LETTER },
  { 0xA767, 0xA767, G_UNICODE_LOWERCASE_LETTER },
  { 0xA768, 0xA768, G_UNICODE_UPPERCASE_LETTER },
  { 0xA769, 0xA769, G_UNICODE_LOWERCASE_LETTER },
  { 0xA76A, 0xA76A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA76B, 0xA76B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA76C, 0xA76C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA76D, 0xA76D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA76E, 0xA76E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA76F, 0xA76F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA770, 0xA770, G_UNICODE_MODIFIER_LETTER },
  { 0xA771, 0xA778, G_UNICODE_LOWERCASE_LETTER },
  { 0xA779, 0xA779, G_UNICODE_UPPERCASE_LETTER },
  { 0xA77A, 0xA77A, G_UNICODE_LOWERCASE_LETTER },
  { 0xA77B, 0xA77B, G_UNICODE_UPPERCASE_LETTER },
  { 0xA77C, 0xA77C, G_UNICODE_LOWERCASE_LETTER },
  { 0xA77D, 0xA77E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA77F, 0xA77F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA780, 0xA780, G_UNICODE_UPPERCASE_LETTER },
  { 0xA781, 0xA781, G_UNICODE_LOWERCASE_LETTER },
  { 0xA782, 0xA782, G_UNICODE_UPPERCASE_LETTER },
  { 0xA783, 0xA783, G_UNICODE_LOWERCASE_LETTER },
  { 0xA784, 0xA784, G_UNICODE_UPPERCASE_LETTER },
  { 0xA785, 0xA785, G_UNICODE_LOWERCASE_LETTER },
  { 0xA786, 0xA786, G_UNICODE_UPPERCASE_LETTER },
  { 0xA787, 0xA787, G_UNICODE_LOWERCASE_LETTER },
  { 0xA788, 0xA788, G_UNICODE_MODIFIER_LETTER },
  { 0xA789, 0xA78A, G_UNICODE_MODIFIER_SYMBOL },
  { 0xA78B, 0xA78B, G_UNICODE_UPPERCASE_LETTER },
  { 0xA78C, 0xA78C, G_UNICODE_LOWERCASE_LETTER },
  { 0xA78D, 0xA78D, G_UNICODE_UPPERCASE_LETTER },
  { 0xA78E, 0xA78E, G_UNICODE_LOWERCASE_LETTER },
  { 0xA78F, 0xA78F, G_UNICODE_OTHER_LETTER },
  { 0xA790, 0xA790, G_UNICODE_UPPERCASE_LETTER },
  { 0xA791, 0xA791, G_UNICODE_LOWERCASE_LETTER },
  { 0xA792, 0xA792, G_UNICODE_UPPERCASE_LETTER },
  { 0xA793, 0xA795, G_UNICODE_LOWERCASE_LETTER },
  { 0xA796, 0xA796, G_UNICODE_UPPERCASE_LETTER },
  { 0xA797, 0xA797, G_UNICODE_LOWERCASE_LETTER },
  { 0xA798, 0xA798, G_UNICODE_UPPERCASE_LETTER },
  { 0xA799, 0xA799, G_UNICODE_LOWERCASE_LETTER },
  { 0xA79A, 0xA79A, G_UNICODE_UPPERCASE_LETTER },
  { 0xA79B, 0xA79B, G_UNICODE_LOWERCASE_LETTER },
  { 0xA79C, 0xA79C, G_UNICODE_UPPERCASE_LETTER },
  { 0xA79D, 0xA79D, G_UNICODE_LOWERCASE_LETTER },
  { 0xA79E, 0xA79E, G_UNICODE_UPPERCASE_LETTER },
  { 0xA79F, 0xA79F, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7A0, 0xA7A0, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7A1, 0xA7A1, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7A2, 0xA7A2, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7A3, 0xA7A3, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7A4, 0xA7A4, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7A5, 0xA7A5, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7A6, 0xA7A6, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7A7, 0xA7A7, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7A8, 0xA7A8, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7A9, 0xA7A9, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7AA, 0xA7AE, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7AF, 0xA7AF, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7B0, 0xA7B4, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7B5, 0xA7B5, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7B6, 0xA7B6, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7B7, 0xA7B7, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7B8, 0xA7B8, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7B9, 0xA7B9, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7BA, 0xA7BA, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7BB, 0xA7BB, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7BC, 0xA7BC, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7BD, 0xA7BD, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7BE, 0xA7BE, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7BF, 0xA7BF, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7C0, 0xA7C0, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7C1, 0xA7C1, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7C2, 0xA7C2, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7C3, 0xA7C3, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7C4, 0xA7C7, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7C8, 0xA7C8, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7C9, 0xA7C9, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7CA, 0xA7CA, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7CB, 0xA7CC, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7CD, 0xA7CD, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7D0, 0xA7D0, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7D1, 0xA7D1, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7D3, 0xA7D3, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7D5, 0xA7D5, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7D6, 0xA7D6, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7D7, 0xA7D7, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7D8, 0xA7D8, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7D9, 0xA7D9, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7DA, 0xA7DA, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7DB, 0xA7DB, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7DC, 0xA7DC, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7F2, 0xA7F4, G_UNICODE_MODIFIER_LETTER },
  { 0xA7F5, 0xA7F5, G_UNICODE_UPPERCASE_LETTER },
  { 0xA7F6, 0xA7F6, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7F7, 0xA7F7, G_UNICODE_OTHER_LETTER },
  { 0xA7F8, 0xA7F9, G_UNICODE_MODIFIER_LETTER },
  { 0xA7FA, 0xA7FA, G_UNICODE_LOWERCASE_LETTER },
  { 0xA7FB, 0xA801, G_UNICODE_OTHER_LETTER },
  { 0xA802, 0xA802, G_UNICODE_NON_SPACING_MARK },
  { 0xA803, 0xA805, G_UNICODE_OTHER_LETTER },
  { 0xA806, 0xA806, G_UNICODE_NON_SPACING_MARK },
  { 0xA807, 0xA80A, G_UNICODE_OTHER_LETTER },
  { 0xA80B, 0xA80B, G_UNICODE_NON_SPACING_MARK },
  { 0xA80C, 0xA822, G_UNICODE_OTHER_LETTER },
  { 0xA823, 0xA824, G_UNICODE_SPACING_MARK },
  { 0xA825, 0xA826, G_UNICODE_NON_SPACING_MARK },
  { 0xA827, 0xA827, G_UNICODE_SPACING_MARK },
  { 0xA828, 0xA82B, G_UNICODE_OTHER_SYMBOL },
  { 0xA82C, 0xA82C, G_UNICODE_NON_SPACING_MARK },
  { 0xA830, 0xA835, G_UNICODE_OTHER_NUMBER },
  { 0xA836, 0xA837, G_UNICODE_OTHER_SYMBOL },
  { 0xA838, 0xA838, G_UNICODE_CURRENCY_SYMBOL },
  { 0xA839, 0xA839, G_UNICODE_OTHER_SYMBOL },
  { 0xA840, 0xA873, G_UNICODE_OTHER_LETTER },
  { 0xA874, 0xA877, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA880, 0xA881, G_UNICODE_SPACING_MARK },
  { 0xA882, 0xA8B3, G_UNICODE_OTHER_LETTER },
  { 0xA8B4, 0xA8C3, G_UNICODE_SPACING_MARK },
  { 0xA8C4, 0xA8C5, G_UNICODE_NON_SPACING_MARK },
  { 0xA8CE, 0xA8CF, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA8D0, 0xA8D9, G_UNICODE_DECIMAL_NUMBER },
  { 0xA8E0, 0xA8F1, G_UNICODE_NON_SPACING_MARK },
  { 0xA8F2, 0xA8F7, G_UNICODE_OTHER_LETTER },
  { 0xA8F8, 0xA8FA, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA8FB, 0xA8FB, G_UNICODE_OTHER_LETTER },
  { 0xA8FC, 0xA8FC, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA8FD, 0xA8FE, G_UNICODE_OTHER_LETTER },
  { 0xA8FF, 0xA8FF, G_UNICODE_NON_SPACING_MARK },
  { 0xA900, 0xA909, G_UNICODE_DECIMAL_NUMBER },
  { 0xA90A, 0xA925, G_UNICODE_OTHER_LETTER },
  { 0xA926, 0xA92D, G_UNICODE_NON_SPACING_MARK },
  { 0xA92E, 0xA92F, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA930, 0xA946, G_UNICODE_OTHER_LETTER },
  { 0xA947, 0xA951, G_UNICODE_NON_SPACING_MARK },
  { 0xA952, 0xA953, G_UNICODE_SPACING_MARK },
  { 0xA95F, 0xA95F, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA960, 0xA97C, G_UNICODE_OTHER_LETTER },
  { 0xA980, 0xA982, G_UNICODE_NON_SPACING_MARK },
  { 0xA983, 0xA983, G_UNICODE_SPACING_MARK },
  { 0xA984, 0xA9B2, G_UNICODE_OTHER_LETTER },
  { 0xA9B3, 0xA9B3, G_UNICODE_NON_SPACING_MARK },
  { 0xA9B4, 0xA9B5, G_UNICODE_SPACING_MARK },
  { 0xA9B6, 0xA9B9, G_UNICODE_NON_SPACING_MARK },
  { 0xA9BA, 0xA9BB, G_UNICODE_SPACING_MARK },
  { 0xA9BC, 0xA9BD, G_UNICODE_NON_SPACING_MARK },
  { 0xA9BE, 0xA9C0, G_UNICODE_SPACING_MARK },
  { 0xA9C1, 0xA9CD, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA9CF, 0xA9CF, G_UNICODE_MODIFIER_LETTER },
  { 0xA9D0, 0xA9D9, G_UNICODE_DECIMAL_NUMBER },
  { 0xA9DE, 0xA9DF, G_UNICODE_OTHER_PUNCTUATION },
  { 0xA9E0, 0xA9E4, G_UNICODE_OTHER_LETTER },
  { 0xA9E5, 0xA9E5, G_UNICODE_NON_SPACING_MARK },
  { 0xA9E6, 0xA9E6, G_UNICODE_MODIFIER_LETTER },
  { 0xA9E7, 0xA9EF, G_UNICODE_OTHER_LETTER },
  { 0xA9F0, 0xA9F9, G_UNICODE_DECIMAL_NUMBER },
  { 0xA9FA, 0xA9FE, G_UNICODE_OTHER_LETTER },
  { 0xAA00, 0xAA28, G_UNICODE_OTHER_LETTER },
  { 0xAA29, 0xAA2E, G_UNICODE_NON_SPACING_MARK },
  { 0xAA2F, 0xAA30, G_UNICODE_SPACING_MARK },
  { 0xAA31, 0xAA32, G_UNICODE_NON_SPACING_MARK },
  { 0xAA33, 0xAA34, G_UNICODE_SPACING_MARK },
  { 0xAA35, 0xAA36, G_UNICODE_NON_SPACING_MARK },
  { 0xAA40, 0xAA42, G_UNICODE_OTHER_LETTER },
  { 0xAA43, 0xAA43, G_UNICODE_NON_SPACING_MARK },
  { 0xAA44, 0xAA4B, G_UNICODE_OTHER_LETTER },
  { 0xAA4C, 0xAA4C, G_UNICODE_NON_SPACING_MARK },
  { 0xAA4D, 0xAA4D, G_UNICODE_SPACING_MARK },
  { 0xAA50, 0xAA59, G_UNICODE_DECIMAL_NUMBER },
  { 0xAA5C, 0xAA5F, G_UNICODE_OTHER_PUNCTUATION },
  { 0xAA60, 0xAA6F, G_UNICODE_OTHER_LETTER },
  { 0xAA70, 0xAA70, G_UNICODE_MODIFIER_LETTER },
  { 0xAA71, 0xAA76, G_UNICODE_OTHER_LETTER },
  { 0xAA77, 0xAA79, G_UNICODE_OTHER_SYMBOL },
  { 0xAA7A, 0xAA7A, G_UNICODE_OTHER_LETTER },
  { 0xAA7B, 0xAA7B, G_UNICODE_SPACING_MARK },
  { 0xAA7C, 0xAA7C, G_UNICODE_NON_SPACING_MARK },
  { 0xAA7D, 0xAA7D, G_UNICODE_SPACING_MARK },
  { 0xAA7E, 0xAAAF, G_UNICODE_OTHER_LETTER },
  { 0xAAB0, 0xAAB0, G_UNICODE_NON_SPACING_MARK },
  { 0xAAB1, 0xAAB1, G_UNICODE_OTHER_LETTER },
  { 0xAAB2, 0xAAB4, G_UNICODE_NON_SPACING_MARK },
  { 0xAAB5, 0xAAB6, G_UNICODE_OTHER_LETTER },
  { 0xAAB7, 0xAAB8, G_UNICODE_NON_SPACING_MARK },
  { 0xAAB9, 0xAABD, G_UNICODE_OTHER_LETTER },
  { 0xAABE, 0xAABF, G_UNICODE_NON_SPACING_MARK },
  { 0xAAC0, 0xAAC0, G_UNICODE_OTHER_LETTER },
  { 0xAAC1, 0xAAC1, G_UNICODE_NON_SPACING_MARK },
  { 0xAAC2, 0xAAC2, G_UNICODE_OTHER_LETTER },
  { 0xAADB, 0xAADC, G_UNICODE_OTHER_LETTER },
  { 0xAADD, 0xAADD, G_UNICODE_MODIFIER_LETTER },
  { 0xAADE, 0xAADF, G_UNICODE_OTHER_PUNCTUATION },
  { 0xAAE0, 0xAAEA, G_UNICODE_OTHER_LETTER },
  { 0xAAEB, 0xAAEB, G_UNICODE_SPACING_MARK },
  { 0xAAEC, 0xAAED, G_UNICODE_NON_SPACING_MARK },
  { 0xAAEE, 0xAAEF, G_UNICODE_SPACING_MARK },
  { 0xAAF0, 0xAAF1, G_UNICODE_OTHER_PUNCTUATION },
  { 0xAAF2, 0xAAF2, G_UNICODE_OTHER_LETTER },
  { 0xAAF3, 0xAAF4, G_UNICODE_MODIFIER_LETTER },
  { 0xAAF5, 0xAAF5, G_UNICODE_SPACING_MARK },
  { 0xAAF6, 0xAAF6, G_UNICODE_NON_SPACING_MARK },
  { 0xAB01, 0xAB06, G_UNICODE_OTHER_LETTER },
  { 0xAB09, 0xAB0E, G_UNICODE_OTHER_LETTER },
  { 0xAB11, 0xAB16, G_UNICODE_OTHER_LETTER },
  { 0xAB20, 0xAB26, G_UNICODE_OTHER_LETTER },
  { 0xAB28, 0xAB2E, G_UNICODE_OTHER_LETTER },
  { 0xAB30, 0xAB5A, G_UNICODE_LOWERCASE_LETTER },
  { 0xAB5B, 0xAB5B, G_UNICODE_MODIFIER_SYMBOL },
  { 0xAB5C, 0xAB5F, G_UNICODE_MODIFIER_LETTER },
  { 0xAB60, 0xAB68, G_UNICODE_LOWERCASE_LETTER },
  { 0xAB69, 0xAB69, G_UNICODE_MODIFIER_LETTER },
  { 0xAB6A, 0xAB6B, G_UNICODE_MODIFIER_SYMBOL },
  { 0xAB70, 0xABBF, G_UNICODE_LOWERCASE_LETTER },
  { 0xABC0, 0xABE2, G_UNICODE_OTHER_LETTER },
  { 0xABE3, 0xABE4, G_UNICODE_SPACING_MARK },
  { 0xABE5, 0xABE5, G_UNICODE_NON_SPACING_MARK },
  { 0xABE6, 0xABE7, G_UNICODE_SPACING_MARK },
  { 0xABE8, 0xABE8, G_UNICODE_NON_SPACING_MARK },
  { 0xABE9, 0xABEA, G_UNICODE_SPACING_MARK },
  { 0xABEB, 0xABEB, G_UNICODE_OTHER_PUNCTUATION },
  { 0xABEC, 0xABEC, G_UNICODE_SPACING_MARK },
  { 0xABED, 0xABED, G_UNICODE_NON_SPACING_MARK },
  { 0xABF0, 0xABF9, G_UNICODE_DECIMAL_NUMBER },
  { 0xAC00, 0xD7A3, G_UNICODE_OTHER_LETTER },
  { 0xD7B0, 0xD7C6, G_UNICODE_OTHER_LETTER },
  { 0xD7CB, 0xD7FB, G_UNICODE_OTHER_LETTER },
  { 0xD800, 0xDB7F, G_UNICODE_SURROGATE },
  { 0xDB80, 0xDBFF, G_UNICODE_SURROGATE },
  { 0xDC00, 0xDFFF, G_UNICODE_SURROGATE },
  { 0xE000, 0xF8FF, G_UNICODE_PRIVATE_USE },
  { 0xF900, 0xFA6D, G_UNICODE_OTHER_LETTER },
  { 0xFA70, 0xFAD9, G_UNICODE_OTHER_LETTER },
  { 0xFB00, 0xFB06, G_UNICODE_LOWERCASE_LETTER },
  { 0xFB13, 0xFB17, G_UNICODE_LOWERCASE_LETTER },
  { 0xFB1D, 0xFB1D, G_UNICODE_OTHER_LETTER },
  { 0xFB1E, 0xFB1E, G_UNICODE_NON_SPACING_MARK },
  { 0xFB1F, 0xFB28, G_UNICODE_OTHER_LETTER },
  { 0xFB29, 0xFB29, G_UNICODE_MATH_SYMBOL },
  { 0xFB2A, 0xFB36, G_UNICODE_OTHER_LETTER },
  { 0xFB38, 0xFB3C, G_UNICODE_OTHER_LETTER },
  { 0xFB3E, 0xFB3E, G_UNICODE_OTHER_LETTER },
  { 0xFB40, 0xFB41, G_UNICODE_OTHER_LETTER },
  { 0xFB43, 0xFB44, G_UNICODE_OTHER_LETTER },
  { 0xFB46, 0xFBB1, G_UNICODE_OTHER_LETTER },
  { 0xFBB2, 0xFBC2, G_UNICODE_MODIFIER_SYMBOL },
  { 0xFBD3, 0xFD3D, G_UNICODE_OTHER_LETTER },
  { 0xFD3E, 0xFD3E, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFD3F, 0xFD3F, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFD40, 0xFD4F, G_UNICODE_OTHER_SYMBOL },
  { 0xFD50, 0xFD8F, G_UNICODE_OTHER_LETTER },
  { 0xFD92, 0xFDC7, G_UNICODE_OTHER_LETTER },
  { 0xFDCF, 0xFDCF, G_UNICODE_OTHER_SYMBOL },
  { 0xFDF0, 0xFDFB, G_UNICODE_OTHER_LETTER },
  { 0xFDFC, 0xFDFC, G_UNICODE_CURRENCY_SYMBOL },
  { 0xFDFD, 0xFDFF, G_UNICODE_OTHER_SYMBOL },
  { 0xFE00, 0xFE0F, G_UNICODE_NON_SPACING_MARK },
  { 0xFE10, 0xFE16, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE17, 0xFE17, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE18, 0xFE18, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE19, 0xFE19, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE20, 0xFE2F, G_UNICODE_NON_SPACING_MARK },
  { 0xFE30, 0xFE30, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE31, 0xFE32, G_UNICODE_DASH_PUNCTUATION },
  { 0xFE33, 0xFE34, G_UNICODE_CONNECT_PUNCTUATION },
  { 0xFE35, 0xFE35, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE36, 0xFE36, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE37, 0xFE37, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE38, 0xFE38, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE39, 0xFE39, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE3A, 0xFE3A, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE3B, 0xFE3B, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE3C, 0xFE3C, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE3D, 0xFE3D, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE3E, 0xFE3E, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE3F, 0xFE3F, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE40, 0xFE40, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE41, 0xFE41, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE42, 0xFE42, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE43, 0xFE43, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE44, 0xFE44, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE45, 0xFE46, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE47, 0xFE47, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE48, 0xFE48, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE49, 0xFE4C, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE4D, 0xFE4F, G_UNICODE_CONNECT_PUNCTUATION },
  { 0xFE50, 0xFE52, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE54, 0xFE57, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE58, 0xFE58, G_UNICODE_DASH_PUNCTUATION },
  { 0xFE59, 0xFE59, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE5A, 0xFE5A, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE5B, 0xFE5B, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE5C, 0xFE5C, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE5D, 0xFE5D, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFE5E, 0xFE5E, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFE5F, 0xFE61, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE62, 0xFE62, G_UNICODE_MATH_SYMBOL },
  { 0xFE63, 0xFE63, G_UNICODE_DASH_PUNCTUATION },
  { 0xFE64, 0xFE66, G_UNICODE_MATH_SYMBOL },
  { 0xFE68, 0xFE68, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE69, 0xFE69, G_UNICODE_CURRENCY_SYMBOL },
  { 0xFE6A, 0xFE6B, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFE70, 0xFE74, G_UNICODE_OTHER_LETTER },
  { 0xFE76, 0xFEFC, G_UNICODE_OTHER_LETTER },
  { 0xFEFF, 0xFEFF, G_UNICODE_FORMAT },
  { 0xFF01, 0xFF03, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF04, 0xFF04, G_UNICODE_CURRENCY_SYMBOL },
  { 0xFF05, 0xFF07, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF08, 0xFF08, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFF09, 0xFF09, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFF0A, 0xFF0A, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF0B, 0xFF0B, G_UNICODE_MATH_SYMBOL },
  { 0xFF0C, 0xFF0C, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF0D, 0xFF0D, G_UNICODE_DASH_PUNCTUATION },
  { 0xFF0E, 0xFF0F, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF10, 0xFF19, G_UNICODE_DECIMAL_NUMBER },
  { 0xFF1A, 0xFF1B, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF1C, 0xFF1E, G_UNICODE_MATH_SYMBOL },
  { 0xFF1F, 0xFF20, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF21, 0xFF3A, G_UNICODE_UPPERCASE_LETTER },
  { 0xFF3B, 0xFF3B, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFF3C, 0xFF3C, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF3D, 0xFF3D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFF3E, 0xFF3E, G_UNICODE_MODIFIER_SYMBOL },
  { 0xFF3F, 0xFF3F, G_UNICODE_CONNECT_PUNCTUATION },
  { 0xFF40, 0xFF40, G_UNICODE_MODIFIER_SYMBOL },
  { 0xFF41, 0xFF5A, G_UNICODE_LOWERCASE_LETTER },
  { 0xFF5B, 0xFF5B, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFF5C, 0xFF5C, G_UNICODE_MATH_SYMBOL },
  { 0xFF5D, 0xFF5D, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFF5E, 0xFF5E, G_UNICODE_MATH_SYMBOL },
  { 0xFF5F, 0xFF5F, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFF60, 0xFF60, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFF61, 0xFF61, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF62, 0xFF62, G_UNICODE_OPEN_PUNCTUATION },
  { 0xFF63, 0xFF63, G_UNICODE_CLOSE_PUNCTUATION },
  { 0xFF64, 0xFF65, G_UNICODE_OTHER_PUNCTUATION },
  { 0xFF66, 0xFF6F, G_UNICODE_OTHER_LETTER },
  { 0xFF70, 0xFF70, G_UNICODE_MODIFIER_LETTER },
  { 0xFF71, 0xFF9D, G_UNICODE_OTHER_LETTER },
  { 0xFF9E, 0xFF9F, G_UNICODE_MODIFIER_LETTER },
  { 0xFFA0, 0xFFBE, G_UNICODE_OTHER_LETTER },
  { 0xFFC2, 0xFFC7, G_UNICODE_OTHER_LETTER },
  { 0xFFCA, 0xFFCF, G_UNICODE_OTHER_LETTER },
  { 0xFFD2, 0xFFD7, G_UNICODE_OTHER_LETTER },
  { 0xFFDA, 0xFFDC, G_UNICODE_OTHER_LETTER },
  { 0xFFE0, 0xFFE1, G_UNICODE_CURRENCY_SYMBOL },
  { 0xFFE2, 0xFFE2, G_UNICODE_MATH_SYMBOL },
  { 0xFFE3, 0xFFE3, G_UNICODE_MODIFIER_SYMBOL },
  { 0xFFE4, 0xFFE4, G_UNICODE_OTHER_SYMBOL },
  { 0xFFE5, 0xFFE6, G_UNICODE_CURRENCY_SYMBOL },
  { 0xFFE8, 0xFFE8, G_UNICODE_OTHER_SYMBOL },
  { 0xFFE9, 0xFFEC, G_UNICODE_MATH_SYMBOL },
  { 0xFFED, 0xFFEE, G_UNICODE_OTHER_SYMBOL },
  { 0xFFF9, 0xFFFB, G_UNICODE_FORMAT },
  { 0xFFFC, 0xFFFD, G_UNICODE_OTHER_SYMBOL },
  { 0x10000, 0x1000B, G_UNICODE_OTHER_LETTER },
  { 0x1000D, 0x10026, G_UNICODE_OTHER_LETTER },
  { 0x10028, 0x1003A, G_UNICODE_OTHER_LETTER },
  { 0x1003C, 0x1003D, G_UNICODE_OTHER_LETTER },
  { 0x1003F, 0x1004D, G_UNICODE_OTHER_LETTER },
  { 0x10050, 0x1005D, G_UNICODE_OTHER_LETTER },
  { 0x10080, 0x100FA, G_UNICODE_OTHER_LETTER },
  { 0x10100, 0x10102, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10107, 0x10133, G_UNICODE_OTHER_NUMBER },
  { 0x10137, 0x1013F, G_UNICODE_OTHER_SYMBOL },
  { 0x10140, 0x10174, G_UNICODE_LETTER_NUMBER },
  { 0x10175, 0x10178, G_UNICODE_OTHER_NUMBER },
  { 0x10179, 0x10189, G_UNICODE_OTHER_SYMBOL },
  { 0x1018A, 0x1018B, G_UNICODE_OTHER_NUMBER },
  { 0x1018C, 0x1018E, G_UNICODE_OTHER_SYMBOL },
  { 0x10190, 0x1019C, G_UNICODE_OTHER_SYMBOL },
  { 0x101A0, 0x101A0, G_UNICODE_OTHER_SYMBOL },
  { 0x101D0, 0x101FC, G_UNICODE_OTHER_SYMBOL },
  { 0x101FD, 0x101FD, G_UNICODE_NON_SPACING_MARK },
  { 0x10280, 0x1029C, G_UNICODE_OTHER_LETTER },
  { 0x102A0, 0x102D0, G_UNICODE_OTHER_LETTER },
  { 0x102E0, 0x102E0, G_UNICODE_NON_SPACING_MARK },
  { 0x102E1, 0x102FB, G_UNICODE_OTHER_NUMBER },
  { 0x10300, 0x1031F, G_UNICODE_OTHER_LETTER },
  { 0x10320, 0x10323, G_UNICODE_OTHER_NUMBER },
  { 0x1032D, 0x10340, G_UNICODE_OTHER_LETTER },
  { 0x10341, 0x10341, G_UNICODE_LETTER_NUMBER },
  { 0x10342, 0x10349, G_UNICODE_OTHER_LETTER },
  { 0x1034A, 0x1034A, G_UNICODE_LETTER_NUMBER },
  { 0x10350, 0x10375, G_UNICODE_OTHER_LETTER },
  { 0x10376, 0x1037A, G_UNICODE_NON_SPACING_MARK },
  { 0x10380, 0x1039D, G_UNICODE_OTHER_LETTER },
  { 0x1039F, 0x1039F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x103A0, 0x103C3, G_UNICODE_OTHER_LETTER },
  { 0x103C8, 0x103CF, G_UNICODE_OTHER_LETTER },
  { 0x103D0, 0x103D0, G_UNICODE_OTHER_PUNCTUATION },
  { 0x103D1, 0x103D5, G_UNICODE_LETTER_NUMBER },
  { 0x10400, 0x10427, G_UNICODE_UPPERCASE_LETTER },
  { 0x10428, 0x1044F, G_UNICODE_LOWERCASE_LETTER },
  { 0x10450, 0x1049D, G_UNICODE_OTHER_LETTER },
  { 0x104A0, 0x104A9, G_UNICODE_DECIMAL_NUMBER },
  { 0x104B0, 0x104D3, G_UNICODE_UPPERCASE_LETTER },
  { 0x104D8, 0x104FB, G_UNICODE_LOWERCASE_LETTER },
  { 0x10500, 0x10527, G_UNICODE_OTHER_LETTER },
  { 0x10530, 0x10563, G_UNICODE_OTHER_LETTER },
  { 0x1056F, 0x1056F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10570, 0x1057A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1057C, 0x1058A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1058C, 0x10592, G_UNICODE_UPPERCASE_LETTER },
  { 0x10594, 0x10595, G_UNICODE_UPPERCASE_LETTER },
  { 0x10597, 0x105A1, G_UNICODE_LOWERCASE_LETTER },
  { 0x105A3, 0x105B1, G_UNICODE_LOWERCASE_LETTER },
  { 0x105B3, 0x105B9, G_UNICODE_LOWERCASE_LETTER },
  { 0x105BB, 0x105BC, G_UNICODE_LOWERCASE_LETTER },
  { 0x105C0, 0x105F3, G_UNICODE_OTHER_LETTER },
  { 0x10600, 0x10736, G_UNICODE_OTHER_LETTER },
  { 0x10740, 0x10755, G_UNICODE_OTHER_LETTER },
  { 0x10760, 0x10767, G_UNICODE_OTHER_LETTER },
  { 0x10780, 0x10785, G_UNICODE_MODIFIER_LETTER },
  { 0x10787, 0x107B0, G_UNICODE_MODIFIER_LETTER },
  { 0x107B2, 0x107BA, G_UNICODE_MODIFIER_LETTER },
  { 0x10800, 0x10805, G_UNICODE_OTHER_LETTER },
  { 0x10808, 0x10808, G_UNICODE_OTHER_LETTER },
  { 0x1080A, 0x10835, G_UNICODE_OTHER_LETTER },
  { 0x10837, 0x10838, G_UNICODE_OTHER_LETTER },
  { 0x1083C, 0x1083C, G_UNICODE_OTHER_LETTER },
  { 0x1083F, 0x10855, G_UNICODE_OTHER_LETTER },
  { 0x10857, 0x10857, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10858, 0x1085F, G_UNICODE_OTHER_NUMBER },
  { 0x10860, 0x10876, G_UNICODE_OTHER_LETTER },
  { 0x10877, 0x10878, G_UNICODE_OTHER_SYMBOL },
  { 0x10879, 0x1087F, G_UNICODE_OTHER_NUMBER },
  { 0x10880, 0x1089E, G_UNICODE_OTHER_LETTER },
  { 0x108A7, 0x108AF, G_UNICODE_OTHER_NUMBER },
  { 0x108E0, 0x108F2, G_UNICODE_OTHER_LETTER },
  { 0x108F4, 0x108F5, G_UNICODE_OTHER_LETTER },
  { 0x108FB, 0x108FF, G_UNICODE_OTHER_NUMBER },
  { 0x10900, 0x10915, G_UNICODE_OTHER_LETTER },
  { 0x10916, 0x1091B, G_UNICODE_OTHER_NUMBER },
  { 0x1091F, 0x1091F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10920, 0x10939, G_UNICODE_OTHER_LETTER },
  { 0x1093F, 0x1093F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10980, 0x109B7, G_UNICODE_OTHER_LETTER },
  { 0x109BC, 0x109BD, G_UNICODE_OTHER_NUMBER },
  { 0x109BE, 0x109BF, G_UNICODE_OTHER_LETTER },
  { 0x109C0, 0x109CF, G_UNICODE_OTHER_NUMBER },
  { 0x109D2, 0x109FF, G_UNICODE_OTHER_NUMBER },
  { 0x10A00, 0x10A00, G_UNICODE_OTHER_LETTER },
  { 0x10A01, 0x10A03, G_UNICODE_NON_SPACING_MARK },
  { 0x10A05, 0x10A06, G_UNICODE_NON_SPACING_MARK },
  { 0x10A0C, 0x10A0F, G_UNICODE_NON_SPACING_MARK },
  { 0x10A10, 0x10A13, G_UNICODE_OTHER_LETTER },
  { 0x10A15, 0x10A17, G_UNICODE_OTHER_LETTER },
  { 0x10A19, 0x10A35, G_UNICODE_OTHER_LETTER },
  { 0x10A38, 0x10A3A, G_UNICODE_NON_SPACING_MARK },
  { 0x10A3F, 0x10A3F, G_UNICODE_NON_SPACING_MARK },
  { 0x10A40, 0x10A48, G_UNICODE_OTHER_NUMBER },
  { 0x10A50, 0x10A58, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10A60, 0x10A7C, G_UNICODE_OTHER_LETTER },
  { 0x10A7D, 0x10A7E, G_UNICODE_OTHER_NUMBER },
  { 0x10A7F, 0x10A7F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10A80, 0x10A9C, G_UNICODE_OTHER_LETTER },
  { 0x10A9D, 0x10A9F, G_UNICODE_OTHER_NUMBER },
  { 0x10AC0, 0x10AC7, G_UNICODE_OTHER_LETTER },
  { 0x10AC8, 0x10AC8, G_UNICODE_OTHER_SYMBOL },
  { 0x10AC9, 0x10AE4, G_UNICODE_OTHER_LETTER },
  { 0x10AE5, 0x10AE6, G_UNICODE_NON_SPACING_MARK },
  { 0x10AEB, 0x10AEF, G_UNICODE_OTHER_NUMBER },
  { 0x10AF0, 0x10AF6, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10B00, 0x10B35, G_UNICODE_OTHER_LETTER },
  { 0x10B39, 0x10B3F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10B40, 0x10B55, G_UNICODE_OTHER_LETTER },
  { 0x10B58, 0x10B5F, G_UNICODE_OTHER_NUMBER },
  { 0x10B60, 0x10B72, G_UNICODE_OTHER_LETTER },
  { 0x10B78, 0x10B7F, G_UNICODE_OTHER_NUMBER },
  { 0x10B80, 0x10B91, G_UNICODE_OTHER_LETTER },
  { 0x10B99, 0x10B9C, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10BA9, 0x10BAF, G_UNICODE_OTHER_NUMBER },
  { 0x10C00, 0x10C48, G_UNICODE_OTHER_LETTER },
  { 0x10C80, 0x10CB2, G_UNICODE_UPPERCASE_LETTER },
  { 0x10CC0, 0x10CF2, G_UNICODE_LOWERCASE_LETTER },
  { 0x10CFA, 0x10CFF, G_UNICODE_OTHER_NUMBER },
  { 0x10D00, 0x10D23, G_UNICODE_OTHER_LETTER },
  { 0x10D24, 0x10D27, G_UNICODE_NON_SPACING_MARK },
  { 0x10D30, 0x10D39, G_UNICODE_DECIMAL_NUMBER },
  { 0x10D40, 0x10D49, G_UNICODE_DECIMAL_NUMBER },
  { 0x10D4A, 0x10D4D, G_UNICODE_OTHER_LETTER },
  { 0x10D4E, 0x10D4E, G_UNICODE_MODIFIER_LETTER },
  { 0x10D4F, 0x10D4F, G_UNICODE_OTHER_LETTER },
  { 0x10D50, 0x10D65, G_UNICODE_UPPERCASE_LETTER },
  { 0x10D69, 0x10D6D, G_UNICODE_NON_SPACING_MARK },
  { 0x10D6E, 0x10D6E, G_UNICODE_DASH_PUNCTUATION },
  { 0x10D6F, 0x10D6F, G_UNICODE_MODIFIER_LETTER },
  { 0x10D70, 0x10D85, G_UNICODE_LOWERCASE_LETTER },
  { 0x10D8E, 0x10D8F, G_UNICODE_MATH_SYMBOL },
  { 0x10E60, 0x10E7E, G_UNICODE_OTHER_NUMBER },
  { 0x10E80, 0x10EA9, G_UNICODE_OTHER_LETTER },
  { 0x10EAB, 0x10EAC, G_UNICODE_NON_SPACING_MARK },
  { 0x10EAD, 0x10EAD, G_UNICODE_DASH_PUNCTUATION },
  { 0x10EB0, 0x10EB1, G_UNICODE_OTHER_LETTER },
  { 0x10EC2, 0x10EC4, G_UNICODE_OTHER_LETTER },
  { 0x10EFC, 0x10EFF, G_UNICODE_NON_SPACING_MARK },
  { 0x10F00, 0x10F1C, G_UNICODE_OTHER_LETTER },
  { 0x10F1D, 0x10F26, G_UNICODE_OTHER_NUMBER },
  { 0x10F27, 0x10F27, G_UNICODE_OTHER_LETTER },
  { 0x10F30, 0x10F45, G_UNICODE_OTHER_LETTER },
  { 0x10F46, 0x10F50, G_UNICODE_NON_SPACING_MARK },
  { 0x10F51, 0x10F54, G_UNICODE_OTHER_NUMBER },
  { 0x10F55, 0x10F59, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10F70, 0x10F81, G_UNICODE_OTHER_LETTER },
  { 0x10F82, 0x10F85, G_UNICODE_NON_SPACING_MARK },
  { 0x10F86, 0x10F89, G_UNICODE_OTHER_PUNCTUATION },
  { 0x10FB0, 0x10FC4, G_UNICODE_OTHER_LETTER },
  { 0x10FC5, 0x10FCB, G_UNICODE_OTHER_NUMBER },
  { 0x10FE0, 0x10FF6, G_UNICODE_OTHER_LETTER },
  { 0x11000, 0x11000, G_UNICODE_SPACING_MARK },
  { 0x11001, 0x11001, G_UNICODE_NON_SPACING_MARK },
  { 0x11002, 0x11002, G_UNICODE_SPACING_MARK },
  { 0x11003, 0x11037, G_UNICODE_OTHER_LETTER },
  { 0x11038, 0x11046, G_UNICODE_NON_SPACING_MARK },
  { 0x11047, 0x1104D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11052, 0x11065, G_UNICODE_OTHER_NUMBER },
  { 0x11066, 0x1106F, G_UNICODE_DECIMAL_NUMBER },
  { 0x11070, 0x11070, G_UNICODE_NON_SPACING_MARK },
  { 0x11071, 0x11072, G_UNICODE_OTHER_LETTER },
  { 0x11073, 0x11074, G_UNICODE_NON_SPACING_MARK },
  { 0x11075, 0x11075, G_UNICODE_OTHER_LETTER },
  { 0x1107F, 0x11081, G_UNICODE_NON_SPACING_MARK },
  { 0x11082, 0x11082, G_UNICODE_SPACING_MARK },
  { 0x11083, 0x110AF, G_UNICODE_OTHER_LETTER },
  { 0x110B0, 0x110B2, G_UNICODE_SPACING_MARK },
  { 0x110B3, 0x110B6, G_UNICODE_NON_SPACING_MARK },
  { 0x110B7, 0x110B8, G_UNICODE_SPACING_MARK },
  { 0x110B9, 0x110BA, G_UNICODE_NON_SPACING_MARK },
  { 0x110BB, 0x110BC, G_UNICODE_OTHER_PUNCTUATION },
  { 0x110BD, 0x110BD, G_UNICODE_FORMAT },
  { 0x110BE, 0x110C1, G_UNICODE_OTHER_PUNCTUATION },
  { 0x110C2, 0x110C2, G_UNICODE_NON_SPACING_MARK },
  { 0x110CD, 0x110CD, G_UNICODE_FORMAT },
  { 0x110D0, 0x110E8, G_UNICODE_OTHER_LETTER },
  { 0x110F0, 0x110F9, G_UNICODE_DECIMAL_NUMBER },
  { 0x11100, 0x11102, G_UNICODE_NON_SPACING_MARK },
  { 0x11103, 0x11126, G_UNICODE_OTHER_LETTER },
  { 0x11127, 0x1112B, G_UNICODE_NON_SPACING_MARK },
  { 0x1112C, 0x1112C, G_UNICODE_SPACING_MARK },
  { 0x1112D, 0x11134, G_UNICODE_NON_SPACING_MARK },
  { 0x11136, 0x1113F, G_UNICODE_DECIMAL_NUMBER },
  { 0x11140, 0x11143, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11144, 0x11144, G_UNICODE_OTHER_LETTER },
  { 0x11145, 0x11146, G_UNICODE_SPACING_MARK },
  { 0x11147, 0x11147, G_UNICODE_OTHER_LETTER },
  { 0x11150, 0x11172, G_UNICODE_OTHER_LETTER },
  { 0x11173, 0x11173, G_UNICODE_NON_SPACING_MARK },
  { 0x11174, 0x11175, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11176, 0x11176, G_UNICODE_OTHER_LETTER },
  { 0x11180, 0x11181, G_UNICODE_NON_SPACING_MARK },
  { 0x11182, 0x11182, G_UNICODE_SPACING_MARK },
  { 0x11183, 0x111B2, G_UNICODE_OTHER_LETTER },
  { 0x111B3, 0x111B5, G_UNICODE_SPACING_MARK },
  { 0x111B6, 0x111BE, G_UNICODE_NON_SPACING_MARK },
  { 0x111BF, 0x111C0, G_UNICODE_SPACING_MARK },
  { 0x111C1, 0x111C4, G_UNICODE_OTHER_LETTER },
  { 0x111C5, 0x111C8, G_UNICODE_OTHER_PUNCTUATION },
  { 0x111C9, 0x111CC, G_UNICODE_NON_SPACING_MARK },
  { 0x111CD, 0x111CD, G_UNICODE_OTHER_PUNCTUATION },
  { 0x111CE, 0x111CE, G_UNICODE_SPACING_MARK },
  { 0x111CF, 0x111CF, G_UNICODE_NON_SPACING_MARK },
  { 0x111D0, 0x111D9, G_UNICODE_DECIMAL_NUMBER },
  { 0x111DA, 0x111DA, G_UNICODE_OTHER_LETTER },
  { 0x111DB, 0x111DB, G_UNICODE_OTHER_PUNCTUATION },
  { 0x111DC, 0x111DC, G_UNICODE_OTHER_LETTER },
  { 0x111DD, 0x111DF, G_UNICODE_OTHER_PUNCTUATION },
  { 0x111E1, 0x111F4, G_UNICODE_OTHER_NUMBER },
  { 0x11200, 0x11211, G_UNICODE_OTHER_LETTER },
  { 0x11213, 0x1122B, G_UNICODE_OTHER_LETTER },
  { 0x1122C, 0x1122E, G_UNICODE_SPACING_MARK },
  { 0x1122F, 0x11231, G_UNICODE_NON_SPACING_MARK },
  { 0x11232, 0x11233, G_UNICODE_SPACING_MARK },
  { 0x11234, 0x11234, G_UNICODE_NON_SPACING_MARK },
  { 0x11235, 0x11235, G_UNICODE_SPACING_MARK },
  { 0x11236, 0x11237, G_UNICODE_NON_SPACING_MARK },
  { 0x11238, 0x1123D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1123E, 0x1123E, G_UNICODE_NON_SPACING_MARK },
  { 0x1123F, 0x11240, G_UNICODE_OTHER_LETTER },
  { 0x11241, 0x11241, G_UNICODE_NON_SPACING_MARK },
  { 0x11280, 0x11286, G_UNICODE_OTHER_LETTER },
  { 0x11288, 0x11288, G_UNICODE_OTHER_LETTER },
  { 0x1128A, 0x1128D, G_UNICODE_OTHER_LETTER },
  { 0x1128F, 0x1129D, G_UNICODE_OTHER_LETTER },
  { 0x1129F, 0x112A8, G_UNICODE_OTHER_LETTER },
  { 0x112A9, 0x112A9, G_UNICODE_OTHER_PUNCTUATION },
  { 0x112B0, 0x112DE, G_UNICODE_OTHER_LETTER },
  { 0x112DF, 0x112DF, G_UNICODE_NON_SPACING_MARK },
  { 0x112E0, 0x112E2, G_UNICODE_SPACING_MARK },
  { 0x112E3, 0x112EA, G_UNICODE_NON_SPACING_MARK },
  { 0x112F0, 0x112F9, G_UNICODE_DECIMAL_NUMBER },
  { 0x11300, 0x11301, G_UNICODE_NON_SPACING_MARK },
  { 0x11302, 0x11303, G_UNICODE_SPACING_MARK },
  { 0x11305, 0x1130C, G_UNICODE_OTHER_LETTER },
  { 0x1130F, 0x11310, G_UNICODE_OTHER_LETTER },
  { 0x11313, 0x11328, G_UNICODE_OTHER_LETTER },
  { 0x1132A, 0x11330, G_UNICODE_OTHER_LETTER },
  { 0x11332, 0x11333, G_UNICODE_OTHER_LETTER },
  { 0x11335, 0x11339, G_UNICODE_OTHER_LETTER },
  { 0x1133B, 0x1133C, G_UNICODE_NON_SPACING_MARK },
  { 0x1133D, 0x1133D, G_UNICODE_OTHER_LETTER },
  { 0x1133E, 0x1133F, G_UNICODE_SPACING_MARK },
  { 0x11340, 0x11340, G_UNICODE_NON_SPACING_MARK },
  { 0x11341, 0x11344, G_UNICODE_SPACING_MARK },
  { 0x11347, 0x11348, G_UNICODE_SPACING_MARK },
  { 0x1134B, 0x1134D, G_UNICODE_SPACING_MARK },
  { 0x11350, 0x11350, G_UNICODE_OTHER_LETTER },
  { 0x11357, 0x11357, G_UNICODE_SPACING_MARK },
  { 0x1135D, 0x11361, G_UNICODE_OTHER_LETTER },
  { 0x11362, 0x11363, G_UNICODE_SPACING_MARK },
  { 0x11366, 0x1136C, G_UNICODE_NON_SPACING_MARK },
  { 0x11370, 0x11374, G_UNICODE_NON_SPACING_MARK },
  { 0x11380, 0x11389, G_UNICODE_OTHER_LETTER },
  { 0x1138B, 0x1138B, G_UNICODE_OTHER_LETTER },
  { 0x1138E, 0x1138E, G_UNICODE_OTHER_LETTER },
  { 0x11390, 0x113B5, G_UNICODE_OTHER_LETTER },
  { 0x113B7, 0x113B7, G_UNICODE_OTHER_LETTER },
  { 0x113B8, 0x113BA, G_UNICODE_SPACING_MARK },
  { 0x113BB, 0x113C0, G_UNICODE_NON_SPACING_MARK },
  { 0x113C2, 0x113C2, G_UNICODE_SPACING_MARK },
  { 0x113C5, 0x113C5, G_UNICODE_SPACING_MARK },
  { 0x113C7, 0x113CA, G_UNICODE_SPACING_MARK },
  { 0x113CC, 0x113CD, G_UNICODE_SPACING_MARK },
  { 0x113CE, 0x113CE, G_UNICODE_NON_SPACING_MARK },
  { 0x113CF, 0x113CF, G_UNICODE_SPACING_MARK },
  { 0x113D0, 0x113D0, G_UNICODE_NON_SPACING_MARK },
  { 0x113D1, 0x113D1, G_UNICODE_OTHER_LETTER },
  { 0x113D2, 0x113D2, G_UNICODE_NON_SPACING_MARK },
  { 0x113D3, 0x113D3, G_UNICODE_OTHER_LETTER },
  { 0x113D4, 0x113D5, G_UNICODE_OTHER_PUNCTUATION },
  { 0x113D7, 0x113D8, G_UNICODE_OTHER_PUNCTUATION },
  { 0x113E1, 0x113E2, G_UNICODE_NON_SPACING_MARK },
  { 0x11400, 0x11434, G_UNICODE_OTHER_LETTER },
  { 0x11435, 0x11437, G_UNICODE_SPACING_MARK },
  { 0x11438, 0x1143F, G_UNICODE_NON_SPACING_MARK },
  { 0x11440, 0x11441, G_UNICODE_SPACING_MARK },
  { 0x11442, 0x11444, G_UNICODE_NON_SPACING_MARK },
  { 0x11445, 0x11445, G_UNICODE_SPACING_MARK },
  { 0x11446, 0x11446, G_UNICODE_NON_SPACING_MARK },
  { 0x11447, 0x1144A, G_UNICODE_OTHER_LETTER },
  { 0x1144B, 0x1144F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11450, 0x11459, G_UNICODE_DECIMAL_NUMBER },
  { 0x1145A, 0x1145B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1145D, 0x1145D, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1145E, 0x1145E, G_UNICODE_NON_SPACING_MARK },
  { 0x1145F, 0x11461, G_UNICODE_OTHER_LETTER },
  { 0x11480, 0x114AF, G_UNICODE_OTHER_LETTER },
  { 0x114B0, 0x114B2, G_UNICODE_SPACING_MARK },
  { 0x114B3, 0x114B8, G_UNICODE_NON_SPACING_MARK },
  { 0x114B9, 0x114B9, G_UNICODE_SPACING_MARK },
  { 0x114BA, 0x114BA, G_UNICODE_NON_SPACING_MARK },
  { 0x114BB, 0x114BE, G_UNICODE_SPACING_MARK },
  { 0x114BF, 0x114C0, G_UNICODE_NON_SPACING_MARK },
  { 0x114C1, 0x114C1, G_UNICODE_SPACING_MARK },
  { 0x114C2, 0x114C3, G_UNICODE_NON_SPACING_MARK },
  { 0x114C4, 0x114C5, G_UNICODE_OTHER_LETTER },
  { 0x114C6, 0x114C6, G_UNICODE_OTHER_PUNCTUATION },
  { 0x114C7, 0x114C7, G_UNICODE_OTHER_LETTER },
  { 0x114D0, 0x114D9, G_UNICODE_DECIMAL_NUMBER },
  { 0x11580, 0x115AE, G_UNICODE_OTHER_LETTER },
  { 0x115AF, 0x115B1, G_UNICODE_SPACING_MARK },
  { 0x115B2, 0x115B5, G_UNICODE_NON_SPACING_MARK },
  { 0x115B8, 0x115BB, G_UNICODE_SPACING_MARK },
  { 0x115BC, 0x115BD, G_UNICODE_NON_SPACING_MARK },
  { 0x115BE, 0x115BE, G_UNICODE_SPACING_MARK },
  { 0x115BF, 0x115C0, G_UNICODE_NON_SPACING_MARK },
  { 0x115C1, 0x115D7, G_UNICODE_OTHER_PUNCTUATION },
  { 0x115D8, 0x115DB, G_UNICODE_OTHER_LETTER },
  { 0x115DC, 0x115DD, G_UNICODE_NON_SPACING_MARK },
  { 0x11600, 0x1162F, G_UNICODE_OTHER_LETTER },
  { 0x11630, 0x11632, G_UNICODE_SPACING_MARK },
  { 0x11633, 0x1163A, G_UNICODE_NON_SPACING_MARK },
  { 0x1163B, 0x1163C, G_UNICODE_SPACING_MARK },
  { 0x1163D, 0x1163D, G_UNICODE_NON_SPACING_MARK },
  { 0x1163E, 0x1163E, G_UNICODE_SPACING_MARK },
  { 0x1163F, 0x11640, G_UNICODE_NON_SPACING_MARK },
  { 0x11641, 0x11643, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11644, 0x11644, G_UNICODE_OTHER_LETTER },
  { 0x11650, 0x11659, G_UNICODE_DECIMAL_NUMBER },
  { 0x11660, 0x1166C, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11680, 0x116AA, G_UNICODE_OTHER_LETTER },
  { 0x116AB, 0x116AB, G_UNICODE_NON_SPACING_MARK },
  { 0x116AC, 0x116AC, G_UNICODE_SPACING_MARK },
  { 0x116AD, 0x116AD, G_UNICODE_NON_SPACING_MARK },
  { 0x116AE, 0x116AF, G_UNICODE_SPACING_MARK },
  { 0x116B0, 0x116B5, G_UNICODE_NON_SPACING_MARK },
  { 0x116B6, 0x116B6, G_UNICODE_SPACING_MARK },
  { 0x116B7, 0x116B7, G_UNICODE_NON_SPACING_MARK },
  { 0x116B8, 0x116B8, G_UNICODE_OTHER_LETTER },
  { 0x116B9, 0x116B9, G_UNICODE_OTHER_PUNCTUATION },
  { 0x116C0, 0x116C9, G_UNICODE_DECIMAL_NUMBER },
  { 0x116D0, 0x116E3, G_UNICODE_DECIMAL_NUMBER },
  { 0x11700, 0x1171A, G_UNICODE_OTHER_LETTER },
  { 0x1171D, 0x1171D, G_UNICODE_NON_SPACING_MARK },
  { 0x1171E, 0x1171E, G_UNICODE_SPACING_MARK },
  { 0x1171F, 0x1171F, G_UNICODE_NON_SPACING_MARK },
  { 0x11720, 0x11721, G_UNICODE_SPACING_MARK },
  { 0x11722, 0x11725, G_UNICODE_NON_SPACING_MARK },
  { 0x11726, 0x11726, G_UNICODE_SPACING_MARK },
  { 0x11727, 0x1172B, G_UNICODE_NON_SPACING_MARK },
  { 0x11730, 0x11739, G_UNICODE_DECIMAL_NUMBER },
  { 0x1173A, 0x1173B, G_UNICODE_OTHER_NUMBER },
  { 0x1173C, 0x1173E, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1173F, 0x1173F, G_UNICODE_OTHER_SYMBOL },
  { 0x11740, 0x11746, G_UNICODE_OTHER_LETTER },
  { 0x11800, 0x1182B, G_UNICODE_OTHER_LETTER },
  { 0x1182C, 0x1182E, G_UNICODE_SPACING_MARK },
  { 0x1182F, 0x11837, G_UNICODE_NON_SPACING_MARK },
  { 0x11838, 0x11838, G_UNICODE_SPACING_MARK },
  { 0x11839, 0x1183A, G_UNICODE_NON_SPACING_MARK },
  { 0x1183B, 0x1183B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x118A0, 0x118BF, G_UNICODE_UPPERCASE_LETTER },
  { 0x118C0, 0x118DF, G_UNICODE_LOWERCASE_LETTER },
  { 0x118E0, 0x118E9, G_UNICODE_DECIMAL_NUMBER },
  { 0x118EA, 0x118F2, G_UNICODE_OTHER_NUMBER },
  { 0x118FF, 0x11906, G_UNICODE_OTHER_LETTER },
  { 0x11909, 0x11909, G_UNICODE_OTHER_LETTER },
  { 0x1190C, 0x11913, G_UNICODE_OTHER_LETTER },
  { 0x11915, 0x11916, G_UNICODE_OTHER_LETTER },
  { 0x11918, 0x1192F, G_UNICODE_OTHER_LETTER },
  { 0x11930, 0x11935, G_UNICODE_SPACING_MARK },
  { 0x11937, 0x11938, G_UNICODE_SPACING_MARK },
  { 0x1193B, 0x1193C, G_UNICODE_NON_SPACING_MARK },
  { 0x1193D, 0x1193D, G_UNICODE_SPACING_MARK },
  { 0x1193E, 0x1193E, G_UNICODE_NON_SPACING_MARK },
  { 0x1193F, 0x1193F, G_UNICODE_OTHER_LETTER },
  { 0x11940, 0x11940, G_UNICODE_SPACING_MARK },
  { 0x11941, 0x11941, G_UNICODE_OTHER_LETTER },
  { 0x11942, 0x11942, G_UNICODE_SPACING_MARK },
  { 0x11943, 0x11943, G_UNICODE_NON_SPACING_MARK },
  { 0x11944, 0x11946, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11950, 0x11959, G_UNICODE_DECIMAL_NUMBER },
  { 0x119A0, 0x119A7, G_UNICODE_OTHER_LETTER },
  { 0x119AA, 0x119D0, G_UNICODE_OTHER_LETTER },
  { 0x119D1, 0x119D3, G_UNICODE_SPACING_MARK },
  { 0x119D4, 0x119D7, G_UNICODE_NON_SPACING_MARK },
  { 0x119DA, 0x119DB, G_UNICODE_NON_SPACING_MARK },
  { 0x119DC, 0x119DF, G_UNICODE_SPACING_MARK },
  { 0x119E0, 0x119E0, G_UNICODE_NON_SPACING_MARK },
  { 0x119E1, 0x119E1, G_UNICODE_OTHER_LETTER },
  { 0x119E2, 0x119E2, G_UNICODE_OTHER_PUNCTUATION },
  { 0x119E3, 0x119E3, G_UNICODE_OTHER_LETTER },
  { 0x119E4, 0x119E4, G_UNICODE_SPACING_MARK },
  { 0x11A00, 0x11A00, G_UNICODE_OTHER_LETTER },
  { 0x11A01, 0x11A0A, G_UNICODE_NON_SPACING_MARK },
  { 0x11A0B, 0x11A32, G_UNICODE_OTHER_LETTER },
  { 0x11A33, 0x11A38, G_UNICODE_NON_SPACING_MARK },
  { 0x11A39, 0x11A39, G_UNICODE_SPACING_MARK },
  { 0x11A3A, 0x11A3A, G_UNICODE_OTHER_LETTER },
  { 0x11A3B, 0x11A3E, G_UNICODE_NON_SPACING_MARK },
  { 0x11A3F, 0x11A46, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11A47, 0x11A47, G_UNICODE_NON_SPACING_MARK },
  { 0x11A50, 0x11A50, G_UNICODE_OTHER_LETTER },
  { 0x11A51, 0x11A56, G_UNICODE_NON_SPACING_MARK },
  { 0x11A57, 0x11A58, G_UNICODE_SPACING_MARK },
  { 0x11A59, 0x11A5B, G_UNICODE_NON_SPACING_MARK },
  { 0x11A5C, 0x11A89, G_UNICODE_OTHER_LETTER },
  { 0x11A8A, 0x11A96, G_UNICODE_NON_SPACING_MARK },
  { 0x11A97, 0x11A97, G_UNICODE_SPACING_MARK },
  { 0x11A98, 0x11A99, G_UNICODE_NON_SPACING_MARK },
  { 0x11A9A, 0x11A9C, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11A9D, 0x11A9D, G_UNICODE_OTHER_LETTER },
  { 0x11A9E, 0x11AA2, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11AB0, 0x11AF8, G_UNICODE_OTHER_LETTER },
  { 0x11B00, 0x11B09, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11BC0, 0x11BE0, G_UNICODE_OTHER_LETTER },
  { 0x11BE1, 0x11BE1, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11BF0, 0x11BF9, G_UNICODE_DECIMAL_NUMBER },
  { 0x11C00, 0x11C08, G_UNICODE_OTHER_LETTER },
  { 0x11C0A, 0x11C2E, G_UNICODE_OTHER_LETTER },
  { 0x11C2F, 0x11C2F, G_UNICODE_SPACING_MARK },
  { 0x11C30, 0x11C36, G_UNICODE_NON_SPACING_MARK },
  { 0x11C38, 0x11C3D, G_UNICODE_NON_SPACING_MARK },
  { 0x11C3E, 0x11C3E, G_UNICODE_SPACING_MARK },
  { 0x11C3F, 0x11C3F, G_UNICODE_NON_SPACING_MARK },
  { 0x11C40, 0x11C40, G_UNICODE_OTHER_LETTER },
  { 0x11C41, 0x11C45, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11C50, 0x11C59, G_UNICODE_DECIMAL_NUMBER },
  { 0x11C5A, 0x11C6C, G_UNICODE_OTHER_NUMBER },
  { 0x11C70, 0x11C71, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11C72, 0x11C8F, G_UNICODE_OTHER_LETTER },
  { 0x11C92, 0x11CA7, G_UNICODE_NON_SPACING_MARK },
  { 0x11CA9, 0x11CA9, G_UNICODE_SPACING_MARK },
  { 0x11CAA, 0x11CB0, G_UNICODE_NON_SPACING_MARK },
  { 0x11CB1, 0x11CB1, G_UNICODE_SPACING_MARK },
  { 0x11CB2, 0x11CB3, G_UNICODE_NON_SPACING_MARK },
  { 0x11CB4, 0x11CB4, G_UNICODE_SPACING_MARK },
  { 0x11CB5, 0x11CB6, G_UNICODE_NON_SPACING_MARK },
  { 0x11D00, 0x11D06, G_UNICODE_OTHER_LETTER },
  { 0x11D08, 0x11D09, G_UNICODE_OTHER_LETTER },
  { 0x11D0B, 0x11D30, G_UNICODE_OTHER_LETTER },
  { 0x11D31, 0x11D36, G_UNICODE_NON_SPACING_MARK },
  { 0x11D3A, 0x11D3A, G_UNICODE_NON_SPACING_MARK },
  { 0x11D3C, 0x11D3D, G_UNICODE_NON_SPACING_MARK },
  { 0x11D3F, 0x11D45, G_UNICODE_NON_SPACING_MARK },
  { 0x11D46, 0x11D46, G_UNICODE_OTHER_LETTER },
  { 0x11D47, 0x11D47, G_UNICODE_NON_SPACING_MARK },
  { 0x11D50, 0x11D59, G_UNICODE_DECIMAL_NUMBER },
  { 0x11D60, 0x11D65, G_UNICODE_OTHER_LETTER },
  { 0x11D67, 0x11D68, G_UNICODE_OTHER_LETTER },
  { 0x11D6A, 0x11D89, G_UNICODE_OTHER_LETTER },
  { 0x11D8A, 0x11D8E, G_UNICODE_SPACING_MARK },
  { 0x11D90, 0x11D91, G_UNICODE_NON_SPACING_MARK },
  { 0x11D93, 0x11D94, G_UNICODE_SPACING_MARK },
  { 0x11D95, 0x11D95, G_UNICODE_NON_SPACING_MARK },
  { 0x11D96, 0x11D96, G_UNICODE_SPACING_MARK },
  { 0x11D97, 0x11D97, G_UNICODE_NON_SPACING_MARK },
  { 0x11D98, 0x11D98, G_UNICODE_OTHER_LETTER },
  { 0x11DA0, 0x11DA9, G_UNICODE_DECIMAL_NUMBER },
  { 0x11EE0, 0x11EF2, G_UNICODE_OTHER_LETTER },
  { 0x11EF3, 0x11EF4, G_UNICODE_NON_SPACING_MARK },
  { 0x11EF5, 0x11EF6, G_UNICODE_SPACING_MARK },
  { 0x11EF7, 0x11EF8, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11F00, 0x11F01, G_UNICODE_NON_SPACING_MARK },
  { 0x11F02, 0x11F02, G_UNICODE_OTHER_LETTER },
  { 0x11F03, 0x11F03, G_UNICODE_SPACING_MARK },
  { 0x11F04, 0x11F10, G_UNICODE_OTHER_LETTER },
  { 0x11F12, 0x11F33, G_UNICODE_OTHER_LETTER },
  { 0x11F34, 0x11F35, G_UNICODE_SPACING_MARK },
  { 0x11F36, 0x11F3A, G_UNICODE_NON_SPACING_MARK },
  { 0x11F3E, 0x11F3F, G_UNICODE_SPACING_MARK },
  { 0x11F40, 0x11F40, G_UNICODE_NON_SPACING_MARK },
  { 0x11F41, 0x11F41, G_UNICODE_SPACING_MARK },
  { 0x11F42, 0x11F42, G_UNICODE_NON_SPACING_MARK },
  { 0x11F43, 0x11F4F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x11F50, 0x11F59, G_UNICODE_DECIMAL_NUMBER },
  { 0x11F5A, 0x11F5A, G_UNICODE_NON_SPACING_MARK },
  { 0x11FB0, 0x11FB0, G_UNICODE_OTHER_LETTER },
  { 0x11FC0, 0x11FD4, G_UNICODE_OTHER_NUMBER },
  { 0x11FD5, 0x11FDC, G_UNICODE_OTHER_SYMBOL },
  { 0x11FDD, 0x11FE0, G_UNICODE_CURRENCY_SYMBOL },
  { 0x11FE1, 0x11FF1, G_UNICODE_OTHER_SYMBOL },
  { 0x11FFF, 0x11FFF, G_UNICODE_OTHER_PUNCTUATION },
  { 0x12000, 0x12399, G_UNICODE_OTHER_LETTER },
  { 0x12400, 0x1246E, G_UNICODE_LETTER_NUMBER },
  { 0x12470, 0x12474, G_UNICODE_OTHER_PUNCTUATION },
  { 0x12480, 0x12543, G_UNICODE_OTHER_LETTER },
  { 0x12F90, 0x12FF0, G_UNICODE_OTHER_LETTER },
  { 0x12FF1, 0x12FF2, G_UNICODE_OTHER_PUNCTUATION },
  { 0x13000, 0x1342F, G_UNICODE_OTHER_LETTER },
  { 0x13430, 0x1343F, G_UNICODE_FORMAT },
  { 0x13440, 0x13440, G_UNICODE_NON_SPACING_MARK },
  { 0x13441, 0x13446, G_UNICODE_OTHER_LETTER },
  { 0x13447, 0x13455, G_UNICODE_NON_SPACING_MARK },
  { 0x13460, 0x143FA, G_UNICODE_OTHER_LETTER },
  { 0x14400, 0x14646, G_UNICODE_OTHER_LETTER },
  { 0x16100, 0x1611D, G_UNICODE_OTHER_LETTER },
  { 0x1611E, 0x16129, G_UNICODE_NON_SPACING_MARK },
  { 0x1612A, 0x1612C, G_UNICODE_SPACING_MARK },
  { 0x1612D, 0x1612F, G_UNICODE_NON_SPACING_MARK },
  { 0x16130, 0x16139, G_UNICODE_DECIMAL_NUMBER },
  { 0x16800, 0x16A38, G_UNICODE_OTHER_LETTER },
  { 0x16A40, 0x16A5E, G_UNICODE_OTHER_LETTER },
  { 0x16A60, 0x16A69, G_UNICODE_DECIMAL_NUMBER },
  { 0x16A6E, 0x16A6F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16A70, 0x16ABE, G_UNICODE_OTHER_LETTER },
  { 0x16AC0, 0x16AC9, G_UNICODE_DECIMAL_NUMBER },
  { 0x16AD0, 0x16AED, G_UNICODE_OTHER_LETTER },
  { 0x16AF0, 0x16AF4, G_UNICODE_NON_SPACING_MARK },
  { 0x16AF5, 0x16AF5, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16B00, 0x16B2F, G_UNICODE_OTHER_LETTER },
  { 0x16B30, 0x16B36, G_UNICODE_NON_SPACING_MARK },
  { 0x16B37, 0x16B3B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16B3C, 0x16B3F, G_UNICODE_OTHER_SYMBOL },
  { 0x16B40, 0x16B43, G_UNICODE_MODIFIER_LETTER },
  { 0x16B44, 0x16B44, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16B45, 0x16B45, G_UNICODE_OTHER_SYMBOL },
  { 0x16B50, 0x16B59, G_UNICODE_DECIMAL_NUMBER },
  { 0x16B5B, 0x16B61, G_UNICODE_OTHER_NUMBER },
  { 0x16B63, 0x16B77, G_UNICODE_OTHER_LETTER },
  { 0x16B7D, 0x16B8F, G_UNICODE_OTHER_LETTER },
  { 0x16D40, 0x16D42, G_UNICODE_MODIFIER_LETTER },
  { 0x16D43, 0x16D6A, G_UNICODE_OTHER_LETTER },
  { 0x16D6B, 0x16D6C, G_UNICODE_MODIFIER_LETTER },
  { 0x16D6D, 0x16D6F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16D70, 0x16D79, G_UNICODE_DECIMAL_NUMBER },
  { 0x16E40, 0x16E5F, G_UNICODE_UPPERCASE_LETTER },
  { 0x16E60, 0x16E7F, G_UNICODE_LOWERCASE_LETTER },
  { 0x16E80, 0x16E96, G_UNICODE_OTHER_NUMBER },
  { 0x16E97, 0x16E9A, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16F00, 0x16F4A, G_UNICODE_OTHER_LETTER },
  { 0x16F4F, 0x16F4F, G_UNICODE_NON_SPACING_MARK },
  { 0x16F50, 0x16F50, G_UNICODE_OTHER_LETTER },
  { 0x16F51, 0x16F87, G_UNICODE_SPACING_MARK },
  { 0x16F8F, 0x16F92, G_UNICODE_NON_SPACING_MARK },
  { 0x16F93, 0x16F9F, G_UNICODE_MODIFIER_LETTER },
  { 0x16FE0, 0x16FE1, G_UNICODE_MODIFIER_LETTER },
  { 0x16FE2, 0x16FE2, G_UNICODE_OTHER_PUNCTUATION },
  { 0x16FE3, 0x16FE3, G_UNICODE_MODIFIER_LETTER },
  { 0x16FE4, 0x16FE4, G_UNICODE_NON_SPACING_MARK },
  { 0x16FF0, 0x16FF1, G_UNICODE_SPACING_MARK },
  { 0x17000, 0x187F7, G_UNICODE_OTHER_LETTER },
  { 0x18800, 0x18CD5, G_UNICODE_OTHER_LETTER },
  { 0x18CFF, 0x18D08, G_UNICODE_OTHER_LETTER },
  { 0x1AFF0, 0x1AFF3, G_UNICODE_MODIFIER_LETTER },
  { 0x1AFF5, 0x1AFFB, G_UNICODE_MODIFIER_LETTER },
  { 0x1AFFD, 0x1AFFE, G_UNICODE_MODIFIER_LETTER },
  { 0x1B000, 0x1B122, G_UNICODE_OTHER_LETTER },
  { 0x1B132, 0x1B132, G_UNICODE_OTHER_LETTER },
  { 0x1B150, 0x1B152, G_UNICODE_OTHER_LETTER },
  { 0x1B155, 0x1B155, G_UNICODE_OTHER_LETTER },
  { 0x1B164, 0x1B167, G_UNICODE_OTHER_LETTER },
  { 0x1B170, 0x1B2FB, G_UNICODE_OTHER_LETTER },
  { 0x1BC00, 0x1BC6A, G_UNICODE_OTHER_LETTER },
  { 0x1BC70, 0x1BC7C, G_UNICODE_OTHER_LETTER },
  { 0x1BC80, 0x1BC88, G_UNICODE_OTHER_LETTER },
  { 0x1BC90, 0x1BC99, G_UNICODE_OTHER_LETTER },
  { 0x1BC9C, 0x1BC9C, G_UNICODE_OTHER_SYMBOL },
  { 0x1BC9D, 0x1BC9E, G_UNICODE_NON_SPACING_MARK },
  { 0x1BC9F, 0x1BC9F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1BCA0, 0x1BCA3, G_UNICODE_FORMAT },
  { 0x1CC00, 0x1CCEF, G_UNICODE_OTHER_SYMBOL },
  { 0x1CCF0, 0x1CCF9, G_UNICODE_DECIMAL_NUMBER },
  { 0x1CD00, 0x1CEB3, G_UNICODE_OTHER_SYMBOL },
  { 0x1CF00, 0x1CF2D, G_UNICODE_NON_SPACING_MARK },
  { 0x1CF30, 0x1CF46, G_UNICODE_NON_SPACING_MARK },
  { 0x1CF50, 0x1CFC3, G_UNICODE_OTHER_SYMBOL },
  { 0x1D000, 0x1D0F5, G_UNICODE_OTHER_SYMBOL },
  { 0x1D100, 0x1D126, G_UNICODE_OTHER_SYMBOL },
  { 0x1D129, 0x1D164, G_UNICODE_OTHER_SYMBOL },
  { 0x1D165, 0x1D166, G_UNICODE_SPACING_MARK },
  { 0x1D167, 0x1D169, G_UNICODE_NON_SPACING_MARK },
  { 0x1D16A, 0x1D16C, G_UNICODE_OTHER_SYMBOL },
  { 0x1D16D, 0x1D172, G_UNICODE_SPACING_MARK },
  { 0x1D173, 0x1D17A, G_UNICODE_FORMAT },
  { 0x1D17B, 0x1D182, G_UNICODE_NON_SPACING_MARK },
  { 0x1D183, 0x1D184, G_UNICODE_OTHER_SYMBOL },
  { 0x1D185, 0x1D18B, G_UNICODE_NON_SPACING_MARK },
  { 0x1D18C, 0x1D1A9, G_UNICODE_OTHER_SYMBOL },
  { 0x1D1AA, 0x1D1AD, G_UNICODE_NON_SPACING_MARK },
  { 0x1D1AE, 0x1D1EA, G_UNICODE_OTHER_SYMBOL },
  { 0x1D200, 0x1D241, G_UNICODE_OTHER_SYMBOL },
  { 0x1D242, 0x1D244, G_UNICODE_NON_SPACING_MARK },
  { 0x1D245, 0x1D245, G_UNICODE_OTHER_SYMBOL },
  { 0x1D2C0, 0x1D2D3, G_UNICODE_OTHER_NUMBER },
  { 0x1D2E0, 0x1D2F3, G_UNICODE_OTHER_NUMBER },
  { 0x1D300, 0x1D356, G_UNICODE_OTHER_SYMBOL },
  { 0x1D360, 0x1D378, G_UNICODE_OTHER_NUMBER },
  { 0x1D400, 0x1D419, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D41A, 0x1D433, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D434, 0x1D44D, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D44E, 0x1D454, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D456, 0x1D467, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D468, 0x1D481, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D482, 0x1D49B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D49C, 0x1D49C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D49E, 0x1D49F, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D4A2, 0x1D4A2, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D4A5, 0x1D4A6, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D4A9, 0x1D4AC, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D4AE, 0x1D4B5, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D4B6, 0x1D4B9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D4BB, 0x1D4BB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D4BD, 0x1D4C3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D4C5, 0x1D4CF, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D4D0, 0x1D4E9, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D4EA, 0x1D503, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D504, 0x1D505, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D507, 0x1D50A, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D50D, 0x1D514, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D516, 0x1D51C, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D51E, 0x1D537, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D538, 0x1D539, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D53B, 0x1D53E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D540, 0x1D544, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D546, 0x1D546, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D54A, 0x1D550, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D552, 0x1D56B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D56C, 0x1D585, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D586, 0x1D59F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D5A0, 0x1D5B9, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D5BA, 0x1D5D3, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D5D4, 0x1D5ED, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D5EE, 0x1D607, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D608, 0x1D621, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D622, 0x1D63B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D63C, 0x1D655, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D656, 0x1D66F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D670, 0x1D689, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D68A, 0x1D6A5, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D6A8, 0x1D6C0, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D6C1, 0x1D6C1, G_UNICODE_MATH_SYMBOL },
  { 0x1D6C2, 0x1D6DA, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D6DB, 0x1D6DB, G_UNICODE_MATH_SYMBOL },
  { 0x1D6DC, 0x1D6E1, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D6E2, 0x1D6FA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D6FB, 0x1D6FB, G_UNICODE_MATH_SYMBOL },
  { 0x1D6FC, 0x1D714, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D715, 0x1D715, G_UNICODE_MATH_SYMBOL },
  { 0x1D716, 0x1D71B, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D71C, 0x1D734, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D735, 0x1D735, G_UNICODE_MATH_SYMBOL },
  { 0x1D736, 0x1D74E, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D74F, 0x1D74F, G_UNICODE_MATH_SYMBOL },
  { 0x1D750, 0x1D755, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D756, 0x1D76E, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D76F, 0x1D76F, G_UNICODE_MATH_SYMBOL },
  { 0x1D770, 0x1D788, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D789, 0x1D789, G_UNICODE_MATH_SYMBOL },
  { 0x1D78A, 0x1D78F, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D790, 0x1D7A8, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D7A9, 0x1D7A9, G_UNICODE_MATH_SYMBOL },
  { 0x1D7AA, 0x1D7C2, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D7C3, 0x1D7C3, G_UNICODE_MATH_SYMBOL },
  { 0x1D7C4, 0x1D7C9, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D7CA, 0x1D7CA, G_UNICODE_UPPERCASE_LETTER },
  { 0x1D7CB, 0x1D7CB, G_UNICODE_LOWERCASE_LETTER },
  { 0x1D7CE, 0x1D7FF, G_UNICODE_DECIMAL_NUMBER },
  { 0x1D800, 0x1D9FF, G_UNICODE_OTHER_SYMBOL },
  { 0x1DA00, 0x1DA36, G_UNICODE_NON_SPACING_MARK },
  { 0x1DA37, 0x1DA3A, G_UNICODE_OTHER_SYMBOL },
  { 0x1DA3B, 0x1DA6C, G_UNICODE_NON_SPACING_MARK },
  { 0x1DA6D, 0x1DA74, G_UNICODE_OTHER_SYMBOL },
  { 0x1DA75, 0x1DA75, G_UNICODE_NON_SPACING_MARK },
  { 0x1DA76, 0x1DA83, G_UNICODE_OTHER_SYMBOL },
  { 0x1DA84, 0x1DA84, G_UNICODE_NON_SPACING_MARK },
  { 0x1DA85, 0x1DA86, G_UNICODE_OTHER_SYMBOL },
  { 0x1DA87, 0x1DA8B, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1DA9B, 0x1DA9F, G_UNICODE_NON_SPACING_MARK },
  { 0x1DAA1, 0x1DAAF, G_UNICODE_NON_SPACING_MARK },
  { 0x1DF00, 0x1DF09, G_UNICODE_LOWERCASE_LETTER },
  { 0x1DF0A, 0x1DF0A, G_UNICODE_OTHER_LETTER },
  { 0x1DF0B, 0x1DF1E, G_UNICODE_LOWERCASE_LETTER },
  { 0x1DF25, 0x1DF2A, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E000, 0x1E006, G_UNICODE_NON_SPACING_MARK },
  { 0x1E008, 0x1E018, G_UNICODE_NON_SPACING_MARK },
  { 0x1E01B, 0x1E021, G_UNICODE_NON_SPACING_MARK },
  { 0x1E023, 0x1E024, G_UNICODE_NON_SPACING_MARK },
  { 0x1E026, 0x1E02A, G_UNICODE_NON_SPACING_MARK },
  { 0x1E030, 0x1E06D, G_UNICODE_MODIFIER_LETTER },
  { 0x1E08F, 0x1E08F, G_UNICODE_NON_SPACING_MARK },
  { 0x1E100, 0x1E12C, G_UNICODE_OTHER_LETTER },
  { 0x1E130, 0x1E136, G_UNICODE_NON_SPACING_MARK },
  { 0x1E137, 0x1E13D, G_UNICODE_MODIFIER_LETTER },
  { 0x1E140, 0x1E149, G_UNICODE_DECIMAL_NUMBER },
  { 0x1E14E, 0x1E14E, G_UNICODE_OTHER_LETTER },
  { 0x1E14F, 0x1E14F, G_UNICODE_OTHER_SYMBOL },
  { 0x1E290, 0x1E2AD, G_UNICODE_OTHER_LETTER },
  { 0x1E2AE, 0x1E2AE, G_UNICODE_NON_SPACING_MARK },
  { 0x1E2C0, 0x1E2EB, G_UNICODE_OTHER_LETTER },
  { 0x1E2EC, 0x1E2EF, G_UNICODE_NON_SPACING_MARK },
  { 0x1E2F0, 0x1E2F9, G_UNICODE_DECIMAL_NUMBER },
  { 0x1E2FF, 0x1E2FF, G_UNICODE_CURRENCY_SYMBOL },
  { 0x1E4D0, 0x1E4EA, G_UNICODE_OTHER_LETTER },
  { 0x1E4EB, 0x1E4EB, G_UNICODE_MODIFIER_LETTER },
  { 0x1E4EC, 0x1E4EF, G_UNICODE_NON_SPACING_MARK },
  { 0x1E4F0, 0x1E4F9, G_UNICODE_DECIMAL_NUMBER },
  { 0x1E5D0, 0x1E5ED, G_UNICODE_OTHER_LETTER },
  { 0x1E5EE, 0x1E5EF, G_UNICODE_NON_SPACING_MARK },
  { 0x1E5F0, 0x1E5F0, G_UNICODE_OTHER_LETTER },
  { 0x1E5F1, 0x1E5FA, G_UNICODE_DECIMAL_NUMBER },
  { 0x1E5FF, 0x1E5FF, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1E7E0, 0x1E7E6, G_UNICODE_OTHER_LETTER },
  { 0x1E7E8, 0x1E7EB, G_UNICODE_OTHER_LETTER },
  { 0x1E7ED, 0x1E7EE, G_UNICODE_OTHER_LETTER },
  { 0x1E7F0, 0x1E7FE, G_UNICODE_OTHER_LETTER },
  { 0x1E800, 0x1E8C4, G_UNICODE_OTHER_LETTER },
  { 0x1E8C7, 0x1E8CF, G_UNICODE_OTHER_NUMBER },
  { 0x1E8D0, 0x1E8D6, G_UNICODE_NON_SPACING_MARK },
  { 0x1E900, 0x1E921, G_UNICODE_UPPERCASE_LETTER },
  { 0x1E922, 0x1E943, G_UNICODE_LOWERCASE_LETTER },
  { 0x1E944, 0x1E94A, G_UNICODE_NON_SPACING_MARK },
  { 0x1E94B, 0x1E94B, G_UNICODE_MODIFIER_LETTER },
  { 0x1E950, 0x1E959, G_UNICODE_DECIMAL_NUMBER },
  { 0x1E95E, 0x1E95F, G_UNICODE_OTHER_PUNCTUATION },
  { 0x1EC71, 0x1ECAB, G_UNICODE_OTHER_NUMBER },
  { 0x1ECAC, 0x1ECAC, G_UNICODE_OTHER_SYMBOL },
  { 0x1ECAD, 0x1ECAF, G_UNICODE_OTHER_NUMBER },
  { 0x1ECB0, 0x1ECB0, G_UNICODE_CURRENCY_SYMBOL },
  { 0x1ECB1, 0x1ECB4, G_UNICODE_OTHER_NUMBER },
  { 0x1ED01, 0x1ED2D, G_UNICODE_OTHER_NUMBER },
  { 0x1ED2E, 0x1ED2E, G_UNICODE_OTHER_SYMBOL },
  { 0x1ED2F, 0x1ED3D, G_UNICODE_OTHER_NUMBER },
  { 0x1EE00, 0x1EE03, G_UNICODE_OTHER_LETTER },
  { 0x1EE05, 0x1EE1F, G_UNICODE_OTHER_LETTER },
  { 0x1EE21, 0x1EE22, G_UNICODE_OTHER_LETTER },
  { 0x1EE24, 0x1EE24, G_UNICODE_OTHER_LETTER },
  { 0x1EE27, 0x1EE27, G_UNICODE_OTHER_LETTER },
  { 0x1EE29, 0x1EE32, G_UNICODE_OTHER_LETTER },
  { 0x1EE34, 0x1EE37, G_UNICODE_OTHER_LETTER },
  { 0x1EE39, 0x1EE39, G_UNICODE_OTHER_LETTER },
  { 0x1EE3B, 0x1EE3B, G_UNICODE_OTHER_LETTER },
  { 0x1EE42, 0x1EE42, G_UNICODE_OTHER_LETTER },
  { 0x1EE47, 0x1EE47, G_UNICODE_OTHER_LETTER },
  { 0x1EE49, 0x1EE49, G_UNICODE_OTHER_LETTER },
  { 0x1EE4B, 0x1EE4B, G_UNICODE_OTHER_LETTER },
  { 0x1EE4D, 0x1EE4F, G_UNICODE_OTHER_LETTER },
  { 0x1EE51, 0x1EE52, G_UNICODE_OTHER_LETTER },
  { 0x1EE54, 0x1EE54, G_UNICODE_OTHER_LETTER },
  { 0x1EE57, 0x1EE57, G_UNICODE_OTHER_LETTER },
  { 0x1EE59, 0x1EE59, G_UNICODE_OTHER_LETTER },
  { 0x1EE5B, 0x1EE5B, G_UNICODE_OTHER_LETTER },
  { 0x1EE5D, 0x1EE5D, G_UNICODE_OTHER_LETTER },
  { 0x1EE5F, 0x1EE5F, G_UNICODE_OTHER_LETTER },
  { 0x1EE61, 0x1EE62, G_UNICODE_OTHER_LETTER },
  { 0x1EE64, 0x1EE64, G_UNICODE_OTHER_LETTER },
  { 0x1EE67, 0x1EE6A, G_UNICODE_OTHER_LETTER },
  { 0x1EE6C, 0x1EE72, G_UNICODE_OTHER_LETTER },
  { 0x1EE74, 0x1EE77, G_UNICODE_OTHER_LETTER },
  { 0x1EE79, 0x1EE7C, G_UNICODE_OTHER_LETTER },
  { 0x1EE7E, 0x1EE7E, G_UNICODE_OTHER_LETTER },
  { 0x1EE80, 0x1EE89, G_UNICODE_OTHER_LETTER },
  { 0x1EE8B, 0x1EE9B, G_UNICODE_OTHER_LETTER },
  { 0x1EEA1, 0x1EEA3, G_UNICODE_OTHER_LETTER },
  { 0x1EEA5, 0x1EEA9, G_UNICODE_OTHER_LETTER },
  { 0x1EEAB, 0x1EEBB, G_UNICODE_OTHER_LETTER },
  { 0x1EEF0, 0x1EEF1, G_UNICODE_MATH_SYMBOL },
  { 0x1F000, 0x1F02B, G_UNICODE_OTHER_SYMBOL },
  { 0x1F030, 0x1F093, G_UNICODE_OTHER_SYMBOL },
  { 0x1F0A0, 0x1F0AE, G_UNICODE_OTHER_SYMBOL },
  { 0x1F0B1, 0x1F0BF, G_UNICODE_OTHER_SYMBOL },
  { 0x1F0C1, 0x1F0CF, G_UNICODE_OTHER_SYMBOL },
  { 0x1F0D1, 0x1F0F5, G_UNICODE_OTHER_SYMBOL },
  { 0x1F100, 0x1F10C, G_UNICODE_OTHER_NUMBER },
  { 0x1F10D, 0x1F1AD, G_UNICODE_OTHER_SYMBOL },
  { 0x1F1E6, 0x1F202, G_UNICODE_OTHER_SYMBOL },
  { 0x1F210, 0x1F23B, G_UNICODE_OTHER_SYMBOL },
  { 0x1F240, 0x1F248, G_UNICODE_OTHER_SYMBOL },
  { 0x1F250, 0x1F251, G_UNICODE_OTHER_SYMBOL },
  { 0x1F260, 0x1F265, G_UNICODE_OTHER_SYMBOL },
  { 0x1F300, 0x1F3FA, G_UNICODE_OTHER_SYMBOL },
  { 0x1F3FB, 0x1F3FF, G_UNICODE_MODIFIER_SYMBOL },
  { 0x1F400, 0x1F6D7, G_UNICODE_OTHER_SYMBOL },
  { 0x1F6DC, 0x1F6EC, G_UNICODE_OTHER_SYMBOL },
  { 0x1F6F0, 0x1F6FC, G_UNICODE_OTHER_SYMBOL },
  { 0x1F700, 0x1F776, G_UNICODE_OTHER_SYMBOL },
  { 0x1F77B, 0x1F7D9, G_UNICODE_OTHER_SYMBOL },
  { 0x1F7E0, 0x1F7EB, G_UNICODE_OTHER_SYMBOL },
  { 0x1F7F0, 0x1F7F0, G_UNICODE_OTHER_SYMBOL },
  { 0x1F800, 0x1F80B, G_UNICODE_OTHER_SYMBOL },
  { 0x1F810, 0x1F847, G_UNICODE_OTHER_SYMBOL },
  { 0x1F850, 0x1F859, G_UNICODE_OTHER_SYMBOL },
  { 0x1F860, 0x1F887, G_UNICODE_OTHER_SYMBOL },
  { 0x1F890, 0x1F8AD, G_UNICODE_OTHER_SYMBOL },
  { 0x1F8B0, 0x1F8BB, G_UNICODE_OTHER_SYMBOL },
  { 0x1F8C0, 0x1F8C1, G_UNICODE_OTHER_SYMBOL },
  { 0x1F900, 0x1FA53, G_UNICODE_OTHER_SYMBOL },
  { 0x1FA60, 0x1FA6D, G_UNICODE_OTHER_SYMBOL },
  { 0x1FA70, 0x1FA7C, G_UNICODE_OTHER_SYMBOL },
  { 0x1FA80, 0x1FA89, G_UNICODE_OTHER_SYMBOL },
  { 0x1FA8F, 0x1FAC6, G_UNICODE_OTHER_SYMBOL },
  { 0x1FACE, 0x1FADC, G_UNICODE_OTHER_SYMBOL },
  { 0x1FADF, 0x1FAE9, G_UNICODE_OTHER_SYMBOL },
  { 0x1FAF0, 0x1FAF8, G_UNICODE_OTHER_SYMBOL },
  { 0x1FB00, 0x1FB92, G_UNICODE_OTHER_SYMBOL },
  { 0x1FB94, 0x1FBEF, G_UNICODE_OTHER_SYMBOL },
  { 0x1FBF0, 0x1FBF9, G_UNICODE_DECIMAL_NUMBER },
  { 0x20000, 0x2A6DF, G_UNICODE_OTHER_LETTER },
  { 0x2A700, 0x2B739, G_UNICODE_OTHER_LETTER },
  { 0x2B740, 0x2B81D, G_UNICODE_OTHER_LETTER },
  { 0x2B820, 0x2CEA1, G_UNICODE_OTHER_LETTER },
  { 0x2CEB0, 0x2EBE0, G_UNICODE_OTHER_LETTER },
  { 0x2EBF0, 0x2EE5D, G_UNICODE_OTHER_LETTER },
  { 0x2F800, 0x2FA1D, G_UNICODE_OTHER_LETTER },
  { 0x30000, 0x3134A, G_UNICODE_OTHER_LETTER },
  { 0x31350, 0x323AF, G_UNICODE_OTHER_LETTER },
  { 0xE0001, 0xE0001, G_UNICODE_FORMAT },
  { 0xE0020, 0xE007F, G_UNICODE_FORMAT },
  { 0xE0100, 0xE01EF, G_UNICODE_NON_SPACING_MARK },
  { 0xF0000, 0xFFFFD, G_UNICODE_PRIVATE_USE },
  { 0x100000, 0x10FFFD, G_UNICODE_PRIVATE_USE },
};

#endif

